﻿<%@ Page Title="" Language="VB" MasterPageFile="~/Views/Shared/Modal.Master" Inherits="System.Web.Mvc.ViewPage" %>

<asp:Content ID="Content1" ContentPlaceHolderID="cphHeadSection" runat="server">
    <script>
        require([
               "dojo/parser",
               "dojox/charting/Chart",
               "dojox/charting/themes/MiamiNice",
               "dojox/charting/plot2d/ClusteredColumns",
               "dojox/charting/plot2d/Grid",
               "dojox/charting/action2d/Tooltip",
               "dojox/charting/widget/Legend",
               "dojox/charting/action2d/MouseZoomAndPan",
               "dojox/charting/action2d/TouchZoomAndPan",
               "dojo/dom-style",
               "dojox/charting/Series",
               "dojo/on",
               "dojo/_base/array",
               "dojo/number",
               "dojox/charting/axis2d/Default",
               "dojo/domReady!"
        ], function (parser, Chart, theme, ClusteredColumns, Grid, Tooltip, Legend, MouseZoomAndPan, TouchZoomAndPan, domStyle, Series, on, array, number) {

            var tailingsPondAreaData = dojo.xhrGet({
                "url": window.location.href.substring(0,window.location.href.indexOf("TailingsPond")) + "data/TailingsPondAreas.json", 
                "handleAs": "json"
            });

            // get data from json file
            tailingsPondAreaData.then(requestSucceeded, requestFailed);

            function requestSucceeded(response, io) {

                var tailingsYears = [];
                var tailingsActiveArea = [];
                var tailingsPondActiveArea = [];
                var tailingsWaterArea = [];
                var tailingsDryArea = [];
                var maxArea = 0, index = 0,
                    latestYear = 0, latestActiveArea = 0, latestWaterArea = 0, latestPondVolume = 0,
                    latestActiveAreaAcres = 0, latestWaterAreaAcres = 0,
                    glossaryLink = "<%=ConfigurationManager.AppSettings("dataServiceUrl")%>" + "/lightboxLB/getstyledlightbox?csspage=White.css&contentpage=portal_glossary.htm#Fine_Tailings";

                array.forEach(response.TailingsPondAreas, function (tailingsPondAreas) {
                    index += 1;
                    tailingsYears.push({ value: index, text: tailingsPondAreas.year });
                    tailingsActiveArea.push(tailingsPondAreas.total_active_all_tailings_km2);
                    tailingsPondActiveArea.push(tailingsPondAreas.total_active_all_tailings_pond_km2);
                    tailingsWaterArea.push(tailingsPondAreas.total_tailings_pond_water_area_km2);
                    tailingsDryArea.push(tailingsPondAreas.total_tailings_pond_dry_area_km2);

                    if (tailingsPondAreas.total_active_all_tailings_km2 > maxArea) {
                        maxArea = tailingsPondAreas.total_active_all_tailings_km2;
                    }
                    
                    if (tailingsPondAreas.year > latestYear) {
                        latestYear = tailingsPondAreas.year;
                        latestActiveArea = tailingsPondAreas.total_active_all_tailings_km2;
                        latestWaterArea = tailingsPondAreas.total_tailings_pond_water_area_km2;
                        latestPondVolume = tailingsPondAreas.total_volume_of_fine_fluid_tailingsMm3;
                    }
                });

                // convert to acres
                latestActiveAreaAcres = number.format((latestActiveArea * 247.105), { places: 0, locale: "en-ca" });
                latestWaterAreaAcres = number.format((latestWaterArea * 247.105), { places: 0, locale: "en-ca" });
                
                // set chart description text
                var chartDescription = dojo.byId("chartDescription");
                chartDescription.innerHTML = "The total area occupied by oil sands tailings ponds and associated structures (such as dikes) was " + latestActiveArea + " km2 or " + latestActiveAreaAcres + " acres at the end of " + latestYear
                    + ". Of that, the total liquid surface area of the ponds was " + latestWaterArea + " km2 or " + latestWaterAreaAcres + " acres (" + latestYear + ")." 
                    + " The total volume of " + "<a href='" + glossaryLink + "'>fine fluid tailings</a>" + " reported by the mine operators for " + latestYear + " was " + latestPondVolume + " Bm3.";
                
                
                // Create the chart within it's "holding" node
                var chartTailings = new Chart("chartNodeTailings");

                // Set theme
                chartTailings.setTheme(theme);

                // Add the default plot
                chartTailings.addPlot("default", {
                    type: "ClusteredColumns",
                    markers: true,
                    gap: 5,
                    maxBarSize: 20
                });

                // Add axes
                chartTailings.addAxis("x", {
                    labels: tailingsYears,
                    title: "Year",
                    majorTickStep: 1,
                    minorTickStep: 0,
                    titleOrientation: "away"
                });

                chartTailings.addAxis("y", {
                    vertical: true,
                    max: maxArea,
                    min: 0,
                    minorTicks: false, minorLabels: false, majorTickStep: 100
                });

                // Add the series of data
                chartTailings.addSeries("Total Active Tailings Area including all tailings structures (km2)", tailingsActiveArea, {
                    stroke: { color: "#B27300" },
                    fill: "#B27300"
                });

                chartTailings.addSeries("Total Active Tailings Pond Areas including dykes, berms, and water (km2)", tailingsPondActiveArea, {
                    stroke: { color: "#CC8400" },
                    fill: "#CC8400"
                });

                chartTailings.addSeries("Total Tailings Pond Water Area (km2)", tailingsWaterArea, {
                    stroke: { color: "#FFC859" },
                    fill: "#FFC859"
                });

                chartTailings.addSeries("Total Tailings Pond Drying Areas (km2)", tailingsDryArea, {
                    stroke: { color: "#FFAA00" },
                    fill: "#FFAA00"
                });

                // Tooltip
                var tooltip = new Tooltip(chartTailings, "default");
                
                // Zoom
                var zoomAndPanSpecies = new MouseZoomAndPan(chartTailings, "default", { axis: "x", scaleFactor: 1, maxScale: 4, enableScroll: true, enableDoubleClickZoom: true, keyZoomModifier: "shift" }); //switched to use shift key instead of default ctrl to avoid conflict with browser zooming

                // Render the chart!
                chartTailings.render();

                // Create the legend
                var legend = new Legend({ chart: chartTailings, horizontal: false }, "legendNode");

                parser.parse();
            }
            
            function requestFailed(error) {
                console.log('Get Tailings Pond Area data failed');
            }
        });

    </script>


</asp:Content>

<asp:Content ID="Content2" ContentPlaceHolderID="MainContent" runat="server">
    <div id="detailsPageContentTailings">
        <span class="tailingsTitle">Total Area and Volume of Oil Sands Tailings Ponds over Time</span> <br/>
        <span id="chartDescription" class="tailingsDescription">
        </span>
        <table>
            <tr>
                <td>
                    <div id="chartNodeTailings" style="width: 600px; height: 350px;"></div>
                </td>
                <td>
                    <div id="legendNode"></div>
                    <span class="chartLegendText"> *Volume is not included in this graph.</span>
                </td>
            </tr>
        </table>
        
        <a id="downloadLink" href="<%=ConfigurationManager.AppSettings("DownloadHistoricalTailingsLink")%>" class="links" target="_blank">Download historical tailings area data.</a>
    </div>

</asp:Content>
