﻿define([
    "esri/geometry/Extent"
], function (
    Extent
) {
    'use strict';
    return {
        // **********************************************
        // Example configuration when using a webmap
        // **********************************************

        // example web maps:
        // Portland Bike Map example from Boostrap Map demo pages, see
        // http://esri.github.io/bootstrap-map-js/demo/dojo/webmap.html
        // itemId: '8e42e164d4174da09f61fe0d3f206641',

        // SoCal running trails
        // GPX tracks embeded in web map as feature collections
        // itemId: 'cbb968b3854e4e4fac3f95c30ca41b38',

        // Los Angeles Bike Paths - KML layer of bike paths
        // itemId: '78ca84d1f2534d3496e63fa80240d4f3',

        // web maps from ArcGIS JSAPI sample pages
        // NOTE: both require a dijit theme (i.e. claro)
        // to support the dojox/charting dijits in the popups

        // Tapastry Segments - dynamic map servce w/ dojox/chart in popup
        // itemId: '4778fee6371d4e83a22786029f30c7e1',

        // mobile web map example, see:
        // https://developers.arcgis.com/javascript/jssamples/mobile_arcgis.html
        // itemId: '1e79439598494713b553f990a4040886',

        // NOTE: this is the options sent to arcgisUtils.createMap()
        // see: https://developers.arcgis.com/javascript/jsapi/esri.arcgis.utils-amd.html#createmap
        //options: {
        //  mapOptions: {
        //    basemap: 'topo',
        //    sliderPosition: 'bottom-right'
        //  }
        //},

        // **********************************************
        // Example configuration when NOT using a webmap
        // and loading layers from the settings in this config
        // **********************************************

        // NOTE: this is the options sent to new Map()
        // see: https://developers.arcgis.com/javascript/jsapi/map-amd.html#map1
        options: {
            basemap: 'national-geographic',
            extent: new Extent({
                xmin: -13516233.824208321,
                ymin: 6460888.410972949,
                xmax: -11994831.213220576,
                ymax: 8412784.365262691,
                spatialReference: {
                    wkid: 102100
                }
            }),
            maxExtent: new Extent({
                xmin: -16018476.382151185,
                ymin: 5641483.467756078,
                xmax: -9492588.655277712,
                ymax: 9232189.308479562,
                spatialReference: {
                    wkid: 102100
                }
            }),
            logo: false,
            scrollWheelZoom: true
        },

        basemaps: [
            {
                id: "OpenStreetMap",
                type: "OpenStreetMap",
                title: "Open Street Map",
                thumbnailUrl: "http://www.arcgis.com/sharing/rest/content/items/5d2bfa736f8448b3a1708e1f6be23eed/info/thumbnail/temposm.jpg"
            },
            {
                id: "topographic",
                url: "http://server.arcgisonline.com/ArcGIS/rest/services/World_Topo_Map/MapServer",
                title: "Topographic",
                thumbnailUrl: "http://www.arcgis.com/sharing/rest/content/items/6e03e8c26aad4b9c92a87c1063ddb0e3/info/thumbnail/topo_map_2.jpg"
            },
            {
                id: "streets",
                url: "http://server.arcgisonline.com/ArcGIS/rest/services/World_Street_Map/MapServer",
                title: "Streets",
                thumbnailUrl: "http://www.arcgis.com/sharing/rest/content/items/d8855ee4d3d74413babfb0f41203b168/info/thumbnail/world_street_map.jpg"
            },
            {
                id: "terrain",
                url: "http://services.arcgisonline.com/arcgis/rest/services/World_Terrain_Base/MapServer",
                title: "Terrain",
                thumbnailUrl: "http://www.arcgis.com/sharing/rest/content/items/aab054ab883c4a4094c72e949566ad40/info/thumbnail/terrain_labels.jpg"
            },
            {
                id: "gray",
                url: "http://services.arcgisonline.com/ArcGIS/rest/services/Canvas/World_Light_Gray_Base/MapServer",
                title: "Light Gray",
                thumbnailUrl: "https://www.arcgis.com/sharing/rest/content/items/8b3d38c0819547faa83f7b7aca80bd76/info/thumbnail/thumbnail1579127582619.jpeg"
            },
            {
                id: "dark-gray",
                url: "http://services.arcgisonline.com/arcgis/rest/services/Canvas/World_Dark_Gray_Base/MapServer",
                title: "Dark Gray",
                thumbnailUrl: "http://www.arcgis.com/sharing/rest/content/items/25869b8718c0419db87dad07de5b02d8/info/thumbnail/DGCanvasBase.png"
            },
            {
                id: "imagery",
                url: "http://services.arcgisonline.com/arcgis/rest/services/World_Imagery/MapServer/",
                title: "Satellite",
                thumbnailUrl: "https://www.arcgis.com/sharing/rest/content/items/10df2279f9684e4a9f6a7f08febac2a9/info/thumbnail/thumbnail1584118328864.jpeg"
            },
            {
                id: "national-geographic",
                url: "http://services.arcgisonline.com/ArcGIS/rest/services/NatGeo_World_Map/MapServer",
                title: "National Geographic",
                thumbnailUrl: "http://www.arcgis.com/sharing/rest/content/items/509e2d6b034246d692a461724ae2d62c/info/thumbnail/natgeo.jpg"
            }
        ],

        //basemap gallery div
        galleryId: 'galleryDiv',

        // set the id of a node to place the legend
        // comment this out if you don't want to show legend
        legendNodeId: 'mapLegend',

        // set the id of a node to place content groups in menu
        contentGroupNodeId: 'contentGroupControls',

        // Add config parameters for each map widget you want to include
        // The map reference will get appended to the options
        // To accept default options just pass empty object {}
        // NOTE: to change the position of these widgets, make changes in map.css
        widgets: {
            scalebar: {
                // see https://developers.arcgis.com/javascript/jsapi/scalebar-amd.html#scalebar1
            },
            homeButton: {
                // see: https://developers.arcgis.com/javascript/jsapi/homebutton-amd.html#homebutton1
            },
            locateButton: {
                // see: https://developers.arcgis.com/javascript/jsapi/locatebutton-amd.html#locatebutton1
            },
            geocoder: {
                // see https://developers.arcgis.com/javascript/jsapi/geocoder-amd.html#geocoder1
                autoComplete: true,
                arcgisGeocoder: {
                    placeholder: 'Address or Location'
                },
                'class': 'geocoder'
            }
        }
    };
});