﻿define([
    "app/content/AirEmissionsContent",
    "app/content/AQHIContent"
], function (
    AirEmissionsContent,
    AQHIContent
) {
    'use strict';
    return {
        id: 'Air',
        title: 'AIR',
        description: 'Air',
        iconClass: "icon-air blue-txt",
        operationalLayers: [
            {
                type: 'feature',
                url: siteConfig.osipMapServer + '3',
                title: 'Industrial Emissions Monitoring Stations',
                layerOrder: 3,
                options: {
                    id: 'industrialEmissions',
                    outFields: ['*'],
                    opacity: 1,
                    visible: false
                },
                customModule: new AirEmissionsContent(),
                legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhi_icon_black.png', label: 'Industry Monitoring Station' }]
            },
            {
                type: 'feature',
                title: 'Air Quality Monitoring Stations',
                layerOrder: 3,
                options: {
                    id: 'aqhiLayer',
                    visible: false
                },
                layerDefinition: {
                    geometryType: "esriGeometryPoint",
                    objectIdField: "ObjectID",
                    fields: [{
                        name: "ObjectID",
                        alias: "ObjectID",
                        type: "esriFieldTypeOID"
                    }, {
                        name: "StationName",
                        alias: "StationName",
                        type: "esriFieldTypeString"
                    }, {
                        name: "Abbreviation",
                        alias: "Abbreviation",
                        type: "esriFieldTypeString"
                    }, {
                        name: "AirshedName",
                        alias: "AirshedName",
                        type: "esriFieldTypeString"
                    }, {
                        name: "Type",
                        alias: "Type",
                        type: "esriFieldTypeString"
                    }, {
                        name: "CommunityStationName",
                        alias: "CommunityStationName",
                        type: "esriFieldTypeString"
                    }, {
                        name: "AQHIValue",
                        alias: "AQHIValue",
                        type: "esriFieldTypeInteger"
                    }, {
                        name: "LastUpdated",
                        alias: "LastUpdated",
                        type: "esriFieldTypeString"
                    }, {
                        name: "HealthRisk",
                        alias: "HealthRisk",
                        type: "esriFieldTypeString"
                    }]
                },
                relatedLinks: [
                    {
                        title: "Ambient Air Quality Objectives",
                        url: "http://environmentalmonitoring.alberta.ca/wp-content/uploads/2016/01/AmbientAirQualityObjectives-Aug2013.pdf",
                        type: "link"
                    },
                    {
                        title: "Disclaimer",
                        url: siteConfig.dataUrl + "/lightboxLB/getstyledlightbox?csspage=White.css&contentpage=disclaimer.htm",
                        type: 'iframe',
                        modalCssClass: 'modalSmallContent'
                    },
                    {
                        title: "What is the Air Quality Health Index?",
                        url: siteConfig.dataUrl + "/lightboxLB/getstyledlightbox?csspage=White.css&contentpage=what_is_alberta_ambient_air_quality_index.htm",
                        type: 'iframe'
                    },
                    {
                        title: "AEP airdata",
                        url: "http://airdata.alberta.ca/",
                        type: "link"
                    },
                    {
                        title: "What substances are reported?",
                        url: siteConfig.dataUrl + "/lightboxLB/getstyledlightbox?csspage=White.css&contentpage=what_air_pollutants_are_monitored.htm",
                        type: 'iframe',
                        modalCssClass: 'modalSmallContent'
                    }
                ],
                customModule: new AQHIContent(),
                legendIcons: [
                    { iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhi_icon_white.png', label: 'Air Quality Station without Index' },
                    { iconGroupId: 'airQualityHealthIndex', iconGroupName: 'Air Quality Health Index' },
                    { iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhi1_icon.png', label: 'Low Health Risk' },
                    { iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhi2_icon.png', label: 'Low Health Risk' },
                    { iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhi3_icon.png', label: 'Low Health Risk' },
                    { iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhi4_icon.png', label: 'Moderate Health Risk' },
                    { iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhi5_icon.png', label: 'Moderate Health Risk' },
                    { iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhi6_icon.png', label: 'Moderate Health Risk' },
                    { iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhi7_icon.png', label: 'High Health Risk' },
                    { iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhi8_icon.png', label: 'High Health Risk' },
                    { iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhi9_icon.png', label: 'High Health Risk' },
                    { iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhi10_icon.png', label: 'High Health Risk' },
                    { iconName: siteConfig.rootUrl + 'scripts/app/content/images/air/aqhiPlus_icon.png', label: 'Very High Health Risk' }
                ]
            }
        ]
    };
});