﻿define([
    "app/content/CaribouContent"
], function (    
    CaribouContent
) {
    'use strict';
    return {
        id: 'Biodiversity',
        title: 'BIODIVERSITY',
        description: 'Biodiversity',
        iconClass: "icon-biodiversity blue-txt",
        focusElementId: 'keyWildlifeBiodiversityZone',
        operationalLayers: [
            {
                type: 'feature',
                url: 'https://geospatial.alberta.ca/titan/rest/services/biota/wildlife_sensitivity_mammals_10tm_nad83_aep/MapServer/180',
                title: 'Woodland Caribou Range',
                layerOrder: 1,
                options: {
                    id: 'caribou',
                    outFields: ['OBJECTID', 'LOCALRANGE', 'STATUS', 'SUBUNIT'],
                    opacity: 1,
                    visible: false
                },
                layerDefinition: {
                    geometryType: "esriGeometryPolygon",
                    fields: [{
                        name: "OBJECTID",
                        type: "esriFieldTypeOID",
                        alias: "Object ID"
                    }, {
                        name: "LOCALRANGE",
                        type: "esriFieldTypeString",
                        alias: "Local Range"
                    }, {
                        name: "STATUS",
                        type: "esriFieldTypeString",
                        alias: "Status"
                    }, {
                        name: "SUBUNIT",
                        type: "esriFieldTypeString",
                        alias: "Sub-Unit"
                    }]
                },
                customModule: new CaribouContent(),
                legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/wildlife/woodland_caribou_range.png', label: 'Woodland Caribou Ranges' }]
            },
                {
                    type: 'dynamic',
                    url: 'https://geospatial.alberta.ca/titan/rest/services/biota/wildlife_sensitivity_mammals_10tm_nad83_aep/MapServer',
                    title: 'Grizzly Bear',
                    layerOrder: 1,
                    options: {
                        id: 'GrizzlyBear',
                        visibleLayers: [188],
                        opacity: 1,
                        visible: false
                    },
                    legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/wildlife/grizzly_core.png', label: 'Grizzly Bear Core Ranges' },
                        { iconName: siteConfig.rootUrl + 'scripts/app/content/images/wildlife/grizzly_secondary.png', label: 'Grizzly Bear Secondary Ranges' }],
                    link: {
                        title: 'Grizzly Bear Population',
                        url: siteConfig.libraryUrl + 'SpeciesAtrisk/SpeciesDetails?speciesName=Grizzly Bear',
                        type: 'iframe',
                        cssClass: 'icon floater-right glyphicon glyphicon-modal-window dark-blue-txt'
                    },
                    zoomToLevel: 7
                },
            {
                type: 'dynamic',
                url: 'https://geospatial.alberta.ca/titan/rest/services/biota/wildlife_sensitivity_birds_10tm_nad83_aep/MapServer/',
                title: 'Species At Risk',
                layerOrder: 1,
                options: {
                    id: 'Biodiversity',
                    opacity: 1,
                    multiLayers: [
                        {
                            id: 'PipingPloverWaterbodies',
                            title: 'Piping Plover',
                            visibleLayersIds: [30],
                            link: {
                                title: 'Piping Plover Population',
                                url: siteConfig.libraryUrl + 'SpeciesAtrisk/SpeciesDetails?speciesName=Piping Plover',
                                type: 'iframe',
                                cssClass: 'icon floater-right glyphicon glyphicon-modal-window dark-blue-txt'
                            },
                            zoomToLevel: 7,
                            legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/wildlife/plover_waterbodies.png', label: 'Piping Plover Waterbodies' },
                                          { iconName: siteConfig.rootUrl + 'scripts/app/content/images/wildlife/plover_buffer_50m.png', label: 'Piping Plover 50m Buffer' },
                                          { iconName: siteConfig.rootUrl + 'scripts/app/content/images/wildlife/plover_buffer_100m.png', label: 'Piping Plover 100m Buffer' },
                                          { iconName: siteConfig.rootUrl + 'scripts/app/content/images/wildlife/plover_buffer_200m.png', label: 'Piping Plover 200m Buffer' }
                            ]
                        }                        
                    ],
                    visible: false
                }
            },
            {
                type: 'dynamic',
                url: 'https://geospatial.alberta.ca/titan/rest/services/biota/wildlife_sensitivity_birds_10tm_nad83_aep/MapServer/',
                title: 'Species At Risk',
                layerOrder: 1,
                options: {
                    id: 'Biodiversity',
                    opacity: 1,
                    multiLayers: [
                        {
                            id: 'TrumpeterSwanWaterbodies',
                            title: 'Trumpeter Swan',
                            visibleLayersIds: [40],
                            link: {
                                title: 'Trumpeter Swan Population',
                                url: siteConfig.libraryUrl + 'SpeciesAtrisk/SpeciesDetails?speciesName=Trumpeter Swan',
                                type: 'iframe',
                                cssClass: 'icon floater-right glyphicon glyphicon-modal-window dark-blue-txt'
                            },
                            zoomToLevel: 8,
                            legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/wildlife/swan_waterbody.png', label: 'Trumpeter Swan Waterbodies' },
                                          { iconName: siteConfig.rootUrl + 'scripts/app/content/images/wildlife/swan_buffer_500m.png', label: 'Trumpeter Swan 500m Buffer' },
                                          { iconName: siteConfig.rootUrl + 'scripts/app/content/images/wildlife/swan_buffer_800m.png', label: 'Trumpeter Swan 800m Buffer' }
                            ]
                        }
                    ],
                    visible: false
                }
            },
            {
                type: 'dynamic',
                url: siteConfig.osipMapServer + '',
                title: 'Key Wildlife and Biodiversity Zone',
                layerOrder: 1,
                options: {
                    id: 'keyWildlifeBiodiversityZone',
                    opacity: 1,
                    visibleLayers: [27],
                    visible: false
                },
                legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/wildlife/key_wildlife_and_biodiversity_zones.png', label: 'Key Wildlife and Biodiversity Zones', glossaryAnchorTage: 'Key_Wildlife_and_Biodiversity_Zone' }],
                relatedLinks: [{
                    title: "Alberta Biodiversity Monitoring Institute",
                    url: siteConfig.dataUrl + "/lightboxLB/getstyledlightbox?csspage=White.css&contentpage=alberta_biodiversity_monitoring_institute.htm",
                    type: 'iframe',
                    modalCssClass: 'modalSmallContent'
                }]
            }
        ]
    };
});