﻿define([
    "app/content/OilSandsContent",
    "app/content/TailingsPondContent",
    "app/content/ProjectBoundariesContent"
], function (OilSandsContent, TailingsPondContent, ProjectBoundariesContent) {
    'use strict';
    var landParameters = {
        layerId: 254,
        ospNoField: "OSP_NO",
        hectaresField: "TOTAL_HECTARES",
        yearField: "YEAR_",
        landCoverField: "LANDCOVER"
    };
    return {
        id: 'IndustrialImpacts',
        title: 'INDUSTRIAL IMPACTS',
        description: 'Industrial Impacts',
        iconClass: "icon-oilsands blue-txt",
        focusGroupId: 'oilSandsProjects',
        links: [
            //{
            //    title: "Tailings Ponds Surface Area and Volume",
            //    url: "http://aemerisuat.alberta.ca/library/TailingsPond/TailingsPondAreas"
            //}
        ],
        operationalLayers: [
            {
                type: 'dynamic',
                url: 'https://geospatial.alberta.ca/titan/rest/services/osip/osip_oilsands_business_data/MapServer/',
                title: 'Oilsands Business Data',
                layerOrder: 1,
                options: {
                    id: 'oilsandsBusinessData',
                    opacity: 1,
                    visible: false,
                    multiLayers: [
                        {
                            id: 'cutline',
                            title: 'Cutlines',
                            visibleLayersIds: [0],
                            zoomToLevel: 13,
                            legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/cutlines.png', label: 'Cutline' }]
                        }
                    ]
                }
            },
            {
                type: 'dynamic',
                url: 'https://geospatial.alberta.ca/titan/rest/services/utility/access/MapServer/',
                title: 'Access',
                layerOrder: 1,
                options: {
                    id: 'access',
                    opacity: 1,
                    visible: false,
                    multiLayers: [{
                            id: 'railways',
                            title: 'Railways',
                            visibleLayersIds: [1, 3, 29],
                            zoomToLevel: 13,
                            legendIcons: [
                                { iconGroupId: 'railways', iconGroupName: 'Railways' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/single_line.png', label: 'Single Line' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/double_line.png', label: 'Double Line' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/multiple_line.png', label: 'Multiple Line' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/spur_line.png', label: 'Spur Line' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/abandoned.png', label: 'Abandoned' },
                                { label: 'Railway Points' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/railway_bridge.png', label: 'Bridge' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/station.png', label: 'Station' }
                            ]
                        },
                        {
                            id: 'roads',
                            title: 'Roads',
                            visibleLayersIds: [10, 11, 12, 13, 14, 15, 20, 21, 22, 23, 26, 28],
                            zoomToLevel: 8,
                            legendIcons: [
                                { iconGroupId: 'roads', iconGroupName: 'Roads' },
                                { label: 'Paved Roads' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/primary_divided.png', label: 'Primary Divided' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/primary_undivided_4L.png', label: 'Primary Undivided 4L' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/primary_undivided_2L.png', label: 'Primary Undivided 2L' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/primary_undivided_1L.png', label: 'Primary Undivided 1L' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/interchange_ramp.png', label: 'Interchange Ramp' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/secondary_divided.png', label: 'Secondary Divided' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/secondary_undivided_4L.png', label: 'Secondary Undivided 4L' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/secondary_undivided_2L.png', label: 'Secondary Undivided 2L' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/secondary_undivided_1L.png', label: 'Secondary Undivided 1L' },
                                { label: 'Gravel Roads' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/gravel_primary_undivided_2L.png', label: 'Primary Undivided 2L' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/gravel_primary_undivided_1L.png', label: 'Primary Undivided 1L' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/gravel_secondary_undivided_2L.png', label: 'Secondary Undivided 2L' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/gravel_secondary_undivided_1L.png', label: 'Secondary Undivided 1L' },
                                { label: 'Other Roads' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/unimproved.png', label: 'Unimproved' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/unclassified.png', label: 'Unclassified' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/truck_trail.png', label: 'Truck Trail' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/winter.png', label: 'Winter' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/fordwinter_crossing.png', label: 'Ford Winter Crossing' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/ferry_route.png', label: 'Ferry Route' },
                                { label: 'Road Points' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/bridge.png', label: 'Bridge' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/overpass_underpass.png', label: 'Overpass/Underpass' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/ford_winter_crossing.png', label: 'Ford/Winter Crossing' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/port_of_entry.png', label: 'Port of Entry' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/miscellaneous_control_device.png', label: 'Miscellaneous Control Device' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/tunnel.png', label: 'Tunnel' },
                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/ferry_crossing.png', label: 'Ferry Crossing' }
                            ]
                        }
                    ]
                }
            },
            {
                type: 'dynamic',
                url: 'https://geospatial.alberta.ca/titan/rest/services/utility/access_utility/MapServer/',
                title: 'Powerlines',
                layerOrder: 1,
                options: {
                    id: 'powerlines',
                    opacity: 1,
                    visibleLayers: [15],
                    visible: false
                },
                zoomToLevel: 9,
                legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/powerline.png', label: 'Powerline' }]
            },
            {
                subGroups: [{
                    id: 'oilSandsProjects',
                    title: 'Oil Sands',
                    parentGroupId: 'IndustrialImpacts',
                    focusGroupId: 'disturbanceReclamationOverTimeSubGroup',
                    operationalLayers: [
                        {
                            subGroups: [
                                {
                                    id: 'administrativeSubGroup',
                                    title: 'Administrative Boundaries',
                                    parentGroupId: 'oilSandsProjects',
                                    focusElementId: 'oilSandsMinableArea',
                                    operationalLayers: [
                                        {
                                            type: 'dynamic',
                                            url: 'https://geospatial.alberta.ca/titan/rest/services/osip/osip_oilsands_business_data/MapServer/',
                                            title: 'Deposit Area',
                                            layerOrder: 1,
                                            options: {
                                                id: 'oilSandsDepositArea',
                                                opacity: 0.5,
                                                visibleLayers: [1],
                                                visible: false
                                            },
                                            legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/oilsands_deposit_area.png', label: 'Oil Sands Deposit Area', glossaryAnchorTage: 'Oil_Sands_Deposit_Area' }]
                                        },
                                        {
                                            type: 'wms',
                                            url: 'http://gis.energy.gov.ab.ca/ArcGIS/services/wms/SREM_SMA/MapServer/WMSServer/',
                                            title: 'Minable Area',
                                            layerOrder: 1,
                                            wmsName: '0',
                                            extent: {
                                                xmin: -112.0122269999999958,
                                                ymin: 56.7426740000000009,
                                                xmax: -110.4594120000000004,
                                                ymax: 57.9109520000000018,
                                                wkid: 4326
                                            },
                                            options: {
                                                id: 'oilSandsMinableArea',
                                                opacity: 1,
                                                visibleLayers: [0],
                                                visible: false,
                                                resourceInfo: null
                                            },
                                            legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/oilsands_minable_area.png', label: 'Oil Sands Minable Area', glossaryAnchorTage: 'Mineable_Area' }]
                                        },
                                        {
                                            type: 'dynamic',
                                            url: siteConfig.osipMapServer,
                                            title: 'Leased Land',
                                            layerOrder: 1,
                                            options: {
                                                id: 'oilSandsLeasedLand',
                                                opacity: 0.7,
                                                visibleLayers: [8],
                                                visible: false
                                            },
                                            legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/oilsands_leased_area.png', label: 'Oil Sands Leased Land' }]
                                        }
                                    ]
                                },
                                {
                                    id: 'projectsSubGroup',
                                    title: 'Projects',
                                    parentGroupId: 'oilSandsProjects',
                                    focusElementId: 'projectOilSandsInactive',
                                    operationalLayers: [
                                        {
                                            type: 'feature',
                                            url: siteConfig.osipMapServer + '273',
                                            title: 'Project Boundaries',
                                            layerOrder: 1,
                                            options: {
                                                id: 'projectBoundaries',
                                                outFields: ['OSP_NO'],
                                                opacity: 1,
                                                visible: false
                                            },
                                            layerDefinition: {
                                                geometryType: "esriGeometryPolygon",
                                                fields: [{
                                                    name: "OSP_NO",
                                                    type: "esriFieldTypeSmallInteger",
                                                    alias: "Project Number"
                                                }]
                                            },
                                            customModule: new ProjectBoundariesContent(),
                                            hideLayersWithPrefix: 'landHistory',
                                            legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/operating_project_boundaries-graphic.png', label: 'Operating Project Boundaries' },
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/approved_project_boundaries-graphic.png', label: 'Approved Project Boundaries' },
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/other_project_boundaries-graphic.png', label: 'Other Project Boundaries' }]
                                        },
                                        {
                                            type: 'feature',
                                            url: siteConfig.osipMapServer + '252',
                                            title: 'Operating Mines',
                                            layerOrder: 4,
                                            options: {
                                                id: 'projectOilSandsMine',
                                                outFields: ['OBJECTID', 'OSP_NO', 'Operator_Name', 'OS_Area', 'Year', 'Project_Name', 'Industry_Type', 'Project_Status'],
                                                opacity: 1,
                                                visible: false
                                            },
                                            customModule: new OilSandsContent({ dataUrl: siteConfig.dataUrl, libraryUrl: siteConfig.libraryUrl, projectStatusGroup: ['OilSandsMine-Active', 'OilSandsMine-IU-Active'] }),
                                            showGraphicTooltip: true,
                                            hideLayersWithPrefix: 'landHistory',
                                            legendIcons: [
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Integrated_Upgrader.png', label: 'On-site Upgrader Projects' },
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine.png', label: 'Operating Oil Sands Mines', glossaryAnchorTage: 'Oil_Sands' }
                                            ]
                                        },
                                        {
                                            type: 'feature',
                                            url: siteConfig.osipMapServer + '252',
                                            title: 'Operating In Situ Facilities',
                                            layerOrder: 4,
                                            options: {
                                                id: 'projectOilSandsInSitu',
                                                outFields: ['OBJECTID', 'OSP_NO', 'Operator_Name', 'OS_Area', 'Year', 'Project_Name', 'Industry_Type', 'Project_Status'],
                                                opacity: 1,
                                                visible: false
                                            },
                                            customModule: new OilSandsContent({
                                                dataUrl: siteConfig.dataUrl,
                                                libraryUrl: siteConfig.libraryUrl,
                                                projectStatusGroup: ['InSitu-Active', 'InSitu-IU-Active'],
                                                landTotalHectares: landParameters
                                            }),
                                            showGraphicTooltip: true,
                                            hideLayersWithPrefix: 'landHistory',
                                            legendIcons: [
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu.png', label: 'Operating In Situ Facilities', glossaryAnchorTage: 'In_situ_Facility' }
                                            ]
                                        },
                                        {
                                            type: 'feature',
                                            url: siteConfig.osipMapServer + '252',
                                            title: 'Operating Upgraders',
                                            layerOrder: 4,
                                            options: {
                                                id: 'projectOilSandsUpgraders',
                                                outFields: ['OBJECTID', 'OSP_NO', 'Operator_Name', 'OS_Area', 'Year', 'Project_Name', 'Industry_Type', 'Project_Status'],
                                                opacity: 1,
                                                visible: false
                                            },
                                            customModule: new OilSandsContent({ dataUrl: siteConfig.dataUrl, libraryUrl: siteConfig.libraryUrl, projectStatusGroup: ['Upgrader-Active'] }),
                                            showGraphicTooltip: true,
                                            hideLayersWithPrefix: 'landHistory',
                                            legendIcons: [
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader.png', label: 'Operating Stand Alone Upgraders', glossaryAnchorTage: 'Upgrader' }
                                            ]
                                        },
                                        {
                                            type: 'feature',
                                            url: siteConfig.osipMapServer + '252',
                                            title: 'Approved Mines',
                                            layerOrder: 4,
                                            options: {
                                                id: 'projectOilSandsMineApprove',
                                                outFields: ['OBJECTID', 'OSP_NO', 'Operator_Name', 'OS_Area', 'Year', 'Project_Name', 'Industry_Type', 'Project_Status'],
                                                opacity: 1,
                                                visible: false
                                            },
                                            customModule: new OilSandsContent({ dataUrl: siteConfig.dataUrl, libraryUrl: siteConfig.libraryUrl, projectStatusGroup: ['OilSandsMine-Approved', 'OilSandsMine-IU-Approved'] }),
                                            showGraphicTooltip: true,
                                            hideLayersWithPrefix: 'landHistory',
                                            legendIcons: [
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Grey.png', label: 'Approved Oil Sands Mines', glossaryAnchorTage: 'Approved_Mine' }
                                            ]
                                        },
                                        {
                                            type: 'feature',
                                            url: siteConfig.osipMapServer + '252',
                                            title: 'Approved In Situ Facilities',
                                            layerOrder: 4,
                                            options: {
                                                id: 'projectOilSandsInSituApprove',
                                                outFields: ['OBJECTID', 'OSP_NO', 'Operator_Name', 'OS_Area', 'Year', 'Project_Name', 'Industry_Type', 'Project_Status'],
                                                opacity: 1,
                                                visible: false
                                            },
                                            customModule: new OilSandsContent(
                                                {
                                                    dataUrl: siteConfig.dataUrl,
                                                    libraryUrl: siteConfig.libraryUrl,
                                                    projectStatusGroup: ['InSitu-Approved', 'InSitu-IU-Approved'],
                                                    landTotalHectares: landParameters
                                                }),
                                            showGraphicTooltip: true,
                                            hideLayersWithPrefix: 'landHistory',
                                            legendIcons: [
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Grey.png', label: 'Approved In Situ Facilities', glossaryAnchorTage: 'Approved_In_situ_Facility' }
                                            ]
                                        },
                                        {
                                            type: 'feature',
                                            url: siteConfig.osipMapServer + '252',
                                            title: 'Approved Upgraders',
                                            layerOrder: 4,
                                            options: {
                                                id: 'projectOilSandsUpgradersApprove',
                                                outFields: ['OBJECTID', 'OSP_NO', 'Operator_Name', 'OS_Area', 'Year', 'Project_Name', 'Industry_Type', 'Project_Status'],
                                                opacity: 1,
                                                visible: false
                                            },
                                            customModule: new OilSandsContent({ dataUrl: siteConfig.dataUrl, libraryUrl: siteConfig.libraryUrl, projectStatusGroup: ['Upgrader-Approved'] }),
                                            showGraphicTooltip: true,
                                            hideLayersWithPrefix: 'landHistory',
                                            legendIcons: [
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Grey.png', label: 'Approved Stand Alone Upgraders' }
                                            ]
                                        },
                                        {
                                            type: 'feature',
                                            url: siteConfig.osipMapServer + '252',
                                            title: 'Proposed Projects',
                                            layerOrder: 4,
                                            options: {
                                                id: 'projectOilSandsProposed',
                                                outFields: ['OBJECTID', 'OSP_NO', 'Operator_Name', 'OS_Area', 'Year', 'Project_Name', 'Industry_Type', 'Project_Status'],
                                                opacity: 1,
                                                visible: false
                                            },
                                            customModule: new OilSandsContent({
                                                dataUrl: siteConfig.dataUrl,
                                                libraryUrl: siteConfig.libraryUrl,
                                                projectStatusGroup: ['InSitu-Proposed', 'InSitu-IU-Proposed', 'OilSandsMine-Proposed', 'OilSandsMine-IU-Proposed', 'Upgrader-Proposed', 'Upgrader-IU-Proposed'],
                                                landTotalHectares: landParameters
                                            }),
                                            showGraphicTooltip: true,
                                            hideLayersWithPrefix: 'landHistory',
                                            legendIcons: [
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Orange.png', label: 'Proposed Oil Sands Mines', glossaryAnchorTage: 'Proposed_OilSands_Mines' },
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Orange.png', label: 'Proposed In Situ Facilities', glossaryAnchorTage: 'Proposed_InSitu_Facilities' },
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Orange.png', label: 'Proposed Stand Alone Upgraders', glossaryAnchorTage: 'Proposed_StandAlone_Upgrader' }
                                            ]
                                        },
                                        {
                                            type: 'feature',
                                            url: siteConfig.osipMapServer + '252',
                                            title: 'Inactive Projects',
                                            layerOrder: 4,
                                            options: {
                                                id: 'projectOilSandsInactive',
                                                outFields: ['OBJECTID', 'OSP_NO', 'Operator_Name', 'OS_Area', 'Year', 'Project_Name', 'Industry_Type', 'Project_Status'],
                                                opacity: 1,
                                                visible: false
                                            },
                                            customModule: new OilSandsContent({
                                                dataUrl: siteConfig.dataUrl,
                                                libraryUrl: siteConfig.libraryUrl,
                                                projectStatusGroup: ['InSitu-Inactive', 'InSitu-IU-Inactive', 'OilSandsMine-Inactive', 'OilSandsMine-IU-Inactive', 'Upgrader-Inactive', 'Upgrader-IU-Inactive'],
                                                landTotalHectares: landParameters

                                            }),
                                            showGraphicTooltip: true,
                                            hideLayersWithPrefix: 'landHistory',
                                            legendIcons: [
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Red.png', label: 'Inactive Oil Sands Mines', glossaryAnchorTage: 'Inactive_OilSands_Mines' },
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Red.png', label: 'Inactive In Situ Facilities', glossaryAnchorTage: 'Inactive_OilSands_Mines' },
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Red.png', label: 'Inactive Stand Alone Upgraders', glossaryAnchorTage: 'Inactive_StandAlone_Upgrader' }
                                            ],
                                            relatedLinks: [
                                                {
                                                    title: "Oil Sands Water Use",
                                                    url: siteConfig.dataUrl + "/waterLB/GetWaterUse?csspage=White.css",
                                                    type: 'iframe',
                                                    modalCssClass: 'modalContentMediumCharts'
                                                }
                                            ]
                                        }
                                    ]
                                },
                                {
                                    id: 'tailingsSubGroup',
                                    title: 'Tailings Ponds',
                                    parentGroupId: 'oilSandsProjects',
                                    focusElementId: 'tailingsPond',
                                    operationalLayers: [
                                        {
                                            type: 'feature',
                                            url: siteConfig.osipMapServer + '269', // 2020
                                            title: 'Tailings Ponds',
                                            layerOrder: 2,
                                            options: {
                                                id: 'tailingsPond',
                                                outFields: ['POND_NAME', 'LAND_AREA', 'HECTARES', 'TAILINGS_STRUCTURE', 'YEAR', 'PROJECT_NAME', 'OPERATOR_NAME'],
                                                visible: false
                                            },
                                            layerDefinition: {
                                                geometryType: "esriGeometryPolygon",
                                                fields: [{
                                                    name: "TAILINGS_STRUCTURE",
                                                    type: "esriFieldTypeString",
                                                    alias: "Tailings Structure"
                                                }, {
                                                    name: "POND_NAME",
                                                    type: "esriFieldTypeString",
                                                    alias: "Pond Name"
                                                }, {
                                                    name: "YEAR",
                                                    type: "esriFieldTypeSmallInteger",
                                                    alias: "YEAR"
                                                }, {
                                                    name: "LAND_AREA",
                                                    type: "esriFieldTypeDouble",
                                                    alias: "Area"
                                                }, {
                                                    name: "HECTARES",
                                                    type: "esriFieldTypeDouble",
                                                    alias: "HECTARES"
                                                }, {
                                                    name: "PROJECT_NAME",
                                                    type: "esriFieldTypeString",
                                                    alias: "Project Name"
                                                }, {
                                                    name: "OPERATOR_NAME",
                                                    type: "esriFieldTypeString",
                                                    alias: "Operator Name"
                                                }]
                                            },
                                            //We probably need to add some comments to this config file describing the different options such as relatedLink types and which properties are optional
                                            relatedLinks: [
                                                {
                                                    title: "Total Tailings Pond Surface Area and Volume",
                                                    url: siteConfig.libraryUrl + "/TailingsPond/TailingsPondAreas",
                                                    type: 'iframe',
                                                    modalCssClass: 'modalContentMediumCharts'
                                                }
                                            ],
                                            hideLayersWithPrefix: 'landHistory',
                                            customModule: new TailingsPondContent(),
                                            legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/dedicated_drying_area.png', label: 'Dedicated Drying Area', glossaryAnchorTage: 'DedicatedDry_Tailings' },
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/tailings_ponds.png', label: 'Dry Tailings', glossaryAnchorTage: 'Dry_Tailings' },
                                                { iconName: siteConfig.rootUrl + 'scripts/app/content/images/industrailImpacts/tailings_ponds-wet.png', label: 'Wet Tailings', glossaryAnchorTage: 'Wet_Tailings' }
                                            ]
                                        }
                                    ]
                                },
                                {
                                    id: 'disturbanceReclamationSubGroup',
                                    title: '2020 Disturbance and Reclamation',
                                    parentGroupId: 'oilSandsProjects',
                                    focusElementId: 'currentLandDisturbedMining',
                                    operationalLayers: [
                                        {
                                            type: 'dynamic',
                                            url: siteConfig.osipMapServer,
                                            title: 'Land Data',
                                            layerOrder: 1,
                                            options: {
                                                id: 'landDataCurrent',
                                                opacity: 1,
                                                visible: false,
                                                groupName: 'currentLand',
                                                multiLayers: [
                                                    {
                                                        id: 'currentLandClearedInSitu',
                                                        title: 'Land Cleared (In Situ)',
                                                        visibleLayersIds: [254, 255],
                                                        hideLayersWithPrefix: 'landHistory',
                                                        showLayersWithPrefix: 'projectOilSandsInSitu',
                                                        zoomToLevel: 9,
                                                        legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_cleared.png', label: 'Land Cleared (In Situ)', glossaryAnchorTage: 'Cleared' }]
                                                    },
                                                    {
                                                        id: 'currentLandClearedMining',
                                                        title: 'Land Cleared (Mines)',
                                                        visibleLayersIds: [256],
                                                        hideLayersWithPrefix: 'landHistory',
                                                        showLayersWithPrefix: 'projectOilSandsMine',
                                                        legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_cleared.png', label: 'Land Cleared (Mining)', glossaryAnchorTage: 'Cleared' }]
                                                    },
                                                    {
                                                        id: 'currentLandDisturbedInSitu',
                                                        title: 'Land Disturbed (In Situ)',
                                                        visibleLayersIds: [265, 266, 267, 268, 271, 272],
                                                        hideLayersWithPrefix: 'landHistory',
                                                        showLayersWithPrefix: 'projectOilSandsInSitu',
                                                        legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_plant_sites.png', label: 'In Situ Plant Sites', glossaryAnchorTage: 'Disturbed_Land' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_well_sites.png', label: 'In Situ Well Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_disturbed.png', label: 'In Situ Disturbed' }]
                                                    },
                                                    {
                                                        id: 'currentLandDisturbedMining',
                                                        title: 'Land Disturbed (Mines)',
                                                        visibleLayersIds: [270],
                                                        hideLayersWithPrefix: 'landHistory',
                                                        showLayersWithPrefix: 'projectOilSandsMine',
                                                        legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_disturbed.png', label: 'Land Disturbed (Mining)', glossaryAnchorTage: 'Disturbed_Land' }]
                                                    },
                                                    {
                                                        id: 'currentLandTemporarilyReclaimed',
                                                        title: 'Temporarily Reclaimed (Mines)',
                                                        visibleLayersIds: [261],
                                                        hideLayersWithPrefix: 'landHistory',
                                                        showLayersWithPrefix: 'projectOilSandsMine',
                                                        legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_temporarily_reclaimed_mining.png', label: 'Temporarily Reclaimed (Mining)', glossaryAnchorTage: 'Temporary_Reclamation' }]
                                                    },
                                                    {
                                                        id: 'currentLandPermanentlyReclaimed',
                                                        title: 'Permanently Reclaimed (Mines)',
                                                        hideLayersWithPrefix: 'landHistory',
                                                        showLayersWithPrefix: 'projectOilSandsMine',
                                                        visibleLayersIds: [260],
                                                        legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_permanently_reclaimed_mining.png', label: 'Permanently Reclaimed (Mining)', glossaryAnchorTage: 'Permanent_Reclamation' }]
                                                    }, {
                                                        id: 'currentLandCertifiedReclaimed',
                                                        title: 'Certified Reclaimed (Mines)',
                                                        visibleLayersIds: [262],
                                                        hideLayersWithPrefix: 'landHistory',
                                                        showLayersWithPrefix: 'projectOilSandsMine',
                                                        legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_certified_reclaimed_mining.png', label: 'Certified Reclaimed (Mining)', glossaryAnchorTage: 'Certified_Reclaimed' }]
                                                    },
                                                    {
                                                        id: 'currentLandOilSandsInSituReclaimed',
                                                        title: 'Reclaimed (In Situ)',
                                                        visibleLayersIds: [258, 259],
                                                        hideLayersWithPrefix: 'landHistory',
                                                        showLayersWithPrefix: 'projectOilSandsInSitu',
                                                        legendIcons: [{ iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_reclaimed_insitu.png', label: 'Reclaimed (In Situ)', glossaryAnchorTage: 'Reclaimed_Land' }]
                                                    }]
                                            }
                                        }
                                    ]
                                },
                                {
                                    id: 'disturbanceReclamationOverTimeSubGroup',
                                    title: 'Disturbance and Reclamation Over Time',
                                    parentGroupId: 'oilSandsProjects',
                                    focusGroupId: 'historical-layer-container',
                                    operationalLayers: [
                                        {
                                            type: 'dynamic',
                                            url: siteConfig.osipMapServer,
                                            title: 'Historical Land Data',
                                            layerOrder: 1,
                                            options: {
                                                id: 'landDataHistorical',
                                                opacity: 1,
                                                visible: false,
                                                groupName: 'historicalLand',
                                                multiLayers: [
                                                    {
                                                        id: 'landHistory1980',
                                                        title: '1980',
                                                        visibleLayersIds: [41, 42, 44, 45, 46, 47, 50, 51, 52, 53, 54],
                                                        hideLayersWithPrefix: 'currentLand,project,tailings',
                                                        subLayerToInclude: 'land1980ProjectPoints',
                                                        historicalLayer: true,
                                                        legendIcons: [
                                                            { iconGroupId: '1980', iconGroupName: '1980' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/all_project_boundaries_historical.png', label: 'Operating Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/approved_project_boundaries_light.png', label: 'Approved Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/tailings_ponds.png', label: 'Tailings Ponds' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_cleared.png', label: 'Land Cleared (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_cleared.png', label: 'Land Cleared (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_plant_sites.png', label: 'In Situ Plant Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_well_sites.png', label: 'In Situ Well Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_disturbed.png', label: 'Land Disturbed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_temporarily_reclaimed_mining.png', label: 'Land Temporarily Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_permanently_reclaimed_mining.png', label: 'Land Permanently Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_certified_reclaimed_mining.png', label: 'Land Certified Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_reclaimed_insitu.png', label: 'Land Reclaimed (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Integrated_Upgrader.png', label: 'On-site Upgrader Projects' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine.png', label: 'Operating Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu.png', label: 'Operating In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader.png', label: 'Operating Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Grey.png', label: 'Approved Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Grey.png', label: 'Approved In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Grey.png', label: 'Approved Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Orange.png', label: 'Proposed Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Orange.png', label: 'Proposed In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Orange.png', label: 'Proposed Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Red.png', label: 'Inactive Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Red.png', label: 'Inactive In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Red.png', label: 'Inactive Stand Alone Upgraders' }
                                                        ]
                                                    },
                                                    {
                                                        id: 'landHistory1998',
                                                        title: '1998',
                                                        visibleLayersIds: [58, 59, 61, 62, 63, 64, 67, 68, 69, 70, 71],
                                                        hideLayersWithPrefix: 'currentLand,project,tailings',
                                                        subLayerToInclude: 'land1998ProjectPoints',
                                                        historicalLayer: true,
                                                        legendIcons: [
                                                            { iconGroupId: '1998', iconGroupName: '1998' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/all_project_boundaries_historical.png', label: 'Operating Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/approved_project_boundaries_light.png', label: 'Approved Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/tailings_ponds.png', label: 'Tailings Ponds' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_cleared.png', label: 'Land Cleared (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_cleared.png', label: 'Land Cleared (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_plant_sites.png', label: 'In Situ Plant Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_well_sites.png', label: 'In Situ Well Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_disturbed.png', label: 'Land Disturbed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_temporarily_reclaimed_mining.png', label: 'Land Temporarily Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_permanently_reclaimed_mining.png', label: 'Land Permanently Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_certified_reclaimed_mining.png', label: 'Land Certified Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_reclaimed_insitu.png', label: 'Land Reclaimed (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Integrated_Upgrader.png', label: 'On-site Upgrader Projects' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine.png', label: 'Operating Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu.png', label: 'Operating In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader.png', label: 'Operating Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Grey.png', label: 'Approved Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Grey.png', label: 'Approved In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Grey.png', label: 'Approved Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Orange.png', label: 'Proposed Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Orange.png', label: 'Proposed In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Orange.png', label: 'Proposed Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Red.png', label: 'Inactive Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Red.png', label: 'Inactive In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Red.png', label: 'Inactive Stand Alone Upgraders' }
                                                        ]
                                                    },
                                                    {
                                                        id: 'landHistory2007',
                                                        title: '2007',
                                                        visibleLayersIds: [75, 76, 78, 79, 80, 81, 84, 85, 86, 87, 88],
                                                        hideLayersWithPrefix: 'currentLand,project,tailings',
                                                        subLayerToInclude: 'land2007ProjectPoints',
                                                        historicalLayer: true,
                                                        legendIcons: [
                                                            { iconGroupId: '2007', iconGroupName: '2007' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/all_project_boundaries_historical.png', label: 'Operating Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/approved_project_boundaries_light.png', label: 'Approved Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/tailings_ponds.png', label: 'Tailings Ponds' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_cleared.png', label: 'Land Cleared (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_cleared.png', label: 'Land Cleared (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_plant_sites.png', label: 'In Situ Plant Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_well_sites.png', label: 'In Situ Well Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_disturbed.png', label: 'Land Disturbed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_temporarily_reclaimed_mining.png', label: 'Land Temporarily Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_permanently_reclaimed_mining.png', label: 'Land Permanently Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_certified_reclaimed_mining.png', label: 'Land Certified Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_reclaimed_insitu.png', label: 'Land Reclaimed (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Integrated_Upgrader.png', label: 'On-site Upgrader Projects' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine.png', label: 'Operating Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu.png', label: 'Operating In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader.png', label: 'Operating Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Grey.png', label: 'Approved Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Grey.png', label: 'Approved In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Grey.png', label: 'Approved Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Orange.png', label: 'Proposed Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Orange.png', label: 'Proposed In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Orange.png', label: 'Proposed Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Red.png', label: 'Inactive Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Red.png', label: 'Inactive In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Red.png', label: 'Inactive Stand Alone Upgraders' }
                                                        ]
                                                    },
                                                    {
                                                        id: 'landHistory2010',
                                                        title: '2010',
                                                        visibleLayersIds: [92, 93, 95, 96, 97, 98, 101, 102, 103, 104, 105],
                                                        hideLayersWithPrefix: 'currentLand,project,tailings',
                                                        subLayerToInclude: 'land2010ProjectPoints',
                                                        historicalLayer: true,
                                                        legendIcons: [
                                                            { iconGroupId: '2010', iconGroupName: '2010' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/all_project_boundaries_historical.png', label: 'Operating Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/approved_project_boundaries_light.png', label: 'Approved Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/tailings_ponds.png', label: 'Tailings Ponds' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_cleared.png', label: 'Land Cleared (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_cleared.png', label: 'Land Cleared (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_plant_sites.png', label: 'In Situ Plant Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_well_sites.png', label: 'In Situ Well Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_disturbed.png', label: 'Land Disturbed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_temporarily_reclaimed_mining.png', label: 'Land Temporarily Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_permanently_reclaimed_mining.png', label: 'Land Permanently Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_certified_reclaimed_mining.png', label: 'Land Certified Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_reclaimed_insitu.png', label: 'Land Reclaimed (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Integrated_Upgrader.png', label: 'On-site Upgrader Projects' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine.png', label: 'Operating Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu.png', label: 'Operating In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader.png', label: 'Operating Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Grey.png', label: 'Approved Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Grey.png', label: 'Approved In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Grey.png', label: 'Approved Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Orange.png', label: 'Proposed Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Orange.png', label: 'Proposed In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Orange.png', label: 'Proposed Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Red.png', label: 'Inactive Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Red.png', label: 'Inactive In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Red.png', label: 'Inactive Stand Alone Upgraders' }
                                                        ]
                                                    },
                                                    {
                                                        id: 'landHistory2011',
                                                        title: '2011',
                                                        visibleLayersIds: [109, 110, 112, 113, 114, 115, 118, 119, 120, 121, 122],
                                                        hideLayersWithPrefix: 'currentLand,project,tailings',
                                                        subLayerToInclude: 'land2011ProjectPoints',
                                                        historicalLayer: true,
                                                        legendIcons: [
                                                            { iconGroupId: '2011', iconGroupName: '2011' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/all_project_boundaries_historical.png', label: 'Operating Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/approved_project_boundaries_light.png', label: 'Approved Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/tailings_ponds.png', label: 'Tailings Ponds' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_cleared.png', label: 'Land Cleared (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_cleared.png', label: 'Land Cleared (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_plant_sites.png', label: 'In Situ Plant Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_well_sites.png', label: 'In Situ Well Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_disturbed.png', label: 'Land Disturbed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_temporarily_reclaimed_mining.png', label: 'Land Temporarily Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_permanently_reclaimed_mining.png', label: 'Land Permanently Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_certified_reclaimed_mining.png', label: 'Land Certified Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_reclaimed_insitu.png', label: 'Land Reclaimed (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Integrated_Upgrader.png', label: 'On-site Upgrader Projects' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine.png', label: 'Operating Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu.png', label: 'Operating In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader.png', label: 'Operating Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Grey.png', label: 'Approved Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Grey.png', label: 'Approved In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Grey.png', label: 'Approved Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Orange.png', label: 'Proposed Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Orange.png', label: 'Proposed In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Orange.png', label: 'Proposed Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Red.png', label: 'Inactive Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Red.png', label: 'Inactive In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Red.png', label: 'Inactive Stand Alone Upgraders' }
                                                        ]
                                                    },
                                                    {
                                                        id: 'landHistory2012',
                                                        title: '2012',
                                                        visibleLayersIds: [126, 127, 129, 130, 131, 132, 135, 136, 137, 138, 139],
                                                        hideLayersWithPrefix: 'currentLand,project,tailings',
                                                        subLayerToInclude: 'land2012ProjectPoints',
                                                        historicalLayer: true,
                                                        legendIcons: [
                                                            { iconGroupId: '2012', iconGroupName: '2012' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/all_project_boundaries_historical.png', label: 'Operating Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/approved_project_boundaries_light.png', label: 'Approved Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/tailings_ponds.png', label: 'Tailings Ponds' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_cleared.png', label: 'Land Cleared (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_cleared.png', label: 'Land Cleared (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_plant_sites.png', label: 'In Situ Plant Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_well_sites.png', label: 'In Situ Well Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_disturbed.png', label: 'Land Disturbed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_temporarily_reclaimed_mining.png', label: 'Land Temporarily Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_permanently_reclaimed_mining.png', label: 'Land Permanently Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_certified_reclaimed_mining.png', label: 'Land Certified Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_reclaimed_insitu.png', label: 'Land Reclaimed (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Integrated_Upgrader.png', label: 'On-site Upgrader Projects' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine.png', label: 'Operating Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu.png', label: 'Operating In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader.png', label: 'Operating Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Grey.png', label: 'Approved Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Grey.png', label: 'Approved In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Grey.png', label: 'Approved Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Orange.png', label: 'Proposed Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Orange.png', label: 'Proposed In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Orange.png', label: 'Proposed Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Red.png', label: 'Inactive Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Red.png', label: 'Inactive In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Red.png', label: 'Inactive Stand Alone Upgraders' }
                                                        ]
                                                    },
                                                    {
                                                        id: 'landHistory2013',
                                                        title: '2013',
                                                        visibleLayersIds: [143, 144, 145, 147, 148, 149, 150, 151, 154, 155, 156, 157, 158, 159, 160],
                                                        hideLayersWithPrefix: 'currentLand,project,tailings',
                                                        subLayerToInclude: 'land2013ProjectPoints',
                                                        historicalLayer: true,
                                                        legendIcons: [
                                                            { iconGroupId: '2013', iconGroupName: '2013' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/all_project_boundaries_historical.png', label: 'Operating Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/approved_project_boundaries_light.png', label: 'Approved Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/tailings_ponds.png', label: 'Tailings Ponds' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_cleared.png', label: 'Land Cleared (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_cleared.png', label: 'Land Cleared (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_plant_sites.png', label: 'In Situ Plant Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_well_sites.png', label: 'In Situ Well Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_disturbed.png', label: 'Land Disturbed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_temporarily_reclaimed_mining.png', label: 'Land Temporarily Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_permanently_reclaimed_mining.png', label: 'Land Permanently Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_certified_reclaimed_mining.png', label: 'Land Certified Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_reclaimed_insitu.png', label: 'Land Reclaimed (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Integrated_Upgrader.png', label: 'On-site Upgrader Projects' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine.png', label: 'Operating Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu.png', label: 'Operating In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader.png', label: 'Operating Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Grey.png', label: 'Approved Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Grey.png', label: 'Approved In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Grey.png', label: 'Approved Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Orange.png', label: 'Proposed Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Orange.png', label: 'Proposed In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Orange.png', label: 'Proposed Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Red.png', label: 'Inactive Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Red.png', label: 'Inactive In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Red.png', label: 'Inactive Stand Alone Upgraders' }
                                                        ]
                                                    },
                                                    {
                                                        id: 'landHistory2014',
                                                        title: '2014',
                                                        visibleLayersIds: [164, 165, 166, 168, 169, 170, 171, 172, 175, 176, 177, 178, 179, 180, 181],
                                                        hideLayersWithPrefix: 'currentLand,project,tailings',
                                                        subLayerToInclude: 'land2014ProjectPoints',
                                                        historicalLayer: true,
                                                        legendIcons: [
                                                            { iconGroupId: '2014', iconGroupName: '2014' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/all_project_boundaries_historical.png', label: 'Operating Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/approved_project_boundaries_light.png', label: 'Approved Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/tailings_ponds.png', label: 'Tailings Ponds' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_cleared.png', label: 'Land Cleared (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_cleared.png', label: 'Land Cleared (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_plant_sites.png', label: 'In Situ Plant Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_well_sites.png', label: 'In Situ Well Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_disturbed.png', label: 'Land Disturbed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_temporarily_reclaimed_mining.png', label: 'Land Temporarily Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_permanently_reclaimed_mining.png', label: 'Land Permanently Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_certified_reclaimed_mining.png', label: 'Land Certified Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_reclaimed_insitu.png', label: 'Land Reclaimed (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Integrated_Upgrader.png', label: 'On-site Upgrader Projects' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine.png', label: 'Operating Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu.png', label: 'Operating In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader.png', label: 'Operating Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Grey.png', label: 'Approved Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Grey.png', label: 'Approved In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Grey.png', label: 'Approved Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Orange.png', label: 'Proposed Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Orange.png', label: 'Proposed In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Orange.png', label: 'Proposed Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Red.png', label: 'Inactive Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Red.png', label: 'Inactive In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Red.png', label: 'Inactive Stand Alone Upgraders' }
                                                        ]
                                                    },
                                                    {
                                                        id: 'landHistory2015',
                                                        title: '2015',
                                                        visibleLayersIds: [185, 186, 187, 189, 190, 191, 192, 193, 196, 197, 198, 199, 200, 201, 202, 203, 204],
                                                        hideLayersWithPrefix: 'currentLand,project,tailings',
                                                        subLayerToInclude: 'land2015ProjectPoints',
                                                        historicalLayer: true,
                                                        legendIcons: [
                                                            { iconGroupId: '2015', iconGroupName: '2015' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/all_project_boundaries_historical.png', label: 'Operating Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/approved_project_boundaries_light.png', label: 'Approved Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/tailings_ponds.png', label: 'Tailings Ponds' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_cleared.png', label: 'Land Cleared (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_cleared.png', label: 'Land Cleared (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_plant_sites.png', label: 'In Situ Plant Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_well_sites.png', label: 'In Situ Well Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_disturbed.png', label: 'Land Disturbed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_temporarily_reclaimed_mining.png', label: 'Land Temporarily Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_permanently_reclaimed_mining.png', label: 'Land Permanently Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_certified_reclaimed_mining.png', label: 'Land Certified Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_reclaimed_insitu.png', label: 'Land Reclaimed (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Integrated_Upgrader.png', label: 'On-site Upgrader Projects' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine.png', label: 'Operating Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu.png', label: 'Operating In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader.png', label: 'Operating Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Grey.png', label: 'Approved Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Grey.png', label: 'Approved In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Grey.png', label: 'Approved Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Orange.png', label: 'Proposed Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Orange.png', label: 'Proposed In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Orange.png', label: 'Proposed Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Red.png', label: 'Inactive Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Red.png', label: 'Inactive In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Red.png', label: 'Inactive Stand Alone Upgraders' }
                                                        ]
                                                    },
                                                    {
                                                        id: 'landHistory2016',
                                                        title: '2016',
                                                        visibleLayersIds: [208, 209, 210, 212, 213, 214, 215, 216, 219, 220, 221, 222, 223, 224, 225, 226, 227],
                                                        hideLayersWithPrefix: 'currentLand,project,tailings',
                                                        subLayerToInclude: 'land2015ProjectPoints',
                                                        historicalLayer: true,
                                                        legendIcons: [
                                                            { iconGroupId: '2016', iconGroupName: '2016' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/all_project_boundaries_historical.png', label: 'Operating Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/approved_project_boundaries_light.png', label: 'Approved Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/tailings_ponds.png', label: 'Tailings Ponds' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_cleared.png', label: 'Land Cleared (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_cleared.png', label: 'Land Cleared (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_plant_sites.png', label: 'In Situ Plant Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_well_sites.png', label: 'In Situ Well Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_disturbed.png', label: 'Land Disturbed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_temporarily_reclaimed_mining.png', label: 'Land Temporarily Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_permanently_reclaimed_mining.png', label: 'Land Permanently Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_certified_reclaimed_mining.png', label: 'Land Certified Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_reclaimed_insitu.png', label: 'Land Reclaimed (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Integrated_Upgrader.png', label: 'On-site Upgrader Projects' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine.png', label: 'Operating Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu.png', label: 'Operating In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader.png', label: 'Operating Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Grey.png', label: 'Approved Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Grey.png', label: 'Approved In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Grey.png', label: 'Approved Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Orange.png', label: 'Proposed Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Orange.png', label: 'Proposed In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Orange.png', label: 'Proposed Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Red.png', label: 'Inactive Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Red.png', label: 'Inactive In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Red.png', label: 'Inactive Stand Alone Upgraders' }
                                                        ]
                                                    },
                                                    {
                                                        id: 'landHistory2017',
                                                        title: '2017',
                                                        visibleLayersIds: [231, 232, 233, 235, 236, 237, 238, 239, 240, 242, 243, 244, 245, 246, 247, 248, 249],
                                                        hideLayersWithPrefix: 'currentLand,project,tailings',
                                                        subLayerToInclude: 'land2015ProjectPoints',
                                                        historicalLayer: true,
                                                        legendIcons: [
                                                            { iconGroupId: '2017', iconGroupName: '2017' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/all_project_boundaries_historical.png', label: 'Operating Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/approved_project_boundaries_light.png', label: 'Approved Project Boundaries' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/tailings_ponds.png', label: 'Tailings Ponds' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_land_cleared.png', label: 'Land Cleared (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_cleared.png', label: 'Land Cleared (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_plant_sites.png', label: 'In Situ Plant Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/insitu_well_sites.png', label: 'In Situ Well Sites' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/mining_land_disturbed.png', label: 'Land Disturbed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_temporarily_reclaimed_mining.png', label: 'Land Temporarily Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_permanently_reclaimed_mining.png', label: 'Land Permanently Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_certified_reclaimed_mining.png', label: 'Land Certified Reclaimed (Mining)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/land/land_reclaimed_insitu.png', label: 'Land Reclaimed (In Situ)' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Integrated_Upgrader.png', label: 'On-site Upgrader Projects' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine.png', label: 'Operating Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu.png', label: 'Operating In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader.png', label: 'Operating Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Grey.png', label: 'Approved Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Grey.png', label: 'Approved In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Grey.png', label: 'Approved Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Orange.png', label: 'Proposed Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Orange.png', label: 'Proposed In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Orange.png', label: 'Proposed Stand Alone Upgraders' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Mine_Red.png', label: 'Inactive Oil Sands Mines' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/InSitu_Red.png', label: 'Inactive In Situ Facilities' },
                                                            { iconName: siteConfig.rootUrl + 'scripts/app/content/images/projects/Upgrader_Red.png', label: 'Inactive Stand Alone Upgraders' }
                                                        ]
                                                    }
                                                ],
                                                subLayers: [
                                                    {
                                                        type: 'feature',
                                                        title: 'Oil Sands Projects 2016',
                                                        url: siteConfig.osipMapServer + '206',
                                                        layerOrder: 1,
                                                        options: {
                                                            id: 'land2016ProjectPoints',
                                                            opacity: 1,
                                                            visible: false
                                                        },
                                                        customModule: new OilSandsContent({ isHistoricalLayer: true })
                                                    },
                                                    {
                                                        type: 'feature',
                                                        title: 'Oil Sands Projects 2015',
                                                        url: siteConfig.osipMapServer + '183',
                                                        layerOrder: 1,
                                                        options: {
                                                            id: 'land2015ProjectPoints',
                                                            opacity: 1,
                                                            visible: false
                                                        },
                                                        customModule: new OilSandsContent({ isHistoricalLayer: true })
                                                    },
                                                    {
                                                        type: 'feature',
                                                        title: 'Oil Sands Projects 2014',
                                                        url: siteConfig.osipMapServer + '162',
                                                        layerOrder: 1,
                                                        options: {
                                                            id: 'land2014ProjectPoints',
                                                            opacity: 1,
                                                            visible: false
                                                        },
                                                        customModule: new OilSandsContent({ isHistoricalLayer: true })
                                                    },
                                                    {
                                                        type: 'feature',
                                                        title: 'Oil Sands Projects 2013',
                                                        url: siteConfig.osipMapServer + '141',
                                                        layerOrder: 1,
                                                        options: {
                                                            id: 'land2013ProjectPoints',
                                                            opacity: 1,
                                                            visible: false
                                                        },
                                                        customModule: new OilSandsContent({ isHistoricalLayer: true })
                                                    },
                                                    {
                                                        type: 'feature',
                                                        title: 'Oil Sands Projects 2012',
                                                        url: siteConfig.osipMapServer + '124',
                                                        layerOrder: 1,
                                                        options: {
                                                            id: 'land2012ProjectPoints',
                                                            opacity: 1,
                                                            visible: false
                                                        },
                                                        customModule: new OilSandsContent({ isHistoricalLayer: true })
                                                    },
                                                    {
                                                        type: 'feature',
                                                        title: 'Oil Sands Projects 2011',
                                                        url: siteConfig.osipMapServer + '107',
                                                        layerOrder: 1,
                                                        options: {
                                                            id: 'land2011ProjectPoints',
                                                            opacity: 1,
                                                            visible: false
                                                        },
                                                        customModule: new OilSandsContent({ isHistoricalLayer: true })
                                                    },
                                                    {
                                                        type: 'feature',
                                                        title: 'Oil Sands Projects 2010',
                                                        url: siteConfig.osipMapServer + '90',
                                                        layerOrder: 1,
                                                        options: {
                                                            id: 'land2010ProjectPoints',
                                                            opacity: 1,
                                                            visible: false
                                                        },
                                                        customModule: new OilSandsContent({ isHistoricalLayer: true })
                                                    },
                                                    {
                                                        type: 'feature',
                                                        title: 'Oil Sands Projects 2007',
                                                        url: siteConfig.osipMapServer + '73',
                                                        layerOrder: 1,
                                                        options: {
                                                            id: 'land2007ProjectPoints',
                                                            opacity: 1,
                                                            visible: false
                                                        },
                                                        customModule: new OilSandsContent({ isHistoricalLayer: true })
                                                    },
                                                    {
                                                        type: 'feature',
                                                        title: 'Oil Sands Projects 1998',
                                                        url: siteConfig.osipMapServer + '56',
                                                        layerOrder: 1,
                                                        options: {
                                                            id: 'land1998ProjectPoints',
                                                            opacity: 1,
                                                            visible: false
                                                        },
                                                        customModule: new OilSandsContent({ isHistoricalLayer: true })
                                                    },
                                                    {
                                                        type: 'feature',
                                                        title: 'Oil Sands Projects 1980',
                                                        url: siteConfig.osipMapServer + '39',
                                                        layerOrder: 1,
                                                        options: {
                                                            id: 'land1980ProjectPoints',
                                                            opacity: 1,
                                                            visible: false
                                                        },
                                                        customModule: new OilSandsContent({ isHistoricalLayer: true })
                                                    }
                                                ]
                                            }
                                        }
                                    ]
                                } // end of sub groups of oilSandsProjects
                            ]
                        }
                    ]
                }] // end of sub groups of IndustrialImpacts              
            }
        ]
    };
});