﻿/*property
    AQHIValue, Abbreviation, AirshedName, CommunityStationName, HealthRisk, Id,
    LastUpdated, Latitude, Longitude, MODE_SNAPSHOT, ObjectID, StationName,
    TOOLTIP_DIALOG_ID, Type, _createAQHIStationsGraphic, _getAQHIIcon,
    _getAllAQHIStations, addBreak, allAQHIStations, aqhiIconPath, attributes,
    closeToolTipDialog, constructor, createFeatureLayer,
    createInfoWindowSection, dataUrl, featureSet, features, forEach,
    geographicToWebMercator, geometryType, get,  getRenderer,
    graphic, handleAs, headers, hideSpinner, hitch, id,
    infoWindowHandlerContent, infoWindowHandlerTitle, infoWindowPopupId,
     label, layerDefinition, libraryUrl, maxValue,
    minValue, mode, mouseOutHandler, push, showGraphicTooltip,
    showToolTipDialog, symbol, sync, then, toUrl, visible,
    create, initInfoWindowModal, dialogueId, style, link, createInfoWindowAnchor, parentNode,
    pos, href, innerHTML, infoGlyphSign, className, onclickFunc, dataToggle, roleName, newWindowGlyphSign,
    targetName, add, layer, graphics, length
*/

define([
    'dojo/_base/declare',
    'require', //this is a context-sensitive require
    'dojo/_base/lang',
    'dojo/request',
    'dojo/dom-construct',
    './_BaseContent',
    'esri/symbols/PictureMarkerSymbol',
    'esri/renderers/ClassBreaksRenderer',
    'esri/geometry/webMercatorUtils',
    'esri/geometry/Point',
    'esri/layers/FeatureLayer',
    'esri/graphic',
    'app/mapping/Utils'
], function (declare, require, lang, request, domConstruct, _BaseContent,
    PictureMarkerSymbol, ClassBreaksRenderer, webMercatorUtils, Point, FeatureLayer, Graphic, mapUtils) {
    'use strict';
    var _AQHIContent = declare("AQHIContent", [_BaseContent], {
        dataUrl: '',
        libraryUrl: '',
        allAQHIStations: null,
        aqhiIconPath: require.toUrl("./images/air"),
        TOOLTIP_DIALOG_ID: "aqhiTooltipDialog",
        constructor: function (options) {
            this.dataUrl = (options && options.dataUrl) ? options.dataUrl : siteConfig.dataUrl;
            this.libraryUrl = (options && options.libraryUrl) ? options.libraryUrl : siteConfig.libraryUrl;
            this.layer = null;
        },

        //create feature layer
        createFeatureLayer: function (layerDefinition, layerId) {
            var features = [],
                featureLayer = null,
                featureCollection = {
                    layerDefinition: layerDefinition,
                    featureSet: {
                        features: features,
                        geometryType: "esriGeometryPoint"
                    }
                };

            featureLayer = new FeatureLayer(featureCollection, { id: layerId, visible: false, mode: FeatureLayer.MODE_SNAPSHOT });

            this.layer = featureLayer;
            // add data to the layer
            if (this.allAQHIStations === null) {
                var def = this._getAllAQHIStations();
                def.then(lang.hitch(this, function (data) {
                    this.allAQHIStations = data;
                    this.allAQHIStations.forEach(lang.hitch(this, function (station) {
                        this.layer.add(this._createAQHIStationsGraphic(station));
                    }));
                }));
            }
            
            return featureLayer;
        },

        // assign AQHI station icons
        getRenderer: function () {
            var classBreaksRenderer, defaultStationSymbol = new PictureMarkerSymbol(this.aqhiIconPath + '/aqhi_white.png', 28, 28);
            classBreaksRenderer = new ClassBreaksRenderer(defaultStationSymbol, "AQHIValue");
            //classBreaksRenderer.setDefaultLabel("test");

            classBreaksRenderer.addBreak({minValue: 1, maxValue: 1, symbol: new PictureMarkerSymbol(this._getAQHIIcon(1), 28, 28), label: "Low Health Risk"});
            classBreaksRenderer.addBreak({ minValue: 2, maxValue: 2, symbol: new PictureMarkerSymbol(this._getAQHIIcon(2), 28, 28), label: "Low Health Risk" });
            classBreaksRenderer.addBreak({ minValue: 3, maxValue: 3, symbol: new PictureMarkerSymbol(this._getAQHIIcon(3), 28, 28), label: "Low Health Risk" });
            classBreaksRenderer.addBreak({ minValue: 4, maxValue: 4, symbol: new PictureMarkerSymbol(this._getAQHIIcon(4), 28, 28), label: "Moderate Health Risk" });
            classBreaksRenderer.addBreak({ minValue: 5, maxValue: 5, symbol: new PictureMarkerSymbol(this._getAQHIIcon(5), 28, 28), label: "Moderate Health Risk" });
            classBreaksRenderer.addBreak({ minValue: 6, maxValue: 6, symbol: new PictureMarkerSymbol(this._getAQHIIcon(6), 28, 28), label: "Moderate Health Risk" });
            classBreaksRenderer.addBreak({ minValue: 7, maxValue: 7, symbol: new PictureMarkerSymbol(this._getAQHIIcon(7), 28, 28), label: "High Health Risk" });
            classBreaksRenderer.addBreak({ minValue: 8, maxValue: 8, symbol: new PictureMarkerSymbol(this._getAQHIIcon(8), 28, 28), label: "High Health Risk" });
            classBreaksRenderer.addBreak({ minValue: 9, maxValue: 9, symbol: new PictureMarkerSymbol(this._getAQHIIcon(9), 28, 28), label: "High Health Risk" });
            classBreaksRenderer.addBreak({ minValue: 10, maxValue: 10, symbol: new PictureMarkerSymbol(this._getAQHIIcon(10), 28, 28), label: "High Health Risk" });
            classBreaksRenderer.addBreak({ minValue: 10, maxValue: 200, symbol: new PictureMarkerSymbol(this._getAQHIIcon(11), 28, 28), label: "Very High Health Risk" });
            return classBreaksRenderer;
        },

        // set info-window title
        infoWindowHandlerTitle: function (graphic) {
            return graphic.attributes.StationName + ' Air Quality';
        },

        // set info-window content
        infoWindowHandlerContent: function (graphic) {
            var contentNode = domConstruct.create("div", {}, null),
                onclickFunc = null,
                sectionDiv = null;
            
            if (graphic.attributes.AQHIValue !== null && graphic.attributes.AQHIValue > 0) {
                sectionDiv = this.createInfoWindowSection(contentNode, 'first', null, 'Current ');

                onclickFunc = lang.hitch(this, function () {
                    this.initInfoWindowModal({
                        dialogueId: this.infoWindowPopupId,
                        style: 'modal-content xlg modalContentMax',
                        link: this.dataUrl + 'lightboxLB/getstyledlightbox?csspage=White.css&contentpage=what_is_alberta_ambient_air_quality_index.htm'
                    });
                });
                this.createInfoWindowAnchor({
                    parentNode: sectionDiv,   
                    pos: 'last',              
                    href: "#" + this.infoWindowPopupId,
                    innerHTML: "AQHI",
                    onclickFunc: onclickFunc,
                    dataToggle: "modal"
                });

                domConstruct.create('span', {
                    innerHTML: ' is ' + graphic.attributes.AQHIValue + ' (' + graphic.attributes.HealthRisk + ' Risk).<br/>'
                }, sectionDiv, 'last');

                domConstruct.create('span', {
                    innerHTML: graphic.attributes.LastUpdated
                }, sectionDiv, 'last');
            }

            // Add Substance Measurements except for LICA and Community Stations
            if (graphic.attributes.CommunityStationName !== 'LICA - Portable station.' && graphic.attributes.Type !== "Community") {
                sectionDiv = this.createInfoWindowSection(contentNode, 'last');
                onclickFunc = lang.hitch(this, function () {
                    this.initInfoWindowModal({
                        dialogueId: this.infoWindowPopupId,
                        style: 'modal-content sm modalContentMediumCharts',
                        link: this.dataUrl + 'AirQualityLB/ChemicalMeasurements?cssPage=White.css&type=Archive&station=' + graphic.attributes.CommunityStationName + '&archiveId=' + graphic.attributes.ObjectID
                    });
                });
                this.createInfoWindowAnchor({
                    parentNode: sectionDiv,
                    pos: 'last',
                    href: "#" + this.infoWindowPopupId,
                    innerHTML: this.infoGlyphSign + "Substance Measurements",
                    className: "btn-link",
                    onclickFunc: onclickFunc,
                    dataToggle: "modal",
                    roleName: "button"
                });
            }

            sectionDiv = this.createInfoWindowSection(contentNode, 'last');
            this.createInfoWindowAnchor({
                parentNode: sectionDiv,
                pos: 'last',
                href: "http://airdata.alberta.ca/aepContent/Reports/DataDownloadMain.aspx",
                innerHTML: this.newWindowGlyphSign + "View/Download Historic Station Readings",
                targetName: "_blank"
            });

            sectionDiv = this.createInfoWindowSection(contentNode, 'last');
            this.createInfoWindowAnchor({
                parentNode: sectionDiv,
                pos: 'last',
                href: "http://environmentalmonitoring.alberta.ca/?s=air+quality+health+index",
                innerHTML: this.newWindowGlyphSign + "More data on Air Quality Health Index",
                targetName: "_blank"
            });

            // disclaimer
            sectionDiv = this.createInfoWindowSection(contentNode, 'last');
            onclickFunc = lang.hitch(this, function () {
                this.initInfoWindowModal({
                    dialogueId: this.infoWindowPopupId,
                    style: 'modal-content modalSmallContent',
                    link: this.dataUrl + 'lightboxLB/getstyledlightbox?csspage=White.css&contentpage=disclaimer.htm'
                });
            });
            this.createInfoWindowAnchor({
                parentNode: sectionDiv,
                pos: 'last',
                href: "#" + this.infoWindowPopupId,
                innerHTML: this.infoGlyphSign + "Disclaimer",
                className: "btn-link",
                onclickFunc: onclickFunc,
                dataToggle: "modal",
                roleName: "button"
            });

            this.hideSpinner();
            return contentNode;
        },
        showGraphicTooltip: function (event) {
            mapUtils.showToolTipDialog(event, this.TOOLTIP_DIALOG_ID, event.graphic.attributes.StationName);
        },
        mouseOutHandler: function () {
            mapUtils.closeToolTipDialog(this.TOOLTIP_DIALOG_ID);
        },
        // create AQHI graphic
        _createAQHIStationsGraphic: function (stationData) {
            var point, attributes, symbol;
            point = webMercatorUtils.geographicToWebMercator(new Point(stationData.Longitude, stationData.Latitude));
            attributes = {
                StationName: stationData.StationName,
                Abbreviation: stationData.Abbreviation,
                AirshedName: stationData.AirshedName,
                Type: stationData.Type,
                ObjectID: stationData.Id,
                CommunityStationName: stationData.CommunityStationName,
                AQHIValue: stationData.AQHIValue,
                HealthRisk: stationData.HealthRisk,
                LastUpdated: stationData.LastUpdated
            };
            symbol = new PictureMarkerSymbol(this._getAQHIIcon(stationData.AQHIValue), 28, 28);
            return new Graphic(point, symbol, attributes);
        },

        //get AQHI station icon based on value
        _getAQHIIcon: function (stationValue) {
            // default icon for station
            var stationIcon = this.aqhiIconPath + '/aqhi_white.png';

            // icon changes depending on the AQHI status
            if (stationValue !== null  && stationValue > 0 && stationValue <= 10) {
                stationIcon = this.aqhiIconPath + "/aqhi" + stationValue + ".png";
            } else if (stationValue !== null && stationValue > 10) {
                stationIcon = this.aqhiIconPath + "/aqhiPlus.png";
            }
            return stationIcon;
        },

        // get all AQHI stations
        _getAllAQHIStations: function () {
            return request.get(this.dataUrl + 'moduledata/AirQualityIndex/GetAllStations/', {
                handleAs: "json",
                headers: { "X-Requested-With": null },
                sync: false
            });
        }

    });

    return _AQHIContent;
});