﻿/*property
    AQHI_Name, Archive_Id, TOOLTIP_DIALOG_ID,
    _getIndustryEmissionStationName, aqhiIconPath, attributeField, attributes,
    closeToolTipDialog, constructor, createInfoWindowSection, dataUrl,
    defaultLabel, defaultSymbol, emissionStationName, get, 
    getRenderer, graphic, handleAs, headers, hideSpinner, hitch,
    infoWindowHandlerContent, infoWindowHandlerTitle, infoWindowPopupId,
     libraryUrl, mouseOutHandler, showGraphicTooltip,
    showToolTipDialog, sync, then, toUrl, forEach, Id, Name,
    create, initInfoWindowModal, dialogueId, style, link, createInfoWindowAnchor, parentNode,
    pos, href, innerHTML, infoGlyphSign, className, onclickFunc, dataToggle, roleName, newWindowGlyphSign,
    targetName, getAirQualityStationNames, subscribeHandler, subscribe, remove
*/

define([
    'dojo/_base/declare',
    'require', //this is a context-sensitive require
    'dojo/_base/lang',
    'dojo/dom-construct',
    'dojo/topic',
    './_BaseContent',
    'esri/symbols/PictureMarkerSymbol',
    'esri/renderers/UniqueValueRenderer',
    'app/content/WebServiceData',
    'app/mapping/Utils'
], function (declare, require, lang, domConstruct, topic, _BaseContent,
    PictureMarkerSymbol, UniqueValueRenderer, WebServiceData, mapUtils) {
    'use strict';
    var _AirEmissionsContent = declare("AirEmissionsContent", [_BaseContent], {
        emissionStationName: [],
        dataUrl: '',
        libraryUrl: '',
        aqhiIconPath: require.toUrl("./images/air"),
        TOOLTIP_DIALOG_ID: "airEmissionsTooltipDialog",
        constructor: function (options) {
            this.dataUrl = (options && options.dataUrl) ? options.dataUrl : siteConfig.dataUrl;
            this.libraryUrl = (options && options.libraryUrl) ? options.libraryUrl : siteConfig.libraryUrl;

            this.subscribeHandler = topic.subscribe("getAirQualityStationNames/DataIsReady", lang.hitch(this, function (data) {
                this.subscribeHandler.remove();
                data.forEach(lang.hitch(this, function (station) {
                    this.emissionStationName[station.Id] = station.Name;
                }));
            }));
            WebServiceData.getAirQualityStationNames();
        },

        // assign icon for industrial emissions
        getRenderer: function () {
            var defaultStationSymbol = new PictureMarkerSymbol(this.aqhiIconPath + '/aqhi_black.png', 28, 28),
                industrialEmissionsRenderer = new UniqueValueRenderer({ defaultSymbol: defaultStationSymbol, attributeField: "Archive_Id", defaultLabel: 'Industry Monitoring Station' });
            return industrialEmissionsRenderer;
        },

        // set info-window title
        infoWindowHandlerTitle: function (graphic) {
            var title = this._getIndustryEmissionStationName(graphic);
            return title + ' Air Quality';
        },
        // set info-window content
        infoWindowHandlerContent: function (graphic) {
            var stationName = this._getIndustryEmissionStationName(graphic),
                contentNode = domConstruct.create("div", {}, null),
                // 1. Substance Measurements
                sectionDiv = this.createInfoWindowSection(contentNode, 'first'),
                onclickFunc = lang.hitch(this, function () {
                    this.initInfoWindowModal({
                        dialogueId: this.infoWindowPopupId,
                        style: 'modal-content sm modalContentMediumCharts',
                        link: this.dataUrl + 'AirQualityLB/ChemicalMeasurements?cssPage=White.css&type=Archive&station=' + stationName + '&archiveId=' + graphic.attributes.Archive_Id
                    });
                });

            this.createInfoWindowAnchor({
                parentNode: sectionDiv,   
                pos: 'last',              
                href: "#" + this.infoWindowPopupId,
                innerHTML: this.infoGlyphSign + "Substance Measurements",
                className: "btn-link",
                onclickFunc: onclickFunc,
                dataToggle: "modal",
                roleName: "button"
            });

            // 2. data download link
            sectionDiv = this.createInfoWindowSection(contentNode, 'last');
            this.createInfoWindowAnchor({
                parentNode: sectionDiv,
                pos: 'last',
                href: "http://airdata.alberta.ca/aepContent/Reports/DataDownloadMain.aspx",
                innerHTML: this.newWindowGlyphSign + "View/Download Historic Station Readings",
                targetName: "_blank"
            });

            // 3. AQHI link
            sectionDiv = this.createInfoWindowSection(contentNode, 'last');
            this.createInfoWindowAnchor({
                parentNode: sectionDiv,
                pos: 'last',
                href: "http://environmentalmonitoring.alberta.ca/?s=air+quality+health+index",
                innerHTML: this.newWindowGlyphSign + "More data on Air Quality Health Index",
                targetName: "_blank"
            }); 

            // 4. disclaimer
            sectionDiv = this.createInfoWindowSection(contentNode, 'last');
            onclickFunc = lang.hitch(this, function () {
                this.initInfoWindowModal({
                    dialogueId: this.infoWindowPopupId,
                    style: 'modal-content modalSmallContent',
                    link: this.dataUrl + 'lightboxLB/getstyledlightbox?csspage=White.css&contentpage=disclaimer.htm'
                });
            });

            this.createInfoWindowAnchor({
                parentNode: sectionDiv,
                pos: 'last',
                href: "#" + this.infoWindowPopupId,
                innerHTML: this.infoGlyphSign + "Disclaimer",
                className: "btn-link",
                onclickFunc: onclickFunc,
                dataToggle: "modal",
                roleName: "button"
            });     

            // 5. Wood Buffalo link only for below stations
            if (stationName === 'Albian Mine Site' || stationName === 'CNRL Horizon' || stationName === 'Buffalo Viewpoint' || stationName === 'Lower Camp' ||
                    stationName === 'Albian Muskeg River' || stationName === 'Mildred Lake' || stationName === 'Mannix' || stationName === 'Millennium' ||
                    stationName === 'Anzac' || stationName === 'Barge Landing' || stationName === 'Lower Camp B') {

                sectionDiv = this.createInfoWindowSection(contentNode, 'last');
                this.createInfoWindowAnchor({
                    parentNode: sectionDiv,
                    pos: 'last',
                    href: "http://wbea.org",
                    innerHTML: this.newWindowGlyphSign + "Link to Airshed:  Wood Buffalo Environmental Association",
                    targetName: "_blank"
                });
            }

            this.hideSpinner();
            return contentNode;
        },
        showGraphicTooltip: function (event) {
            var stationName = this._getIndustryEmissionStationName(event.graphic);
            mapUtils.showToolTipDialog(event, this.TOOLTIP_DIALOG_ID, stationName);
        },
        mouseOutHandler: function () {
            mapUtils.closeToolTipDialog(this.TOOLTIP_DIALOG_ID);
        },
        // get industry emission station name
        _getIndustryEmissionStationName: function (graphic) {
            return  this.emissionStationName[graphic.attributes.Archive_Id];
        }
    });

    return _AirEmissionsContent;
});