﻿/*property
    CARIBOU_STATUS_COLOR, Declining, Extirpated, Increasing, LOCALRANGE,
    MODE_SNAPSHOT, STATUS, SUBUNIT, Stable, TOOLTIP_DIALOG_ID, _caribouStatus,
    _caribouStatusFile, _caribouSymbol, _getCaribouStatus, _layer,
    _loadCaribouRangeSuccess, _loadCaribouStatus, addGraphicFeatureToLayer,
    addGraphics, aewError, attributes, closeToolTipDialog, constructor,
    createFeatureLayer, featureSet, features, forEach, generateId, getRenderer,
    getSimpleFillSymbol, graphic, handleAs, hideSpinner, hitch, id,
    infoWindowHandlerContent, infoWindowHandlerTitle, label, layerDefinition,
    message, mode, mouseOutHandler, outFields, polygonFill, queryFeatureLayer,
    setSymbol, showGraphicTooltip, showToolTipDialog, status, symbol, sync,
    then, toUrl, type, visible, year
*/
define([
    'dojo/_base/declare',
    'dojo/_base/lang',
    "dojo/request/xhr",
    'dojo/_base/array',
    'require', //this is a context-sensitive require
    'esri/renderers/SimpleRenderer',
    'esri/layers/FeatureLayer',
    './_BaseContent',
    'app/utils/Common',
    'app/mapping/Utils'
], function (declare, lang, xhr, array,
    require, SimpleRenderer, FeatureLayer, _BaseContent, commonUtils, mapUtils) {
    'use strict';
    var _caribouContent = declare("CaribouContent", [_BaseContent], {
        CARIBOU_STATUS_COLOR: {
            Declining: "#e36c0a",
            Stable: "#00b0f0",
            Increasing: "#92d050",
            Extirpated: "#bfbfbf",
            polygonFill: "#678F00"
        },
        TOOLTIP_DIALOG_ID: "caribouTooltipDialog",
        _caribouStatusFile: require.toUrl("./data/caribou-status.json"),
        _caribouStatus: null, // save caribou status loaded from local json file
        _caribouSymbol: null,
        _layer: null,  // reference to the layer, we need it to set highlight symbol on mouse-over
        constructor: function () {
            this._loadCaribouStatus();
            this._caribouSymbol = mapUtils.getSimpleFillSymbol(this.CARIBOU_STATUS_COLOR.polygonFill, 0.6, this.CARIBOU_STATUS_COLOR.polygonFill, 0.9);
        },
        _loadCaribouStatus: function () {
            xhr(this._caribouStatusFile, {
                sync: false,
                handleAs: "json"
            }).then(lang.hitch(this, function (data) {
                this._caribouStatus = data.status;
            }));
        },
        _getCaribouStatus: function (graphic) {
            return this._caribouStatus[0][graphic.attributes.LOCALRANGE] || graphic.attributes.STATUS;
        },
        createFeatureLayer: function (layerDefinition, layerId) {
            var featureCollection = {
                layerDefinition: layerDefinition,
                featureSet: null
            };
            return new FeatureLayer(featureCollection, { id: layerId, visible: false, mode: FeatureLayer.MODE_SNAPSHOT});
        },
        getRenderer: function () {
            var caribouRenderer = new SimpleRenderer({
                    type: "simple",
                    label: "Woodland Caribou Range",
                    symbol: this._caribouSymbol
                });

            return caribouRenderer;
        },
        addGraphics: function (layer, mapServerUrl, options, iniExtent) {
            this._layer = layer;

            return mapUtils.queryFeatureLayer(lang.hitch(this, this._loadCaribouRangeSuccess),
                commonUtils.aewError, mapServerUrl, options.outFields, iniExtent);
        },
        _loadCaribouRangeSuccess: function (data) {
            array.forEach(data.features, lang.hitch(this, function (feature) {
                mapUtils.addGraphicFeatureToLayer(this._layer, feature, this._caribouSymbol, commonUtils.generateId());
            }));
        },
        infoWindowHandlerTitle: function (graphic) {
            // hide tooltip
            mapUtils.closeToolTipDialog(this.TOOLTIP_DIALOG_ID);
            return "<span>" + graphic.attributes.LOCALRANGE + " Caribou Range</span>";
        },
        infoWindowHandlerContent: function (graphic) {
            var rangeStatus = this._getCaribouStatus(graphic),
                content = 'Herd: ' + graphic.attributes.SUBUNIT + '<br/>'
                    + rangeStatus.year + " Status: " + rangeStatus.status + ". " + rangeStatus.message;

            this.hideSpinner();
            return content;
        },
        showGraphicTooltip: function (event) {
            var rangeStatus = this._getCaribouStatus(event.graphic),
                statusColourCode = this.CARIBOU_STATUS_COLOR[rangeStatus.status],
                highlightSymbol = mapUtils.getSimpleFillSymbol(statusColourCode, 0.7, statusColourCode, 0.7),
                tipStyle = "background-color: " + statusColourCode + ";color:black;",
                tipContent = event.graphic.attributes.LOCALRANGE + " Woodland Caribou Population<br/>" 
                    + rangeStatus.year + " Status: " + rangeStatus.status + ". " + rangeStatus.message;


            // HighLight selected area
            event.graphic.setSymbol(highlightSymbol);

            // show tooltip
            mapUtils.showToolTipDialog(event, this.TOOLTIP_DIALOG_ID, tipContent, tipStyle);
        },
        mouseOutHandler: function (event) {
            mapUtils.closeToolTipDialog(this.TOOLTIP_DIALOG_ID);
            event.graphic.setSymbol(this._caribouSymbol);
        }
    });

    return _caribouContent;
});