﻿/*property
    EarliestSample, Metals, MostRecentSample, NoMetals, Pesticides, StationNo,
    TOOLTIP_DIALOG_ID, _getWaterQualityStation, _getWaterQualityStationData,
    attributes, closeToolTipDialog, constructor, createInfoWindowSection,
    dataUrl, get, getFullYear,  getRenderer, glossaryUrl,
    graphic, handleAs, headers, hideSpinner, hitch, infoWindowHandlerContent,
    infoWindowHandlerTitle, infoWindowPopupId, 
    lakeQualityStations, mouseOutHandler, parse, replace, showGraphicTooltip,
    showToolTipDialog, symbol, sync, then, toUrl, type, waterIconPath, 
    create, initInfoWindowModal, dialogueId, style, link, 
    createInfoWindowAnchor, parentNode, pos, href, innerHTML, infoGlyphSign, className, onclickFunc, dataToggle, roleName, newWindowGlyphSign,
    targetName, createGlossaryAnchor
*/
define([
    'dojo/_base/declare',
    'require', //this is a context-sensitive require
    'dojo/_base/lang',
    'dojo/number',
    'dojo/request',
    'dojo/dom-construct',
    './_BaseContent',
    'esri/symbols/PictureMarkerSymbol',
    'esri/renderers/SimpleRenderer',
    'app/mapping/Utils'
], function (declare, require, lang, number, request, domConstruct, _BaseContent,
    PictureMarkerSymbol, SimpleRenderer, mapUtils) {
    'use strict';
    var _LakeQualityContent = declare("LakeQualityContent", [_BaseContent], {
        lakeQualityStations: {},
        dataUrl: '',
        waterIconPath: require.toUrl("./images/water"),
        TOOLTIP_DIALOG_ID: "lakeQualityTooltipDialog",
        constructor: function (options) {
            this.dataUrl = (options && options.dataUrl) ? options.dataUrl : siteConfig.dataUrl;
        },

        // assign icon for lake quality station
        getRenderer: function () {
            var defaultLakeQualitySymbol = new PictureMarkerSymbol(this.waterIconPath + '/LakeQuality.png', 15, 16),
                lakeQualityRenderer = new SimpleRenderer({ type : 'simple', symbol: defaultLakeQualitySymbol });
            return lakeQualityRenderer;
        },

        //set info-window title
        infoWindowHandlerTitle: function () {
            return 'Lake Water Quality';
        },

        // set info-window content
        infoWindowHandlerContent: function (graphic) {
            var stationData = this._getWaterQualityStation(graphic),
                startDate = new Date(number.parse(stationData.EarliestSample.replace("/Date(", "").replace(")/", ""))),
                endDate = new Date(number.parse(stationData.MostRecentSample.replace("/Date(", "").replace(")/", ""))),
                dateRange,
                contentNode = domConstruct.create("div", {}, null),
                sectionDiv = null;

            this.createInfoWindowSection(contentNode, 'first', 'infoWindowStationName infoWindowSection', stationData.StationNo);
            if (startDate.getFullYear() === endDate.getFullYear()) {
                dateRange = startDate.getFullYear();
            } else {
                dateRange = startDate.getFullYear() + " - " + endDate.getFullYear();
            }

            this.createInfoWindowSection(contentNode, 'last', null, 'Sample Counts (' + dateRange + ')');

            sectionDiv = this.createGlossaryAnchor(contentNode, 'last', 'Inorganics', 'Inorganics:', null, true/* create a section*/);
            domConstruct.create("span", { innerHTML: ' ' + stationData.NoMetals }, sectionDiv, 'last');

            sectionDiv = this.createGlossaryAnchor(contentNode, 'last', 'Metals', 'Metals:', null, true);
            domConstruct.create("span", { innerHTML: ' ' + stationData.Metals }, sectionDiv, 'last');

            sectionDiv = this.createGlossaryAnchor(contentNode, 'last', 'Pesticides', 'Pesticides:', null, true);
            domConstruct.create("span", { innerHTML: ' ' + stationData.Pesticides }, sectionDiv, 'last');

            this.hideSpinner();
            return contentNode;
        },
        showGraphicTooltip: function (event) {
            var stationData = this._getWaterQualityStation(event.graphic);
            mapUtils.showToolTipDialog(event, this.TOOLTIP_DIALOG_ID,
                stationData.StationNo);
        },
        mouseOutHandler: function () {
            mapUtils.closeToolTipDialog(this.TOOLTIP_DIALOG_ID);
        },
        // get station 
        _getWaterQualityStation: function (graphic) {
            var stationData, def;
            if (this.lakeQualityStations["StationNo_" + graphic.attributes.StationNo]) {
                stationData = this.lakeQualityStations["StationNo_" + graphic.attributes.StationNo];
            } else {
                def = this._getWaterQualityStationData(graphic.attributes.StationNo);
                def.then(lang.hitch(this, function (data) {
                    if (data) {
                        stationData = data;
                    }                   
                    this.lakeQualityStations["StationNo_" + graphic.attributes.StationNo] = stationData;
                }));
            }

            return stationData;
        },

        // get lake station data
        _getWaterQualityStationData: function (stationId) {
            return request.get(this.dataUrl + 'moduledata/waterquality/GetLakeStation?stationId=' +stationId,
                {
                    handleAs: "json",
                    headers: { "X-Requested-With": null },
                    sync: true
                });
        }
       
    });

    return _LakeQualityContent;
});