﻿/*property
    APPROVED_PROJECT_BORDER_COLOR, APPROVED_PROJECT_Fill_COLOR, Active_Status,
    GetProjectStatuses, Id, MODE_SNAPSHOT, OPERATING_PROJECT_BORDER_COLOR,
    OPERATING_PROJECT_Fill_COLOR, OSP_NO, OTHER_PROJECT_BORDER_COLOR,
    OTHER_PROJECT_Fill_COLOR, Status, _approvedProjectSymbol, _dataUrl,
    _defaultSymbol, _getProjectStatusByProjectId, _layer,
    _loadProjectBoundariesSuccess, _operatingProjectSymbol, _projectStatuses,
    addGraphicFeatureToLayer, addGraphics, addValue, aewError, attributeField,
    attributes, constructor, createFeatureLayer, dataUrl, defaultLabel,
    defaultSymbol, featureSet, features, forEach, generateId, getInfoTemplate,
    getRenderer, getSimpleFillSymbol, hitch, id, infoWindowHandlerContent,
    label, layerDefinition, mode, outFields, queryFeatureLayer, setMapControl,
    some, symbol, value, visible, getProjectStatuses, _addDataToLayer, performTasksAfterLayerCreated, 
    _mapServerUrl, _options, _iniExtent, subscribe, remove, subscribeHandler
*/
define([
    'dojo/_base/declare',
    'dojo/_base/lang',
    'dojo/_base/array',
    'dojo/topic',
    'esri/layers/FeatureLayer',
    'esri/renderers/UniqueValueRenderer',
    './_BaseContent',
    'app/content/WebServiceData',
    'app/utils/Common',
    'app/mapping/Utils'
], function (declare, lang, array, topic, FeatureLayer, UniqueValueRenderer, _BaseContent, WebServiceData, commonUtils, mapUtils
    ) {
    'use strict';
    return declare("ProjectBoundariesContent", [_BaseContent], {
        OPERATING_PROJECT_Fill_COLOR: "#48C1EA",
        OPERATING_PROJECT_BORDER_COLOR: "#0099FF",
        APPROVED_PROJECT_Fill_COLOR: "#8ECF63",
        APPROVED_PROJECT_BORDER_COLOR: "#669933",
        OTHER_PROJECT_Fill_COLOR: "#cccccc",
        OTHER_PROJECT_BORDER_COLOR: "#888888",
        constructor: function (options) {
            this._layer = null;
            this._projectStatuses = null;
            this._dataUrl = ((options && options.dataUrl) ? options.dataUrl : siteConfig.dataUrl);
            this._operatingProjectSymbol = mapUtils.getSimpleFillSymbol(this.OPERATING_PROJECT_Fill_COLOR, 0.6, this.OPERATING_PROJECT_BORDER_COLOR, 0.8);
            this._approvedProjectSymbol = mapUtils.getSimpleFillSymbol(this.APPROVED_PROJECT_Fill_COLOR, 0.6, this.APPROVED_PROJECT_BORDER_COLOR, 0.8);
            this._defaultSymbol = mapUtils.getSimpleFillSymbol(this.OTHER_PROJECT_Fill_COLOR, 0.6, this.OTHER_PROJECT_BORDER_COLOR, 0.8); //grey

            this.subscribeHandler = topic.subscribe("getProjectStatuses/DataIsReady", lang.hitch(this, function (data) {
                this.subscribeHandler.remove();
                this._projectStatuses = data;

                if (this._layer) { // layer is ready
                    this._addDataToLayer();
                }               
            }));
            WebServiceData.getProjectStatuses();
        },
        performTasksAfterLayerCreated: function (layer) {
            this._layer = layer;

            if (this._projectStatuses) { // data is ready
                this._addDataToLayer();
            }
        },
        createFeatureLayer: function (layerDefinition, layerId) {
            var featureCollection = {
                layerDefinition: layerDefinition,
                featureSet: null
            };
            return new FeatureLayer(featureCollection, { id: layerId, visible: false, mode: FeatureLayer.MODE_SNAPSHOT });
        },
        getRenderer: function () {
            var defaultProjectBoundaryLabel = "Other Project Boundaries",
                operatingProjectBoundaryLabel = "Operating Project Boundaries",
                approvedProjectBoundaryLabel = "Approved Project Boundaries",
                projectBoundariesRenderer = new UniqueValueRenderer({
                    defaultSymbol: this._defaultSymbol,
                    attributeField: "Active_Status",
                    defaultLabel: defaultProjectBoundaryLabel
                });

            projectBoundariesRenderer.addValue({
                value: "Operating",
                symbol: this._operatingProjectSymbol,
                label: operatingProjectBoundaryLabel
            });
            projectBoundariesRenderer.addValue({
                value: "Planned",
                symbol: this._operatingProjectSymbol,
                label: operatingProjectBoundaryLabel
            });
            projectBoundariesRenderer.addValue({
                value: "Approved",
                symbol: this._approvedProjectSymbol,
                label: approvedProjectBoundaryLabel
            });

            return projectBoundariesRenderer;
        },
        addGraphics: function (layer, mapServerUrl, options, iniExtent) {
            this._layer = layer;
            this._mapServerUrl = mapServerUrl;
            this._options = options;
            this._iniExtent = iniExtent;
        },
        _addDataToLayer: function () {
            return mapUtils.queryFeatureLayer(lang.hitch(this, this._loadProjectBoundariesSuccess),
                commonUtils.aewError, this._mapServerUrl, this._options.outFields, this._iniExtent);
        },
        _loadProjectBoundariesSuccess: function (data) {
            var statusRecord = null,
                projectSymbol = null;
            
            array.forEach(data.features, lang.hitch(this, function (feature) {
                statusRecord = this._getProjectStatusByProjectId(feature.attributes.OSP_NO);
                if (statusRecord) {
                    switch (statusRecord.Status) {
                        case "Active":
                            projectSymbol = this._operatingProjectSymbol;
                            feature.attributes.Active_Status = "Operating";
                            break;
                        case "Approved":
                            projectSymbol = this._approvedProjectSymbol;
                            feature.attributes.Active_Status = "Approved";
                            break;
                        case "Exploration":
                            projectSymbol = this._operatingProjectSymbol;
                            feature.attributes.Active_Status = "Planned";
                            break;
                        default:
                            projectSymbol = this._defaultSymbol;
                            feature.attributes.Active_Status = "Other";
                    }
                    mapUtils.addGraphicFeatureToLayer(this._layer, feature, projectSymbol, commonUtils.generateId());
                }                           
            }));
        },
        _getProjectStatusByProjectId: function (projectId) {
            var projectStatus = null;

            if (this._projectStatuses !== undefined) {
                array.some(this._projectStatuses, function (item) {
                    if (item.Id === projectId) {
                        projectStatus = item;
                    }
                });
            }
            return projectStatus;
        },
        getInfoTemplate: null,
        infoWindowHandlerContent: null,
        setMapControl: null // avoid show spinner when click
    });
});