﻿/*property
    CurrentReadingURL, HistoricReadingURL, Id, Latitude, Longitude, Name,
    Number, ShortName, StationType, TOOLTIP_DIALOG_ID, WaterType,
    WaterTypeDisplay, _createStationsGraphic, _getRiverFlowStation,
    _getRiverOrLakeStationData, _loadStationData, add, addGraphics, attributes,
    closeToolTipDialog, constructor, createInfoWindowSection, dataUrl, forEach,
    geographicToWebMercator, get, getRenderer, graphic, handleAs, headers,
    hideSpinner, hitch, infoWindowHandlerContent, infoWindowHandlerTitle,
    lakeFile, lakeStationData, mouseOutHandler, name, riverFile,
    riverFlowStations, riverStationData, showGraphicTooltip, showToolTipDialog,
    stationIcon, stationType, stations, symbol, sync, then, toUrl, type,
    waterIconPath, create, initInfoWindowModal, dialogueId, style, link, 
    createInfoWindowAnchor, parentNode, pos, href, innerHTML, infoGlyphSign, className, onclickFunc, dataToggle, roleName, newWindowGlyphSign,
    targetName, createGlossaryAnchor, id, _createInfoWindowTab, infoWindowPopupId, infoWindowMessagePopupId, messageDialogueId, message, dialogueTitle
*/
define([
    'dojo/_base/declare',
    'require', //this is a context-sensitive require
    'dojo/_base/lang',
    'dojo/_base/array',
    'dojo/request',
    'dojo/request/xhr',
    'dojo/dom-construct',
    './_BaseContent',
    'esri/symbols/PictureMarkerSymbol',
    'esri/geometry/webMercatorUtils',
    'esri/geometry/Point',
    'esri/renderers/SimpleRenderer',
    'esri/graphic',
    'app/mapping/Utils'
], function (declare, require, lang, array, request, xhr, domConstruct, _BaseContent,
    PictureMarkerSymbol, webMercatorUtils, Point, SimpleRenderer, Graphic, mapUtils) {
    'use strict';
    var _RiverFlowAndLakeLevelContent = declare("RiverFlowAndLakeLevelContent", [_BaseContent], {
        riverFlowStations: {},
        dataUrl: '',
        waterIconPath: require.toUrl("./images/water"),
        lakeFile: require.toUrl("./data/lake-level-stations.json"),
        riverFile: require.toUrl("./data/river-flow-level-stations.json"),
        stationType: null,
        riverStationData: null,
        lakeStationData: null,
        stationIcon: null,
        TOOLTIP_DIALOG_ID: "riverlakeTooltipDialog",
        constructor: function (options) {
            this.dataUrl = (options && options.dataUrl) ? options.dataUrl : siteConfig.dataUrl;
            this.stationType = (options && options.stationType) ? options.stationType : siteConfig.stationType;

            // since we don't have data in the webservices displaying additions river/lake water stations section is commented 
            //load additional station data
            //if (this.stationType === 'River' && this.riverStationData === null) {
            //    this._loadStationData(this.riverFile, this.stationType);
            //}
            //else
            //{
            //    this._loadStationData(this.lakeFile, this.stationType);
            //}
        },

        // assign icon for river/lake station
        getRenderer: function (defaultIcon) {
            this.stationIcon = defaultIcon;
            var defaultRiverFlowSymbol = new PictureMarkerSymbol(this.waterIconPath + defaultIcon, 20, 20),
            riverFlowRenderer = new SimpleRenderer({ type: 'simple', symbol: defaultRiverFlowSymbol});
            return riverFlowRenderer;
        },

        //set info-window title
        infoWindowHandlerTitle: function (graphic) {
            var type = ' Level/Flow', stationData = this._getRiverFlowStation(graphic);
            if (stationData.WaterType === 0)
            {
                type = ' Level';
            }
            return stationData.WaterTypeDisplay + type;
        },

        // set info-window content
        infoWindowHandlerContent: function (graphic) {
            var currentReadingText = 'Current Water Flow and Level',
                historicReadingText = 'Historical Water Flow and Level',
                stationData = this._getRiverFlowStation(graphic),
                contentNode = domConstruct.create("div", {}, null),
                sectionDiv = null;

            this.createInfoWindowSection(contentNode, 'first', 'infoWindowStationName infoWindowSection', stationData.Name);
            this.createInfoWindowSection(contentNode, 'last', null, 'Station Short-Name: ' + stationData.ShortName);
            if (stationData.Number) {
                this.createInfoWindowSection(contentNode, 'last', null, 'Station Number: ' + stationData.Number);
            }
            
            if (stationData.WaterType === 0)
            {
                currentReadingText = 'Current Water Level';
                historicReadingText = 'Historical Water Level';
            }

            if (stationData.CurrentReadingURL) {
                sectionDiv = this.createInfoWindowSection(contentNode, 'last');
                this.createInfoWindowAnchor({
                    parentNode: sectionDiv,
                    pos: 'last',
                    href: stationData.CurrentReadingURL,
                    innerHTML: this.newWindowGlyphSign + currentReadingText,
                    targetName: "_blank"
                });
            }

            if (stationData.HistoricReadingURL) {
                sectionDiv = this.createInfoWindowSection(contentNode, 'last');
                this.createInfoWindowAnchor({
                    parentNode: sectionDiv,
                    pos: 'last',
                    href: stationData.HistoricReadingURL,
                    innerHTML: this.newWindowGlyphSign + historicReadingText,
                    targetName: "_blank"
                });
            }

            this.hideSpinner();
            return contentNode;
        },

        showGraphicTooltip: function (event) {
            var stationData = this._getRiverFlowStation(event.graphic);
            mapUtils.showToolTipDialog(event, this.TOOLTIP_DIALOG_ID, stationData.Name);
        },

        mouseOutHandler: function () {
            mapUtils.closeToolTipDialog(this.TOOLTIP_DIALOG_ID);
        },

        // add additional station
        addGraphics: function (layer) {
            array.forEach(this.riverStationData, lang.hitch(this, function (item) {
                var feature = this._createStationsGraphic(item);
                layer.add(feature);
            }));

            array.forEach(this.lakeStationData, lang.hitch(this, function (item) {
                var feature = this._createStationsGraphic(item);
                layer.add(feature);
            }));
        },

        // get river/lake station
        _getRiverFlowStation: function (graphic) {
            var stationData, def, type = ((graphic.attributes.StationType === 'River' )? 1:0);

            if (this.riverFlowStations["StationId_" + graphic.attributes.Id]) {
                stationData = this.riverFlowStations["StationId_" + graphic.attributes.Id];
            } else {
                def = this._getRiverOrLakeStationData(graphic.attributes.Id, type);
                def.then(lang.hitch(this, function (data) {
                    stationData = data;
                    this.riverFlowStations["StationId_" + graphic.attributes.Id] = stationData;
                }));
            }
            return stationData;
        },

        // get river flow or lake station data
        _getRiverOrLakeStationData: function (stationId, type) {
            return request.get(this.dataUrl + 'moduledata/waterquantity/getstations?stationId=' + stationId + '&isriver=' + type,
                {
                    handleAs: "json",
                    headers: { "X-Requested-With": null },
                    sync: true
                });
        },

        // load stations 
        //_loadStationData: function (jasonfile) {
        //    xhr(jasonfile, {
        //        sync: true,
        //        handleAs: "json"
        //    }).then(lang.hitch(this, function (data) {
        //        if (this.stationType === 'River')
        //        {
        //            this.riverStationData = data.stations;
        //        } else
        //        {
        //            this.lakeStationData = data.stations;
        //        }
                
        //    }));
        //},

        // create station graphic
        _createStationsGraphic: function (stationData) {
            var point, attributes, symbol;
            point = webMercatorUtils.geographicToWebMercator(new Point(stationData.Longitude, stationData.Latitude));
            attributes = {
                Id: stationData.Id,
                Number: stationData.Id,
                Name: stationData.name,
                StationType: stationData.StationType
            };
            symbol = new PictureMarkerSymbol(this.waterIconPath + this.stationIcon, 22, 22);
            return new Graphic(point, symbol, attributes);
        }

    });

    return _RiverFlowAndLakeLevelContent;
});