﻿/*property
    BacterialIndex, BacterialRatingCode, ECSite, Latitude, Longitude,
    MetalsIndex, MetalsRatingCode, Name, Number, NutrientsIndex,
    NutrientsRatingCode, Period, PesticidesIndex, PesticidesRatingCode,
    SITE_ID, Site, Station, StationName, StationNo, TOOLTIP_DIALOG_ID, Url,
    WaterQualityIndexRatingCode, Waterbody, Watershed,
    _createJOSMStationsGraphic, _createWaterQualityStationsGraphic,
    _getRiverQualityVerbose, _getStationIcon, _getWaterQualityStationData,
    _loadJOSMStations, add, addGraphics, addValue, attributeField, attributes,
    closeToolTipDialog, constructor, createInfoWindowSection, dataUrl,
    data_url, defaultLabel, defaultSymbol, environmentCanadaSite, forEach,
    geographicToWebMercator, get,  getRenderer, glossaryUrl,
    graphic, handleAs, headers, hideSpinner, hitch, indexOf,
    infoWindowHandlerContent, infoWindowHandlerTitle, infoWindowPopupId,
     josmFile, josmStations, label, lat_decimal,
    libraryUrl, long_decimal, mouseOutHandler, name, number, period,
    riverQualityStations, showGraphicTooltip, showToolTipDialog, site,
    stations, symbol, sync, then, toUrl, value, waterBody, waterIconPath,
    watershed, create, initInfoWindowModal, class,
    createInfoWindowAnchor, parentNode, pos, href, innerHTML, infoGlyphSign, className, onclickFunc, dataToggle, roleName, newWindowGlyphSign,
    targetName, createGlossaryAnchor, id, _createInfoWindowTab, infoWindowPopupId, _createDLLink,
    layer, _addJOSMStationsToLayer, _addWaterQualityStationsToLayer, _loadWaterQualityStations
*/
define([
    'dojo/_base/declare',
    'require', //this is a context-sensitive require
    'dojo/_base/lang',
    'dojo/_base/array',
    'dojo/request',
    'dojo/request/xhr',
    'dojo/dom-construct',
    './_BaseContent',
    'esri/symbols/PictureMarkerSymbol',
    'esri/geometry/webMercatorUtils',
    'esri/geometry/Point',
    'esri/renderers/UniqueValueRenderer',
    'esri/graphic',
    'app/mapping/Utils'
], function (declare, require, lang, array, request, xhr, domConstruct, _BaseContent,
    PictureMarkerSymbol, webMercatorUtils, Point, UniqueValueRenderer, Graphic, mapUtils) {
    'use strict';
    var _RiverQualityContent = declare("RiverQualityContent", [_BaseContent], {
        riverQualityStations: null,
        waterIconPath: require.toUrl("./images/water"),
        libraryUrl: '',
        dataUrl: '',
        josmFile: require.toUrl("./data/josm-stations.json"),
        TOOLTIP_DIALOG_ID: "riverQualityTooltipDialog",
        josmStations: null,
        constructor: function (options) {
            this.dataUrl = (options && options.dataUrl) ? options.dataUrl : siteConfig.dataUrl;
            this.libraryUrl = (options && options.libraryUrl) ? options.libraryUrl : siteConfig.libraryUrl;
            this.layer = null;
            // load water quality stations
            if (this.riverQualityStations === null) {
                this._loadWaterQualityStations();
            }
            //load JOSM stations
            if (this.josmStations === null) {
                this._loadJOSMStations();
            }
        },

        _loadWaterQualityStations: function() {
            var def = this._getWaterQualityStationData();
            def.then(lang.hitch(this, function (data) {
                this.riverQualityStations = data;
                this._addWaterQualityStationsToLayer();
            }));
        },

        _addWaterQualityStationsToLayer: function () {
            if (this.layer) {
                array.forEach(this.riverQualityStations, lang.hitch(this, function (item) {
                    if (item.Station && item.Station.Longitude !== null && item.Station.Latitude !== null) {
                        var feature = this._createWaterQualityStationsGraphic(item);
                        this.layer.add(feature);
                    }
                }));
            }
        },

        _addJOSMStationsToLayer: function () {
            if (this.layer) {
                array.forEach(this.josmStations, lang.hitch(this, function (item) {
                    var feature = this._createJOSMStationsGraphic(item);
                    this.layer.add(feature);
                }));
            }
        },

        // assign icon for river quality station
        getRenderer: function () {
            var defaultRiverFlowSymbol = new PictureMarkerSymbol(this.waterIconPath + '/River.png', 20, 21),
                riverQualityRenderer = new UniqueValueRenderer({ defaultSymbol: defaultRiverFlowSymbol, attributeField: 'WaterQualityIndexRatingCode', defaultLabel: 'Water Quality Stations' });
            riverQualityRenderer.addValue({ value: 'E', symbol: new PictureMarkerSymbol(this.waterIconPath + '/River_Excellent.png', 20, 21), label: 'Excellent' });
            riverQualityRenderer.addValue({ value: 'G', symbol: new PictureMarkerSymbol(this.waterIconPath + '/River_Good.png', 20, 21), label: 'Good' });
            riverQualityRenderer.addValue({ value: 'F', symbol: new PictureMarkerSymbol(this.waterIconPath + '/River_Fair.png', 20, 21), label: 'Fair' });
            riverQualityRenderer.addValue({ value: 'M', symbol: new PictureMarkerSymbol(this.waterIconPath + '/River_Marginal.png', 20, 21), label: 'Marginal' });
            riverQualityRenderer.addValue({ value: 'P', symbol: new PictureMarkerSymbol(this.waterIconPath + '/River_Poor.png', 20, 21), label: 'Poor' });
            return riverQualityRenderer;
        },

        //set info-window title
        infoWindowHandlerTitle: function (graphic) {
            var title;
            if (graphic.attributes.SITE_ID) {
                title = 'River Water Quality';
            } else if (graphic.attributes.Site) {

                title = 'River Water Quality - JOSM Site';
            } else {

                title = 'River Water Quality';
            }

            return title;
        },

        // set info-window content
        infoWindowHandlerContent: function (graphic) {
            var stationNosWithoutMoreData = ['AB05CE0009', 'AB05BE0190', 'AB05BN0080', 'AB05CJ0070', 'AB11AA0150'],
                
                contentNode = domConstruct.create("div", {}, null),
                sectionDiv = null;

            if (graphic.attributes.SITE_ID) { // RAMP water quality stations
                this.createInfoWindowSection(contentNode, 'first', 'infoWindowStationName infoWindowSection', graphic.attributes.SITE_ID);

                sectionDiv = this.createInfoWindowSection(contentNode, 'last');
                this.createInfoWindowAnchor({
                    parentNode: sectionDiv,
                    pos: 'last',
                    href: 'http://www.ramp-alberta.org/data/DataAccessAndUseAgreement.aspx?ReturnUrl=%2fdata%2fWater%2fWaterReport.aspx%3fsiteid%3d&siteid=' + graphic.attributes.SITE_ID,
                    innerHTML: this.newWindowGlyphSign + ' Station Reading ',
                    targetName: "_blank"
                });
            } else if (graphic.attributes.Site) { // JOSM stations
                this.createInfoWindowSection(contentNode, 'first', 'infoWindowStationName infoWindowSection', graphic.attributes.Name);
                this.createInfoWindowSection(contentNode, 'last', null, 'Number: ' + graphic.attributes.Number);
                this.createInfoWindowSection(contentNode, 'last', null, 'Water Body: ' + graphic.attributes.Waterbody);
                this.createInfoWindowSection(contentNode, 'last', null, 'Watershed: ' + graphic.attributes.Watershed);
                sectionDiv = this.createInfoWindowSection(contentNode, 'last');
                this.createInfoWindowAnchor({
                    parentNode: sectionDiv,
                    pos: 'last',
                    href: graphic.attributes.Url,
                    innerHTML: this.newWindowGlyphSign + "Data: " + graphic.attributes.Period,
                    targetName: "_blank"
                });
            } else { // Water quality stations
                this.createInfoWindowSection(contentNode, 'first', 'infoWindowStationName infoWindowSection', graphic.attributes.StationName);
                this.createInfoWindowSection(contentNode, 'last', null, 'Index (' + graphic.attributes.Period + ')');

                sectionDiv = this.createInfoWindowSection(contentNode, 'last');
                var tableNode = domConstruct.create('table', { 'class': 'infoWindowNumberTable' }, sectionDiv, 'last'),
                    tableBodyNode = domConstruct.create('tbody', {}, tableNode, 'last'),
                    // 1. Bacteria row
                    rowNode = domConstruct.create('tr', {}, tableBodyNode, 'last'),
                    // 1.1 Bacteria column
                    columnNode = domConstruct.create('td', {}, rowNode, 'last');
                this.createGlossaryAnchor(columnNode, 'last', 'Bacteria', 'Bacteria:', false);
                // 1.2 index column
                domConstruct.create('td', {
                     innerHTML: ' ' + ((graphic.attributes.BacterialIndex === null) ? 'N/A' : graphic.attributes.BacterialIndex)
                }, rowNode, 'last');
                // 1.3 link column
                columnNode = domConstruct.create('td', {}, rowNode, 'last');
                this.createInfoWindowAnchor({
                    parentNode: columnNode,
                    pos: "last",
                    href: "http://esrd.alberta.ca/water/reports-data/alberta-river-water-quality-index.aspx",
                    innerHTML: " (" + this._getRiverQualityVerbose(graphic.attributes.BacterialRatingCode) + ")",
                    targetName: "_blank"
                });

                // 2. Metals row
                rowNode = domConstruct.create('tr', {}, tableBodyNode, 'last');
                // 2.1 Metals column
                columnNode = domConstruct.create('td', {}, rowNode, 'last');
                this.createGlossaryAnchor(columnNode, 'last', 'Metals', 'Metals:', false);
                // 2.2 index column
                domConstruct.create('td', {
                    innerHTML: ' ' + ((graphic.attributes.MetalsIndex === null) ? 'N/A' : graphic.attributes.MetalsIndex)
                }, rowNode, 'last');
                // 2.3 link column
                columnNode = domConstruct.create('td', {}, rowNode, 'last');
                this.createInfoWindowAnchor({
                    parentNode: columnNode,
                    pos: "last",
                    href: "http://esrd.alberta.ca/water/reports-data/alberta-river-water-quality-index.aspx",
                    innerHTML: " (" + this._getRiverQualityVerbose(graphic.attributes.MetalsRatingCode) + ")",
                    targetName: "_blank"
                });

                // 3. Pesticides row
                rowNode = domConstruct.create('tr', {}, tableBodyNode, 'last');
                // 3.1 Pesticides column
                columnNode = domConstruct.create('td', {}, rowNode, 'last');
                this.createGlossaryAnchor(columnNode, 'last', 'Pesticides', 'Pesticides:', false);
                // 3.2 index column
                domConstruct.create('td', {
                    innerHTML: ' ' + ((graphic.attributes.PesticidesIndex === null) ? 'N/A' : graphic.attributes.PesticidesIndex)
                }, rowNode, 'last');
                // 3.3 link column
                columnNode = domConstruct.create('td', {}, rowNode, 'last');
                this.createInfoWindowAnchor({
                    parentNode: columnNode,
                    pos: "last",
                    href: "http://esrd.alberta.ca/water/reports-data/alberta-river-water-quality-index.aspx",
                    innerHTML: " (" + this._getRiverQualityVerbose(graphic.attributes.PesticidesRatingCode) + ")",
                    targetName: "_blank"
                });

                // 4. Nutrients row
                rowNode = domConstruct.create('tr', {}, tableBodyNode, 'last');
                // 4.1 Nutrients column
                columnNode = domConstruct.create('td', {}, rowNode, 'last');
                this.createGlossaryAnchor(columnNode, 'last', 'Nutrients', 'Nutrients:', false);
                // 4.2 index column
                domConstruct.create('td', {
                    innerHTML: ' ' + ((graphic.attributes.NutrientsIndex === null) ? 'N/A' : graphic.attributes.NutrientsIndex)
                }, rowNode, 'last');
                // 4.3 link column
                columnNode = domConstruct.create('td', {}, rowNode, 'last');
                this.createInfoWindowAnchor({
                    parentNode: columnNode,
                    pos: "last",
                    href: "http://esrd.alberta.ca/water/reports-data/alberta-river-water-quality-index.aspx",
                    innerHTML: " (" + this._getRiverQualityVerbose(graphic.attributes.NutrientsRatingCode) + ")",
                    targetName: "_blank"
                });               
                
                // link to DL page (available only for these stations)
                if (graphic.attributes.StationNo === 'AB07BE0010') {
                    this._createDLLink(contentNode, this.libraryUrl + "/Dataset/Details/65", this.newWindowGlyphSign + "More Water Quality Index Detail");
                } else if (graphic.attributes.StationNo === 'AB07CC0030') {
                    this._createDLLink(contentNode, this.libraryUrl + "/Dataset/Details/66", this.newWindowGlyphSign + "More Water Quality Index Detail");
                } else if (graphic.attributes.StationNo === 'AB07DD0010') {
                    this._createDLLink(contentNode, this.libraryUrl + "/Dataset/Details/67", this.newWindowGlyphSign + "More Water Quality Index Detail");
                } else if (graphic.attributes.StationNo === 'AB07HF0010') {
                    this._createDLLink(contentNode, this.libraryUrl + "/Dataset/Details/68", this.newWindowGlyphSign + "More Water Quality Index Detail");
                }

                //don't show more data link for stations that aren't in the report
                if (array.indexOf(stationNosWithoutMoreData, graphic.attributes.StationNo) < 0)
                {
                    this._createDLLink(contentNode, this.libraryUrl + "Redirect/WaterQuality?StationNo=" + graphic.attributes.StationNo, this.newWindowGlyphSign + "More Water Quality Data");
                }               
            }

            this.hideSpinner();
            return contentNode;
        },
        _createDLLink: function (parentNode, href, innerHtml) {
            var sectionDiv = this.createInfoWindowSection(parentNode, 'last');
            this.createInfoWindowAnchor({
                parentNode: sectionDiv,
                pos: 'last',
                href: href,
                innerHTML: innerHtml,
                targetName: "_blank"
            });
        },
        showGraphicTooltip: function (event) {
            if (event.graphic.attributes.StationName) {
                mapUtils.showToolTipDialog(event, this.TOOLTIP_DIALOG_ID, event.graphic.attributes.StationName);
            } else if (event.graphic.attributes.SITE_ID) {
                mapUtils.showToolTipDialog(event, this.TOOLTIP_DIALOG_ID, "Station Name: " + event.graphic.attributes.SITE_ID);
            } else {
                mapUtils.showToolTipDialog(event, this.TOOLTIP_DIALOG_ID, "Station Name: " + event.graphic.attributes.Name);
            }
        },
        mouseOutHandler: function () {
            mapUtils.closeToolTipDialog(this.TOOLTIP_DIALOG_ID);
        },
        // add additional water quality stations
        addGraphics: function (layer) {
            this.layer = layer;
        },

        // create water quality station graphic
        _createWaterQualityStationsGraphic: function (waterStationData) {
            var point, attributes, symbol;
            point = webMercatorUtils.geographicToWebMercator(new Point(waterStationData.Station.Longitude, waterStationData.Station.Latitude));
            attributes = {
                StationNo: waterStationData.Station.StationNo,
                StationName: waterStationData.StationName,
                Period: waterStationData.Period,
                BacterialIndex: waterStationData.BacterialIndex,
                BacterialRatingCode: waterStationData.BacterialRatingCode,
                MetalsIndex: waterStationData.MetalsIndex,
                MetalsRatingCode: waterStationData.MetalsRatingCode,
                PesticidesIndex: waterStationData.PesticidesIndex,
                PesticidesRatingCode: waterStationData.PesticidesRatingCode,
                NutrientsIndex: waterStationData.NutrientsIndex,
                NutrientsRatingCode: waterStationData.NutrientsRatingCode,
                WaterQualityIndexRatingCode: waterStationData.WaterQualityIndexRatingCode
            };

            //symbol = this._getStationIcon(waterStationData.WaterQualityIndexRatingCode);
            symbol = new PictureMarkerSymbol(this.waterIconPath + '/River_Excellent.png', 22, 22);
            return new Graphic(point, symbol, attributes);
        },

        // create JOSM station graphic
        _createJOSMStationsGraphic: function (stationData) {
            var point, attributes, symbol;
            point = webMercatorUtils.geographicToWebMercator(new Point(stationData.long_decimal, stationData.lat_decimal));
            attributes = {
                Number: stationData.number,
                Name: stationData.name,
                Watershed: stationData.watershed,
                Waterbody: stationData.waterBody,
                Period: stationData.period,
                Url: stationData.data_url,
                Site: stationData.site,
                ECSite: stationData.environmentCanadaSite
            };
            symbol = new PictureMarkerSymbol(this.waterIconPath + '/River.png', 22, 22);
            return new Graphic(point, symbol, attributes);
        },

        //get station icon based on water quality index
        _getStationIcon: function (waterQualityIndexRatingCode) {
            var image, symbolWidth = 22, symbolHelight = 22;

            switch (waterQualityIndexRatingCode) {
                case "E":
                    image = "/River_Excellent.png";
                    break;
                case "G":
                    image = "/River_Good.png";
                    break;
                case "F":
                    image = "/River_Fair.png";
                    break;
                case "M":
                    image = "/River_Marginal.png";
                    break;
                case "P":
                    image = "/River_Poor.png";
                    break;
                default:
                    image = "/River.png";
                    symbolWidth = 22;
                    symbolHelight = 22;
            }

            return new PictureMarkerSymbol(this.waterIconPath + image, symbolHelight, symbolWidth);
        },

        // get water quality indices station data
        _getWaterQualityStationData: function () {
            return request.get(this.dataUrl + 'moduledata/waterquality/GetWaterQualityIndicesStationsData',
                {
                    handleAs: "json",
                    headers: { "X-Requested-With": null },
                    sync: false
                });
        },

        // get river quality verbose using code
        _getRiverQualityVerbose: function (code) {
            var quality;
            switch (code) {
                case "E":
                    quality = "Excellent";
                    break;
                case "G":
                    quality = "Good";
                    break;
                case "F":
                    quality = "Fair";
                    break;
                case "M":
                    quality = "Marginal";
                    break;
                case "P":
                    quality = "Poor";
                    break;
                default:
                    quality = "N/A";
            }
            return quality;
        },

        // load JOSM stations 
        _loadJOSMStations: function () {
            xhr(this.josmFile, {
                sync: false,
                handleAs: "json"
            }).then(lang.hitch(this, function (data) {
                this.josmStations = data.stations;
                this._addJOSMStationsToLayer();
            }));
        }

    });

    return _RiverQualityContent;
});