﻿/*property
    DEDICATED_DRY_POND_COLOR, DRY_POND_COLOR, FIELD_HECTARES, FIELD_LAND_AREA,
    FIELD_OPERATOR_NAME, FIELD_POND_NAME, FIELD_PROJECT_NAME,
    FIELD_TAILINGS_STRUCTURE, FIELD_VOLUME_MFT, FIELD_YEAR, MODE_SNAPSHOT,
    TOOLTIP_DIALOG_ID, TotalDedicatedDryingSurfaceArea,
    TotalDedicatedDryingSurfaceAreaHectares, TotalDrySurfaceArea,
    TotalDrySurfaceAreaHectares, TotalSurfaceArea, TotalSurfaceAreaHectares,
    TotalWetSurfaceArea, TotalWetSurfaceAreaHectares, WET_POND_COLOR,
    _addMergedFeatureToLayer, _createOwnInfoTemplate, _dataUrl, _isWetPond,
    _layer, _loadTailingsPondLocationsSuccess, _tailingsPonds,
    addGraphicFeatureToLayer, addGraphics, addValue, aewError, attributeField,
    attributes, closeToolTipDialog, constructor, createFeatureLayer,
    createInfoWindowSection, dataUrl, dedicatedDryFeature,
    dedicatedDryingFillSymbol, dedicatedryPondsGeometries, defaultLabel,
    defaultSymbol, dryFeature, dryFillSymbol, dryPondsGeometries, featureSet,
    features, forEach, format, generateId, geometry, getInfoTemplate,
     getRenderer, getSimpleFillSymbol, glossaryUrl, graphic,
    hasOwnProperty, hideSpinner, hitch, id, indexOf, infoWindowHandlerContent,
    infoWindowHandlerTitle, infoWindowPopupId,  keys,
    label, layerDefinition, length, mode, mouseOutHandler, outFields, push,
    queryFeatureLayer, setGeometry, setInfoTemplate, showGraphicTooltip,
    showToolTipDialog, symbol, then, union, value, visible, wetFeature,
    wetFillSymbol, wetPondsGeometries, create,
    createGlossaryAnchor, innerHTML, createInfoWindowAnchor, parentNode, pos, href, innerHTML,
    targetName, infoGlyphSign
*/
define([
    'dojo/_base/declare',
    'dojo/_base/lang',
    'dojo/_base/array',
    'dojo/number',
    'dojo/dom-construct',
    'esri/layers/FeatureLayer',
    'esri/renderers/UniqueValueRenderer',
    'esri/geometry/geometryEngine',
    'esri/geometry/geometryEngineAsync',
    'app/content/_BaseContent',
    'app/utils/Common',
    'app/mapping/Utils'
], function (declare, lang, array, number, domConstruct, FeatureLayer, UniqueValueRenderer, geometryEngine, geometryEngineAsync, _BaseContent, commonUtils, mapUtils
    ) {
    'use strict';
    return declare("TailingsPondContent", [_BaseContent], {
        // Tailing pond field names in feature data retrieved from genesis
        FIELD_TAILINGS_STRUCTURE: "TAILINGS_STRUCTURE",
        FIELD_POND_NAME: "POND_NAME",
        FIELD_YEAR: "YEAR",
        FIELD_LAND_AREA: "LAND_AREA",
        FIELD_HECTARES: "HECTARES",
        FIELD_VOLUME_MFT: "VOLUME_MFT",
        FIELD_PROJECT_NAME: "PROJECT_NAME",
        FIELD_OPERATOR_NAME: "OPERATOR_NAME",
        // colors to distinguish wet and dry ponds
        DRY_POND_COLOR: "#FFAA00",
        WET_POND_COLOR: "#ffc859",
        DEDICATED_DRY_POND_COLOR: "#E26229", // R: 226, G: 98, B: 41
        TOOLTIP_DIALOG_ID: "tailingsPondTooltipDialog",
        _createOwnInfoTemplate: true, // prevent Content group from applying infoTemplate to the whole layer, we need to create infotemplate for each graphic object
        _layer: null,
        constructor: function (options) {
            this._tailingsPonds = {}; //variable for calculating and storing pond surface area and volume values
            this._dataUrl = (options && options.dataUrl) ? options.dataUrl : siteConfig.dataUrl;
            this.dryFillSymbol = mapUtils.getSimpleFillSymbol(this.DRY_POND_COLOR, 1, this.DRY_POND_COLOR, 1);
            this.wetFillSymbol = mapUtils.getSimpleFillSymbol(this.WET_POND_COLOR, 1, this.WET_POND_COLOR, 1);
            this.dedicatedDryingFillSymbol = mapUtils.getSimpleFillSymbol(this.DEDICATED_DRY_POND_COLOR, 1, this.DEDICATED_DRY_POND_COLOR, 1);
        },
        createFeatureLayer: function (layerDefinition, layerId) {
            var featureCollection = {
                layerDefinition: layerDefinition,
                featureSet: null
            };
            return new FeatureLayer(featureCollection, { id: layerId, visible: false, mode: FeatureLayer.MODE_SNAPSHOT });
        },
        addGraphics: function (layer, mapServerUrl, options, iniExtent) {
            this._layer = layer;

            return mapUtils.queryFeatureLayer(lang.hitch(this, this._loadTailingsPondLocationsSuccess),
                commonUtils.aewError, mapServerUrl, options.outFields, iniExtent);
        },
        getRenderer: function() {
            var dryPondLabel = "Dry Tailings",
                wetPondLabel = "Wet Tailings",
                dedicatedDryPondLabel = "Dedicated Dry Tailings",
                tailingsPondRenderer = new UniqueValueRenderer({
                    defaultSymbol: this.dryFillSymbol,
                    attributeField: this.FIELD_TAILINGS_STRUCTURE,
                    defaultLabel: dryPondLabel
                });
            
            tailingsPondRenderer.addValue({
                value: "04",
                symbol: this.wetFillSymbol,
                label: wetPondLabel
            });
            tailingsPondRenderer.addValue({
                value: "07",
                symbol: this.wetFillSymbol,
                label: wetPondLabel
            });
            tailingsPondRenderer.addValue({
                value: "08",
                symbol: this.dedicatedDryingFillSymbol,
                label: dedicatedDryPondLabel
            });

            return tailingsPondRenderer;
        },
        infoWindowHandlerTitle: function (graphic) {
            return graphic.attributes[this.FIELD_PROJECT_NAME];
        },
        infoWindowHandlerContent: function (graphic) {
            var pondName = graphic.attributes[this.FIELD_POND_NAME],
                pondType = graphic.attributes[this.FIELD_TAILINGS_STRUCTURE],
                year = graphic.attributes[this.FIELD_YEAR],
                sectionPond = null,
                sectionTotalArea = "Total Surface Area: " +number.format(this._tailingsPonds[pondName].TotalSurfaceArea / 1000000) + " km<span class='superscript'>2</span> (" + year + ")",
                sectionSubAreaTitle = null,
                sectionSubArea = null,
                glossaryKeyword = null,
                contentNode = domConstruct.create("div", {}, null),
                sectionDiv = null;

            this.createInfoWindowSection(contentNode, "first", null, "Operator: " + graphic.attributes[this.FIELD_OPERATOR_NAME]);

            if (this._isWetPond(pondType)) { // Wet
                if (pondName) {
                    sectionPond = "Pond: " + pondName + ", Wet Tailings Area";
                }
                glossaryKeyword = "Wet_Tailings";
                sectionSubAreaTitle = "Wet Tailings Surface Area: ";
                sectionSubArea = number.format(this._tailingsPonds[pondName].TotalWetSurfaceArea / 1000000)
                                 + " km<span class='superscript'>2</span> (" + year + ")";                  
            } else if (pondType === "08") { // dedicatedDry
                if (pondName) {
                    sectionPond = "Pond: " + pondName + ", Dedicated Dry Tailings Area";
                }
                glossaryKeyword = "DedicatedDry_Tailings";
                sectionSubAreaTitle = "Dedicated Drying Surface Area: ";
                sectionSubArea = number.format(this._tailingsPonds[pondName].TotalDedicatedDryingSurfaceArea / 1000000)
                                 + " km<span class='superscript'>2</span> (" + year + ")";
            } else { // Dry
                if (pondName) {
                    sectionPond = "Pond: " + pondName + ", Dry Tailings Area";
                }
                glossaryKeyword = "Dry_Tailings";
                sectionSubAreaTitle = "Dry Tailings Surface Area: ";
                sectionSubArea = number.format(this._tailingsPonds[pondName].TotalDrySurfaceArea / 1000000)
                                 + " km<span class='superscript'>2</span> (" + year + ")";
            }

            if (sectionPond) {
                this.createInfoWindowSection(contentNode, "last", null, sectionPond);
            }

            this.createInfoWindowSection(contentNode, "last", null, sectionTotalArea);
            sectionDiv = this.createGlossaryAnchor(contentNode, "last", glossaryKeyword, sectionSubAreaTitle, null, true);
            if (sectionSubArea) {
                domConstruct.create('span', { innerHTML: sectionSubArea }, sectionDiv, "last");
            }

            sectionDiv = this.createInfoWindowSection(contentNode, "last");
            this.createInfoWindowAnchor({
                parentNode: sectionDiv,
                pos: "last",
                href: "http://aemeris.alberta.ca/library/Dataset/Details/431",
                innerHTML: "Download Shape Files",
                targetName: "_blank"
            });

            this.hideSpinner();
            return contentNode;
        },
        showGraphicTooltip: function (event) {
            var tipText = event.graphic.attributes[this.FIELD_PROJECT_NAME];               
            mapUtils.showToolTipDialog(event, this.TOOLTIP_DIALOG_ID, tipText);
        },
        mouseOutHandler: function () {
            mapUtils.closeToolTipDialog(this.TOOLTIP_DIALOG_ID);
        },
        _loadTailingsPondLocationsSuccess: function(data) {
            var pond,
                pondName,
                polygonArea,
                polygonAreaHectares,
                tailingsPondGeometries = {},
                infoTemplate = this.getInfoTemplate(lang.hitch(this, this.infoWindowHandlerTitle),
                    lang.hitch(this, this.infoWindowHandlerContent));
                    
            array.forEach(data.features, lang.hitch(this, function (feature) {
                feature.setInfoTemplate(infoTemplate);

                // 1. calculate pond area and volume
                // A) Total Tailings Pond Surface Area (= the total surface area of all the polygons with the same pond name as the polygon the user clicked on)
                // B) Total Wet Tailings Surface Area (= the total surface area of all the polygons with the same pond name as the polygon the user clicked on and TAILINGS_STRUCTURE = 4 or 7)
                // C) Total Dry Tailings Surface Area (= the total surface area of all the polygons with the same pond name as the polygon the user clicked on and TAILINGS_STRUCTURE = all except 4,7 or 8)
                // D) Total Volume (= the total volume of all the polygons with the same pond name as the polygon the user clicked on and TAILINGS_STRUCTURE = 4 or 7)
                // E) Total Dedicated Drying Tailings Surface Area (= the total surface area of all the polygons with the same pond name as the polygon the user clicked on and TAILINGS_STRUCTURE = 8)
                // We are no longer displaying volumes in the info window
                pondName = feature.attributes[this.FIELD_POND_NAME];
                if (this._tailingsPonds[pondName] === undefined) {
                    this._tailingsPonds[pondName] = {
                        TotalSurfaceArea: 0,
                        TotalSurfaceAreaHectares: 0,
                        TotalWetSurfaceArea: 0,
                        TotalWetSurfaceAreaHectares: 0,
                        TotalDrySurfaceArea: 0,
                        TotalDrySurfaceAreaHectares: 0,
                        TotalDedicatedDryingSurfaceArea: 0,
                        TotalDedicatedDryingSurfaceAreaHectares: 0
                    };
                }
                if (tailingsPondGeometries[pondName] === undefined) {
                    tailingsPondGeometries[pondName] = {
                        dryFeature: null,
                        dryPondsGeometries: [],
                        dedicatedDryFeature: null,
                        dedicatedryPondsGeometries: [],
                        wetFeature: null,
                        wetPondsGeometries: []
                    };
                }
                polygonArea = feature.attributes[this.FIELD_LAND_AREA];
                polygonAreaHectares = feature.attributes[this.FIELD_HECTARES];
                this._tailingsPonds[pondName].TotalSurfaceArea += polygonArea;
                this._tailingsPonds[pondName].TotalSurfaceAreaHectares += polygonAreaHectares;

                if (this._isWetPond(feature.attributes[this.FIELD_TAILINGS_STRUCTURE])) {
                    this._tailingsPonds[pondName].TotalWetSurfaceArea += polygonArea;
                    this._tailingsPonds[pondName].TotalWetSurfaceAreaHectares += polygonAreaHectares;
                    // save the geometry and first feature, we will merge all geometries and link it to the feature
                    tailingsPondGeometries[pondName].wetPondsGeometries.push(feature.geometry);
                    if (!tailingsPondGeometries[pondName].wetFeature) {
                        tailingsPondGeometries[pondName].wetFeature = feature;
                    }
                } else if (feature.attributes[this.FIELD_TAILINGS_STRUCTURE] === "08")
                {
                    this._tailingsPonds[pondName].TotalDedicatedDryingSurfaceArea += polygonArea;
                    this._tailingsPonds[pondName].TotalDedicatedDryingSurfaceAreaHectares += polygonAreaHectares;
                    tailingsPondGeometries[pondName].dedicatedryPondsGeometries.push(feature.geometry);
                    if (!tailingsPondGeometries[pondName].dedicatedDryFeature) {
                        tailingsPondGeometries[pondName].dedicatedDryFeature = feature;
                    }
                } else {
                    this._tailingsPonds[pondName].TotalDrySurfaceArea += polygonArea;
                    this._tailingsPonds[pondName].TotalDrySurfaceAreaHectares += polygonAreaHectares;
                    tailingsPondGeometries[pondName].dryPondsGeometries.push(feature.geometry);
                    if (!tailingsPondGeometries[pondName].dryFeature) {
                        tailingsPondGeometries[pondName].dryFeature = feature;
                    }
                }
            }));
            Object.keys(tailingsPondGeometries).forEach(function (tailingsPondName) {
                if (tailingsPondGeometries.hasOwnProperty(tailingsPondName)) {
                    pond = tailingsPondGeometries[tailingsPondName];
                    if (pond.dryFeature) {
                        this._addMergedFeatureToLayer(pond.dryPondsGeometries, pond.dryFeature, this.dryFillSymbol);
                    }
                    if (pond.dedicatedDryFeature) {
                        this._addMergedFeatureToLayer(pond.dedicatedryPondsGeometries, pond.dedicatedDryFeature, this.dedicatedDryingFillSymbol);
                    }
                    if (pond.wetFeature) {
                        this._addMergedFeatureToLayer(pond.wetPondsGeometries, pond.wetFeature, this.wetFillSymbol);
                    }
                }
            }, this);
        },
        _addMergedFeatureToLayer: function (geometries, feature, symbol) {
            if (geometries.length === 1) {
                feature.setGeometry(geometries[0]);
                mapUtils.addGraphicFeatureToLayer(this._layer, feature, symbol, commonUtils.generateId());
            } else if (geometries.length > 1) {
                if (Worker !== undefined) {
                    // Yes! Web worker support!
                    geometryEngineAsync.union(geometries).then(
                        lang.hitch(this, function (result) {
                            feature.setGeometry(result);
                            mapUtils.addGraphicFeatureToLayer(this._layer, feature, symbol, commonUtils.generateId());
                        }));
                } else {
                    // Sorry! No Web Worker support..
                    feature.setGeometry(geometryEngine.union(geometries));
                    mapUtils.addGraphicFeatureToLayer(this._layer, feature, symbol, commonUtils.generateId());
                }
            }
        },
        _isWetPond: function (value) {
            // wet ponds tailing structure values
            var wetTailingsStructureList = ["04", "07"];
            return (array.indexOf(wetTailingsStructureList, value) >= 0);
        }
    });
});