﻿/*property
    getProjectStatuses, _loadProjectStatuses, _projectStatuses, get, handleAs,
    headers, hitch, sync, then, _isProjectStatusesCallMade, push, filter, forEach, dataUrl, publish,
    _loadAirQualityStationNames, _isAirQualityStationNamesCallMade, getAirQualityStationNames, _airQualityStationNames,
    _projectsInfo, _isProjectsInfoCallMade, _enforcementTypes, _isEnforcementTypesCallMade, _projectsEmission,
    _isProjectsEmissionCallMade, getProjectsInfo, _loadProjectsInfo, getEnforcementTypes, _loadEnforcementTypes,
    getProjectsEmission, _loadProjectsEmission, _callWebService
*/
define([
    'dojo/_base/declare',
    'dojo/_base/lang',
    'dojo/topic',
    'dojo/request'
], function (declare, lang, topic, request) {
    'use strict';
    var WebServiceData = declare("WebServiceData", [], {
        _projectStatuses: null,
        _isProjectStatusesCallMade: false,
        _airQualityStationNames: null,
        _isAirQualityStationNamesCallMade: false,
        _projectsInfo: null,
        _isProjectsInfoCallMade: false,
        _enforcementTypes: null,
        _isEnforcementTypesCallMade: false,
        _projectsEmission: null,
        _isProjectsEmissionCallMade: false,

        getProjectStatuses: function () {
            if (!this._projectStatuses) {
                if (!this._isProjectStatusesCallMade) { // is already called?
                    this._isProjectStatusesCallMade = true;
                    var def = this._loadProjectStatuses(siteConfig.dataUrl);
                    def.then(lang.hitch(this, function (data) {
                        this._projectStatuses = data;
                        topic.publish('getProjectStatuses/DataIsReady', this._projectStatuses);
                    }));
                }
            } else {
                topic.publish('getProjectStatuses/DataIsReady', this._projectStatuses);
            }
        },
        getAirQualityStationNames: function () {
            if (!this._airQualityStationNames) {
                if (!this._isAirQualityStationNamesCallMade) { // is already called
                    this._isAirQualityStationNamesCallMade = true;
                    var def = this._loadAirQualityStationNames(siteConfig.dataUrl);
                    def.then(lang.hitch(this, function (data) {
                        this._airQualityStationNames = data;
                        topic.publish('getAirQualityStationNames/DataIsReady', this._airQualityStationNames);
                    }));
                }
            } else {
                topic.publish('getAirQualityStationNames/DataIsReady', this._airQualityStationNames);
            }
        },
        getProjectsInfo: function() {
            if (!this._projectsInfo) {
                if (!this._isProjectsInfoCallMade) { // is already called
                    this._isProjectsInfoCallMade = true;
                    var def = this._loadProjectsInfo(siteConfig.dataUrl);
                    def.then(lang.hitch(this, function (data) {
                        this._projectsInfo = data;
                        topic.publish('getProjectsInfo/DataIsReady', this._projectsInfo);
                    }));
                }
            } else {
                topic.publish('getProjectsInfo/DataIsReady', this._projectsInfo);
            }
        },
        getEnforcementTypes: function () {
            if (!this._enforcementTypes) {
                if (!this._isEnforcementTypesCallMade) { // is already called
                    this._isEnforcementTypesCallMade = true;
                    var def = this._loadEnforcementTypes(siteConfig.dataUrl);
                    def.then(lang.hitch(this, function (data) {
                        this._enforcementTypes = data;
                        topic.publish('getEnforcementTypes/DataIsReady', this._enforcementTypes);
                    }));
                }
            } else {
                topic.publish('getEnforcementTypes/DataIsReady', this._enforcementTypes);
            }
        },
        getProjectsEmission: function () {
            if (!this._projectsEmission) {
                if (!this._isProjectsEmissionCallMade) { // is already called
                    this._isProjectsEmissionCallMade = true;
                    var def = this._loadProjectsEmission(siteConfig.dataUrl);
                    def.then(lang.hitch(this, function (data) {
                        this._projectsEmission = data;
                        topic.publish('getProjectsEmission/DataIsReady', this._projectsEmission);
                    }));
                }
            } else {
                topic.publish('getProjectsEmission/DataIsReady', this._projectsEmission);
            }
        },
        // load projects status data 
        _loadProjectStatuses: function (dataUrl) {
            return this._callWebService(dataUrl + 'moduledata/Projects/GetProjectStatuses/');
        },
        _loadAirQualityStationNames: function (dataUrl) {
            return this._callWebService(dataUrl + 'moduledata/AirQualityArchive/GetAllStationIdNames/');
        },
        _loadProjectsInfo: function (dataUrl) {
            return this._callWebService(dataUrl + 'moduledata/Projects/GetAllProjectInfoObjects/');
        },
        _loadEnforcementTypes: function (dataUrl) {
            return this._callWebService(dataUrl + 'moduledata/Projects/GetAllEnforcementTypes/');
        },
        _loadProjectsEmission: function (dataUrl) {
            return this._callWebService(dataUrl + 'moduledata/ClimateChange/GetAllProjectEmissionsIntensityInfo/');
        },
        _callWebService : function(url) {
            return request.get(url, {
                handleAs: "json",
                headers: { "X-Requested-With": null },
                sync: false
            });
        }
    });
    if (_instance === undefined) {//This is a singleton pattern. This check is to ensure another instance doesn't exist. jslint doesn't like this line.
        var _instance = new WebServiceData();
    }
    return _instance;
});