﻿/*property
    _initInfoWindowModal, addGraphics, attributes, body, byId, clickHandler,
    constructor, createFeatureLayer, createInfoWindowPopups, display, forEach,
    getDefinitionExpression, getInfoTemplate, getRenderer, hideSpinner,
    infoWindowHandlerContent, infoWindowHandlerTitle, infoWindowMessagePopupId,
    infoWindowPopupId,  glossarylinkFunc, initInfoWindowModal, innerHTML,
    keys, length, mapControl, place, setAttribute, setContent, setMapControl,
    setTitle, showGraphicTooltip, showSpinner, src, style, publish, infoGlyphSign, newWindowGlyphSign,
    infoWindowPopupId, infoWindowMessagePopupId, messageDialogueId, link, message, createInfoWindowSection,
    createInfoWindowAnchor, dialogueTitle, dialogueId, create, notShowLoading, class, parentNode, pos, href, set, 
    onclickFunc, dataToggle, roleName, className, targetName, createGlossaryAnchor, hitch
*/
define([
    'dojo/_base/lang',
    'dojo/_base/declare',
    'dojo/dom',
    'dojo/query',
    'dojo/dom-construct',
    'dojo/dom-attr',
    'dojo/_base/window',
    'dojo/topic',
    'esri/InfoTemplate'
], function (lang, declare, dom, query, domConstruct, domAttr, win, topic, InfoTemplate) {
    'use strict';
    var _BaseContent = declare("_BaseContent", [], {
        constructor: function (ignore) {
            this.mapControl = null;
            this.infoGlyphSign = '<span class="glyphicon glyphicon-info-sign"></span>';
            this.newWindowGlyphSign = '<span class="glyphicon glyphicon-new-window"></span>';
            this.infoWindowMessagePopupId = "infoWindowModalWithMessage";
            this.infoWindowPopupId = "infoWindowModal";

            // create infowindow popup dialogues, only once
            if (!window.createInfoWindowPopups) {
                window.createInfoWindowPopups = true;
                var infoWindowModalWithMessageMarkup = '<div class="modal fade popup-container in" id="' + this.infoWindowMessagePopupId
                    + '" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">'
                    + '<div class="vertical-alignment-helper">'
                    + '<div class="modal-dialog vertical-align-center">'
                    + '<div class="modal-content noBackground">'
                    + '<div class="modal-header">'
                    + '<button type="button" class="close noText" data-dismiss="modal" aria-hidden="true">×</button>'
                    + '</div>'
                    + '<div class="modal-body message">'
                    + '</div>'
                    + '<div class="modal-footer">'
                    + '<button class="btn btn-sm" data-dismiss="modal" data-toggle="modal" data-target="#infoWindowModal">OK</button>'
                    + '</div>'
                    + '</div>'
                    + '</div>'
                    + '</div>',
                infoWindowModalMarkup = '<div class="modal in" id="' + this.infoWindowPopupId + '" tabindex="-1" role="dialog" aria-labelledby="myModalLabel" aria-hidden="true">'
                    + '<div class="vertical-alignment-helper">'
                    + '<div class="modal-dialog vertical-align-center">'
                    + '<div class="modal-content">'
                    + '<div class="modal-header">'
                    + '</div>'
                    + '<div id="divInfoWindowModalLoading" class="modal-loading-panel modal-loading">'
                    + '</div>'
                    + '<div id="divInfoWindowModalIFrame" class="modal-body">'
                    + '<iframe src="" id="infoWindowModalIFrame" onload="'
                    + '{'
                    + "  document.getElementById('divInfoWindowModalLoading').style.display = 'none';"
                    + "  document.getElementById('divInfoWindowModalIFrame').style.display = 'block';"
                    + '}"></iframe>'
                    + '</div>'
                    + '<div class="modal-footer">'
                    + '<button type="button" class="btn btn-default" data-dismiss="modal">Close</button>'
                    + '</div>'
                    + '</div>'
                    + '</div>'
                    + '</div>'
                    + '</div>';

                domConstruct.place(infoWindowModalWithMessageMarkup, win.body(), "last");
                domConstruct.place(infoWindowModalMarkup, win.body(), "last");
            }
        },
        initInfoWindowModal: function (params) {
            var dialogueId = params.dialogueId,
                messageDialogueId = params.messageDialogueId,
                style = params.style,
                link = params.link,
                message = params.message,
                dialogueTitle = params.dialogueTitle,
                notShowLoading = params.notShowLoading,
                iFrameNode = query("#" + dialogueId + " iframe")[0],
                        dialogueHeaderNode = query("#" + dialogueId + " .modal-header")[0],
                        dialogueContentNode = query("#" + dialogueId + " .modal-content")[0],
                        messageNode = query("#" + messageDialogueId + " .modal-body")[0],
                        encodedlink = encodeURI(link);

            if (iFrameNode && iFrameNode.src !== encodedlink) {
                iFrameNode.src = encodedlink;
                if (dialogueContentNode && style) {
                    dialogueContentNode.setAttribute('class', style);
                }

                if (dialogueHeaderNode) {
                    if (dialogueTitle && dialogueTitle.length > 0) {
                        dialogueHeaderNode.innerHTML = dialogueTitle
                            + '<button type="button" class="close" data-dismiss="modal" aria-hidden="true">'
                            + 'x' + '</button>';
                    } else {
                        dialogueHeaderNode.innerHTML = '<button type="button" class="close noText" data-dismiss="modal" aria-hidden="true">'
                            + 'x' + '</button>';
                    }
                }

                if (notShowLoading) {
                    dom.byId('divInfoWindowModalLoading').style.display = "none";
                    dom.byId('divInfoWindowModalIFrame').style.display = "block";
                } else {
                    dom.byId('divInfoWindowModalLoading').style.display = "block";
                    dom.byId('divInfoWindowModalIFrame').style.display = "none";
                }
            }

            if (message && messageNode && messageNode.innerHTML !== message) {
                messageNode.innerHTML = message;
            }
        },
        createInfoWindowSection: function (parentNode, pos, className, content) {
            var sectionDiv = null;
            if (className) {
                sectionDiv = domConstruct.create("div", { 'class': className }, parentNode, pos);
            } else {
                sectionDiv = domConstruct.create("div", { 'class': 'infoWindowSection' }, parentNode, pos);
            }
            if (content) {
                domConstruct.create('span', { innerHTML: content }, sectionDiv, 'first');
            }
            return sectionDiv;

        },
        createInfoWindowAnchor: function (params) {
            var anchorNode = domConstruct.create("a", {
                innerHTML: params.innerHTML
            }, params.parentNode, params.pos);

            if (params.href) {
                domAttr.set(anchorNode, "href", params.href);
            }
            if (params.onclickFunc) {
                domAttr.set(anchorNode, "onclick", params.onclickFunc);
            }
            if (params.className) {
                domAttr.set(anchorNode, "class", params.className);
            }
            if (params.dataToggle) {
                domAttr.set(anchorNode, "data-toggle", params.dataToggle);
            }
            if (params.roleName) {
                domAttr.set(anchorNode, "role", params.roleName);
            }
            if (params.targetName) {
                domAttr.set(anchorNode, "target", params.targetName);
            }
        },
        createGlossaryAnchor: function (parentNode, pos, keyword, anchorInnerHtml, description, createSection) {
            var node = null;
            if (createSection) {
                node = this.createInfoWindowSection(parentNode, pos, null, description);
            } else {
                node = parentNode;
            }

            this.createInfoWindowAnchor({
                parentNode: node,
                pos: 'last',
                onclickFunc: lang.hitch(this, function () {
                    topic.publish('PortalGlossary/ShowModal', keyword);
                }),
                innerHTML: anchorInnerHtml,
                className: "popupGlossaryLink",
                targetName: "_blank"
            });

            return node;
        },

        setMapControl: function (paraMapControl) {
            this.mapControl = paraMapControl;
        },
        clickHandler: function (ignore) {
            if (this.mapControl) {
                this.mapControl.showSpinner();
            }            
        },
        hideSpinner: function() {
            if (this.mapControl) {
                this.mapControl.hideSpinner();
            }
        },
        getInfoTemplate: function (templateTitle, templateContent) {
            var infoTemplate = new InfoTemplate();

            if (templateTitle) {
                infoTemplate.setTitle(templateTitle);
            }

            if (templateContent) {
                infoTemplate.setContent(templateContent);
            }
            return infoTemplate;
        },
        infoWindowHandlerContent: function (graphic) {
            var content = '';
            Object.keys(graphic.attributes).forEach(function(attribute) {
                content += attribute + ' : ' + graphic.attributes[attribute] + '<br />';
            });
            this.hideSpinner();
            return content;
        },
        // set virtual functions to null, 
        // otherwise the judgement in ContentGroup is always true even when these functions are not defined in subclass
        // then basecontent functions are applied to subclass which causes error when the layer is graphicLayer
        getRenderer: null,
        getDefinitionExpression: null,
        addGraphics: null,   
        infoWindowHandlerTitle: null,
        showGraphicTooltip: null,
        createFeatureLayer: null
    });
    return _BaseContent;
});