﻿/*property
    _createContent, _createLegend, _getAnchorOptionsforGlossaryLinks, byId,
    constructor, contentGroups, create, dataUrl, forEach, glossaryAnchorTage,
    glossaryLinks, glossaryUrl, group, hitch, iconGroupId, iconGroupName,
    iconName, id, inherited, label, legendIcons, legendNodeId, length,
    multiLayers, operationLayers, operationalLayers, options, place,
    postCreate, push, subGroups, tag, templateString, theMap, visible,
    visibleLayersIds,visibleLayers,_createLegendIcons
*/

define([
    'dojo/_base/declare',
    'dojo/_base/array',
    'dojo/_base/lang',
    'dojo/dom',
    'dojo/query',
    'dojo/dom-construct',
    'dijit/_WidgetBase',
    'dijit/_TemplatedMixin',
    'dojo/text!./templates/MapLegend.html',
    'app/mapping/Utils'
], function (declare, array, lang, dom, query, domConstruct, _WidgetBase, _TemplatedMixin, template, mapUtils) {
    //'use strict';//can't use strict here because of use of special var arguments 
    return declare([_WidgetBase, _TemplatedMixin], {
        templateString: template,
        theMap: null,
        contentGroups: null,
        legendNodeId: null,
        operationLayers: null,
        dataUrl: '',
        glossaryLinks: [],
        postCreate: function () {
            this.inherited(arguments);
            this._createLegend();
        },
        constructor: function (options) {
            this.dataUrl = options.dataUrl || siteConfig.dataUrl;
        },
        _createLegend: function () {

            var legendNode = domConstruct.create("div", null, dom.byId(this.legendNodeId), 'last'),
                content = '', displayStyle;

            //operational layers
            array.forEach(this.operationLayers, function (operationalLayer) {
                displayStyle = '" style ="display:none" >';
                if (operationalLayer.legendIcons) {

                    if (operationalLayer.options.visible) {
                        displayStyle = '" style ="display:block" >';
                    }

                    content += '<div id ="' + operationalLayer.options.id + displayStyle;

                    array.forEach(operationalLayer.legendIcons, function (legendIcon) {
                        content += '<img src="' + legendIcon.iconName + '"/>';
                        content += '<span>' + legendIcon.label + '</span><br/>';
                    }, this);

                    content += '</div>';
                }
            }, this);

            // Content Groups
            this.contentGroups.group.forEach(lang.hitch(this, function (contentGroup) {
                contentGroup.operationalLayers.forEach(lang.hitch(this, function (layerConfig) {
                    content += this._createLegendIcons(layerConfig);
                }));
            }));

            domConstruct.place(content, legendNode);
            // add glossary links
            if (this.glossaryLinks.length > 0) {
                array.forEach(this.glossaryLinks, function (link) {
                    query('[name="' + link.label + '"]').forEach(lang.hitch(this, function (subGroupNode) {
                        var option = mapUtils._getAnchorOptionsforGlossaryLinks(link.label, link.tag, "legendGlossaryLink"),
                            node = domConstruct.create("a", option);
                        domConstruct.place(node, subGroupNode, "replace");
                    }));

                }, this);
            }
        },
        
        _createLegendIcons: function (layerConfig) {
            var displayStyle = '" style ="display:none" >',
                layerid = null,
                groupExist = false,
                content = '';

            if (layerConfig.subGroups) {
                layerConfig.subGroups.forEach(lang.hitch(this, function (subGroup) {
                    if (subGroup.operationalLayers) {
                        subGroup.operationalLayers.forEach(lang.hitch(this, function (layerConfig) {
                            content += this._createLegendIcons(layerConfig);
                        }));
                    }
                }));
            } else {
                if (layerConfig.legendIcons) {
                    if (layerConfig.options.visible) {
                        displayStyle = '" style ="display:block" >';
                    }

                    layerid = (layerConfig.options.visibleLayers !== undefined) ? layerConfig.options.id + '-' + layerConfig.options.visibleLayers : layerConfig.options.id;
                    groupExist = false;
                    content += '<div id ="' + layerid + displayStyle;

                    layerConfig.legendIcons.forEach(lang.hitch(this, function (legendIcon) {
                        if (legendIcon.iconGroupId) {
                            groupExist = true;
                        }
                        content += this._createContent(legendIcon);
                    }));

                    if (groupExist) {
                        content += '</div>';
                    }
                    content += '</div>';
                } else {
                    if (layerConfig.options.multiLayers) {
                        array.forEach(layerConfig.options.multiLayers, function (multiLayer) {
                            if (multiLayer.legendIcons) {
                                groupExist = false;
                                content += '<div id ="' + layerConfig.options.id + '-' + multiLayer.visibleLayersIds + '" style ="display:none" >';

                                array.forEach(multiLayer.legendIcons, function (legendIcon) {

                                    if (legendIcon.iconGroupId) {
                                        groupExist = true;
                                    }
                                    content += this._createContent(legendIcon);
                                }, this);

                                if (groupExist) {
                                    content += '</div>';
                                }
                                content += '</div>';
                            }
                        }, this);
                    }
                }
            }
            return content;
        },

        // create content for legend
        _createContent: function (legendIcon) {
            var legendContent = '';

            if (legendIcon.iconGroupId) {
                legendContent += '<a href="#" class="dropdown-toggle btn btn-primary legendGroupButton dark-blue-bg white" data-toggle="collapse" data-target="#' + legendIcon.iconGroupId + '" data-dojo-dataid="' + legendIcon.iconGroupId + '" >' + legendIcon.iconGroupName + '<b class="caret"></b></a>';
                legendContent += '<div id="' + legendIcon.iconGroupId + '" class="collapse in" style="height: auto;">';
            } else if (legendIcon.iconName === undefined && legendIcon.label) {
                legendContent += '<label>' + legendIcon.label + '</label> <br/>';
            } else {

                legendContent += '<img src="' + legendIcon.iconName + '"/>';

                // glossary links 
                if (legendIcon.glossaryAnchorTage) {
                    legendContent += '<a target="_blank" id="' + legendIcon.glossaryAnchorTage + '" name="' + legendIcon.label + '">' + legendIcon.label + '</a><br/>';
                    this.glossaryLinks.push({ tag: legendIcon.glossaryAnchorTage, label: legendIcon.label });

                } else {
                    legendContent += '<span>' + legendIcon.label + '</span> <br/>';
                }

            }
            return legendContent;
        }

    });
});