﻿/*property
    _addContent, _addEventHandler, _addMouseEventHandler, _buildLayerControls,
    _createOwnInfoTemplate, _hideInfoTemplate, _initLayer, _initSubLayerGroups,
    _setFocus, addGraphics, addLayer, attributes, byId, class, clickHandler,
    collapse, collapseBodyId, collapseId, constructor, contentGroup,
    contentGroupDiv, contentGroupNodeId, create, createFeatureLayer,
    currentTarget, customModule, defaultIconforRenderer, dynamic, extent,
    feature, focus, focusElementId, focusGroupId, forEach,
    getDefinitionExpression, getInfoTemplate, getRenderer, graphics, hitch,
    iconClass, id, infoTemplate, infoWindow, infoWindowHandlerContent,
    infoWindowHandlerTitle, iniExtent, layer, layerConfig, layerDefinition,
    layerInfos, layerOrder, map, mapControls, mapNode, mouseOutHandler, name,
    nodeToAppendTo, operationalLayers, options, parentGroupId, place,
    postCreate, resize, resourceInfo, setDefinitionExpression, setMapControl,
    setRenderer, setVisibleLayers, showGraphicTooltip, subGroupId, subLayers,
    templateString, theMap, tiled, title, type, unshift, url, value,
    visibleLayers, wkid, wms, wmsName, xmax, xmin, ymax, ymin,_createLayers,subGroups,
    performTasksAfterLayerCreated, visibilityChangeHandler
*/

define([
    'dojo/_base/declare',
    'dojo/_base/array',
    'dojo/_base/lang',
    'dojo/dom',
    'dojo/on',
    'dojo/query',
    'dojo/dom-construct',
    'dojo/has',
    'dijit/focus',
    'esri/geometry/Extent',
    'esri/layers/WMSLayerInfo',
    'app/mapping/Utils',
    'dijit/_WidgetBase',
    'dijit/_TemplatedMixin',
    'dojo/text!./templates/Map.html',
    'esri/layers/WMSLayer',
    'dojo-bootstrap/Collapse'
], function (declare, array, lang, dom, on, query, domConstruct, has, focusUtil, Extent, WMSLayerInfo, mapUtils, _WidgetBase, _TemplatedMixin, template) {
    'use strict';
    var _ContentGroup = declare('_ContentGroup', [_WidgetBase, _TemplatedMixin], {
        templateString: template,
        theMap: null,
        contentGroup: null,
        iniExtent: null,
        contentGroupNodeId: null,
        postCreate: function () {
            // NOTE: BootstrapMap needs to work off an id
            this.mapNode.id = this.contentGroup.id;
        },
        constructor: function (paraContentGroup, paraMapControls, paraMap, paraIniExtent, paraContentGroupNodeId) {
            this.contentGroup = paraContentGroup;
            this.mapControls = paraMapControls;
            this.theMap = paraMap;
            this.iniExtent = paraIniExtent;
            this.contentGroupNodeId = paraContentGroupNodeId;
            this._addContent();
        },

        _addContent: function () {
            var layers = [], contentGroupPanelMarkup = "", focusElement = '',
                collapseId = "collapse" + this.contentGroup.id,
                collapseBodyId = collapseId + "-body";

            if (this.contentGroup.focusElementId) {
                focusElement = " data-focus-elementid='layerControl-" + this.contentGroup.focusElementId + "'";
            }

            if (this.contentGroup.focusGroupId) {
                focusElement = " data-focus-elementid='" + this.contentGroup.focusGroupId + "'";
            }

            contentGroupPanelMarkup += "<div class='panel' id='" + this.contentGroup.id + "'><div class='panel-heading' role='tab' id='headingOne'><h4 class='panel-title'>"
                + "<a role='button' class='btn' data-toggle='collapse' data-target='#" + collapseId + "'>"
                + "<span class='aemera-icon " + this.contentGroup.iconClass + "'></span>"
                + this.contentGroup.title
                + "</a></h4></div>"
                + "<div id='" + collapseId + "' class='panel-collapse collapse in' " + "'" + focusElement + ">"
                + "<ul id='" + collapseBodyId + "' class='list-group'></ul></div></div>";
            this.contentGroupDiv = domConstruct.place(contentGroupPanelMarkup, this.contentGroupNodeId, "last");
            //initialize collapsibles
            query('#sidebar .collapse').collapse();
            //close sidebar collapsibles
            query('#sidebar .collapse').collapse('toggle');

            on(dom.byId(collapseId), "shown.bs.collapse", lang.hitch(this, function (pane) {
                this._setFocus(pane);
            }));

            this.contentGroup.operationalLayers.forEach(lang.hitch(this, function (operationalLayer) {
                this._createLayers(operationalLayer, layers, collapseBodyId);
            }));

            // add content group layers to the map
            array.forEach(layers, function (layer) {
                this.theMap.addLayer(layer, layer.layerOrder || 0);
            }, this);            
        },

        _createLayers: function (layerConfigData, layers, parentNodeForLayerControl) {
            if (layerConfigData.subGroups) {
                layerConfigData.subGroups.forEach(lang.hitch(this, function (subGroup) {
                    var parentId = "collapse" + subGroup.parentGroupId + "-body",
                        parentNode = dom.byId(parentId),
                        subGroupListItem = domConstruct.create("li", { 'class': "subgroup" }, parentNode, "last"),
                        focusElement = null,
                        subGroupPanelMarkup = null,
                        collapseId = "collapse" + subGroup.id,
                        collapseBodyId = collapseId + "-body";

                    if (subGroup.focusElementId) {
                        focusElement = " data-focus-elementid='layerControl-" + subGroup.focusElementId + "'";
                    }

                    if (subGroup.focusGroupId) {
                        focusElement = " data-focus-elementid='" + subGroup.focusGroupId + "'";
                    }

                    subGroupPanelMarkup = "<div class='panel' id='" + subGroup.id + "' tabindex='-1'><div class='panel-heading' role='tab' id='headingTwo'><h4 class='panel-title'>"
                    + "<a role='button' class='btn' data-toggle='collapse' data-target='#" + collapseId + "'>"
                    + subGroup.title
                    + "</a></h4></div>"
                    + "<div id='" + collapseId + "' class='panel-collapse collapse in' parentNodeId='collapse" + subGroup.parentGroupId + "' " + focusElement + ">"
                    + "<ul id='" + collapseBodyId + "' class='list-group'></ul></div></div>";

                    this.contentGroupDiv = domConstruct.place(subGroupPanelMarkup, subGroupListItem, "last");

                    // fires when collapsible element is fully shown
                    on(dom.byId(collapseId), "shown.bs.collapse", lang.hitch(this, function (pane) {
                        this._setFocus(pane);
                    }));

                    //initialize collapsibles
                    query('#sidebar .collapse').collapse();
                    //close sidebar collapsibles
                    query('#sidebar .collapse').collapse('toggle');

                    if (subGroup.operationalLayers) {
                        subGroup.operationalLayers.forEach(lang.hitch(this, function (operationalLayer) {
                            this._createLayers(operationalLayer, layers, collapseBodyId);
                        }));
                    }
                }));
            } else {
                var layerTypes = {
                    dynamic: 'ArcGISDynamicMapService',
                    feature: 'Feature',
                    tiled: 'ArcGISTiledMapService',
                    graphics: 'Graphics',
                    wms: 'WMS'
                }, type = layerTypes[layerConfigData.type];

                if (type) {
                    require(['esri/layers/' + type + 'Layer'], lang.hitch(this, '_initLayer', layerConfigData, layers, parentNodeForLayerControl));
                }

                if (layerConfigData.options.subLayers) {
                    array.forEach(layerConfigData.options.subLayers, function (subLayer) {
                        type = layerTypes[subLayer.type];

                        if (type) {
                            require(['esri/layers/' + type + 'Layer'], lang.hitch(this, '_initSubLayerGroups', subLayer, layers));
                        }
                    }, this);
                }
            }                     
        },

        // set focus in navbar
        _setFocus: function (item) {
            if (item.currentTarget.attributes['data-focus-elementid'] !== undefined) {
                focusUtil.focus(dom.byId(item.currentTarget.attributes['data-focus-elementid'].value));
            }
        },

        _initSubLayerGroups: function (subLayer, layers, LayerClass) {
            var newLayer = null, infoTemplate;
            if (subLayer.url) {
                newLayer = new LayerClass(subLayer.url, subLayer.options);
            }
            if (subLayer.customModule) {
                if (subLayer.customModule.getRenderer) {
                    newLayer.setRenderer(subLayer.customModule.getRenderer());
                }

                if(subLayer.customModule.getDefinitionExpression) {
                    newLayer.setDefinitionExpression(subLayer.customModule.getDefinitionExpression());
                }

                if (!subLayer.customModule._createOwnInfoTemplate && !subLayer.customModule._hideInfoTemplate) {
                    if (subLayer.customModule.getInfoTemplate) {
                        // assign custom info-template
                        infoTemplate = subLayer.customModule.getInfoTemplate(lang.hitch(subLayer.customModule, subLayer.customModule.infoWindowHandlerTitle),
                                lang.hitch(subLayer.customModule, subLayer.customModule.infoWindowHandlerContent));
                        if (infoTemplate) {
                            newLayer.infoTemplate = infoTemplate;
                            // temporary set info-window width and height
                            this.theMap.infoWindow.resize(350, 800);
                        }
                    }
                }

                if (subLayer.customModule._hideInfoTemplate) {
                    this._addMouseEventHandler(subLayer.customModule, newLayer);
                } else {
                    this._addEventHandler(subLayer.customModule, newLayer);
                }

                if (subLayer.customModule.performTasksAfterLayerCreated) {
                    subLayer.customModule.performTasksAfterLayerCreated(newLayer);
                }
            }

            if (newLayer) {
                // set layer order
                newLayer.layerOrder = subLayer.layerOrder || 0; // default setting is the bottom
            }
            
            layers.unshift(newLayer);
        },
        _initLayer: function (operationalLayer, layers, parentNodeForLayerControl, LayerClass) {
            var newLayer = null, layerInfo, layerResourceInfo, infoTemplate;

            if (operationalLayer.type === 'wms') {
                layerInfo = new WMSLayerInfo({ name: operationalLayer.wmsName, title: operationalLayer.title });
                layerResourceInfo = {
                    extent: new Extent(operationalLayer.extent.xmin,
                        operationalLayer.extent.ymin,
                        operationalLayer.extent.xmax,
                        operationalLayer.extent.ymax, { wkid: operationalLayer.extent.wkid }),
                    layerInfos: [layerInfo]
                };

                operationalLayer.options.resourceInfo = layerResourceInfo;
            }

            if (operationalLayer.url) {
                newLayer = new LayerClass(operationalLayer.url, operationalLayer.options);
            }

            if (operationalLayer.type === 'dynamic') {
                if (operationalLayer.options.visibleLayers && operationalLayer.options.visibleLayers.constructor === Array) {
                    newLayer.setVisibleLayers(operationalLayer.options.visibleLayers);
                }                
            } else if (operationalLayer.customModule) { //currently dynamic layer doesn't have custom module
                // create feature layer
                if (operationalLayer.layerDefinition) {
                    newLayer = operationalLayer.customModule.createFeatureLayer(operationalLayer.layerDefinition, operationalLayer.options.id);
                }
                
                // set renderer
                if (operationalLayer.customModule.getRenderer) {
                    if (operationalLayer.defaultIconforRenderer) {
                        newLayer.setRenderer(operationalLayer.customModule.getRenderer(operationalLayer.defaultIconforRenderer));
                    } else {
                        newLayer.setRenderer(operationalLayer.customModule.getRenderer());
                    }
                }

                // set definition expression
                if (operationalLayer.customModule.getDefinitionExpression) {
                        newLayer.setDefinitionExpression(operationalLayer.customModule.getDefinitionExpression());
                }

                if (operationalLayer.customModule.setMapControl) {
                    operationalLayer.customModule.setMapControl(this.mapControls);
                }

                // add additional graphic points to layer
                if (operationalLayer.customModule.addGraphics) {
                    operationalLayer.customModule.addGraphics(newLayer, operationalLayer.url, operationalLayer.options, this.iniExtent);
                }

                if (!operationalLayer.customModule._createOwnInfoTemplate && !operationalLayer.customModule._hideInfoTemplate) {
                    if (operationalLayer.customModule.getInfoTemplate) {
                        // assign custom info-template
                        infoTemplate = operationalLayer.customModule.getInfoTemplate(lang.hitch(operationalLayer.customModule, operationalLayer.customModule.infoWindowHandlerTitle),
                                lang.hitch(operationalLayer.customModule, operationalLayer.customModule.infoWindowHandlerContent));
                        if (infoTemplate) {
                            newLayer.infoTemplate = infoTemplate;
                            // temporary set info-window width and height
                            this.theMap.infoWindow.resize(350, 800);
                        }
                    }                  
                }

                if (operationalLayer.customModule._hideInfoTemplate) {
                    this._addMouseEventHandler(operationalLayer.customModule, newLayer);
                } else {
                    this._addEventHandler(operationalLayer.customModule, newLayer);
                }

                if (operationalLayer.customModule.performTasksAfterLayerCreated) {
                    operationalLayer.customModule.performTasksAfterLayerCreated(newLayer);
                }
            }
            // set layer order
            newLayer.layerOrder = operationalLayer.layerOrder || 0; // default setting is the bottom

            // unshift instead of push to keep layer ordering on map intact
            layers.unshift(newLayer);
            //map, layer, layerConfig, nodeToAppendTo
            mapUtils._buildLayerControls({
                map: this.theMap,
                layer: newLayer, 
                layerConfig: operationalLayer, 
                nodeToAppendTo: parentNodeForLayerControl
            });
        },

        _addEventHandler: function (customModule, layer) {
            // hide tooltip from mobile devices
            if (has("device-width") > 1024) {
                if (customModule.showGraphicTooltip) {
                    on(layer, "mouse-over", lang.hitch(customModule, customModule.showGraphicTooltip));
                }

                if (customModule.mouseOutHandler) {
                    on(layer, "mouse-out", lang.hitch(customModule, customModule.mouseOutHandler));
                }
            }

            if (customModule.clickHandler) {
                on(layer, "click", lang.hitch(customModule, customModule.clickHandler));
            }

            if (customModule.visibilityChangeHandler) {
                on(layer, "visibility-change", lang.hitch(customModule, customModule.visibilityChangeHandler));
            }
        },

        _addMouseEventHandler: function (customModule, layer) {      
                if (customModule.showGraphicTooltip) {
                    on(layer, "mouse-over", lang.hitch(customModule, customModule.showGraphicTooltip));
                }

                if (customModule.mouseOutHandler) {
                    on(layer, "mouse-out", lang.hitch(customModule, customModule.mouseOutHandler));
                }
        }
    });

    return _ContentGroup;
});