﻿/*property
    _attachEventHandlers, _clearSelection, _lastSelectedOption,
    _optionDelegates, _selectionChanged, _updateVisibility, add,
    addHistoricalLayer, attributes, children, hideLayersWithPrefix, create,
    domNode, showLayersWithPrefix, historicalLayer, hitch, id, inherited,
    innerHTML, length, options, postCreate, remove, select, selectedIndex,
    stepBackward, stepForward, stopPropagation, strings, subLayerToInclude,
    templateString, title, value, visibleLayersIds,onchange
*/
define([
  'dojo/_base/lang',
  'dojo/_base/declare',
  'dojo/on',
  'dojo/dom-class',
  'dojo/dom-construct',
  'dojo/query',

  'dijit/_WidgetBase',
  'dijit/_TemplatedMixin',

  'dojo/text!./templates/HistoricalLayerSelector.html',
  'dojo/i18n!app/layout/nls/strings',

  'dojo-bootstrap/Collapse',
  'dojo-bootstrap/Dropdown'
], function (
  lang, declare, on, domClass, domConstruct, query,
  _WidgetBase, _TemplatedMixin,
  template, strings
) {
    //'use strict';//can't use strict mode due to use of arguments
    return declare([_WidgetBase, _TemplatedMixin], {
        templateString: template,
        strings: strings,

        postCreate: function () {
            this.inherited(arguments);
            this._attachEventHandlers();
            this._updateVisibility();
        },

        _attachEventHandlers: function () {

            on(this.select, 'change', lang.hitch(this, this._selectionChanged));

            // need this event in "restoreState" because the above event isn't accessible at that point
            this.select.onchange = lang.hitch(this, this._selectionChanged);

            on(this.select, 'click', function (evt) {
                evt.stopPropagation();
            });

            on(this.stepBackward, 'click', lang.hitch(this, function (evt) {
                if (this.select.selectedIndex > 0) {
                    this.select.selectedIndex = (this.select.selectedIndex - 1);
                }
                this._selectionChanged(evt);
            }));

            on(this.stepForward, 'click', lang.hitch(this, function (evt) {
                if (this.select.selectedIndex < (this.select.options.length - 1)) {
                    this.select.selectedIndex = (this.select.selectedIndex + 1);
                }
                this._selectionChanged(evt);
            }));

            on(this.domNode, 'click', lang.hitch(this, function (evt) {
                this.select.selectedIndex = 0;//not selected option
                this._selectionChanged(evt);
            }));
        },

        _clearSelection: function() {
            if (this._lastSelectedOption) {
                this._optionDelegates[this._lastSelectedOption.attributes['data-layer-name'].value](this._lastSelectedOption, false);
                this._lastSelectedOption = undefined;
            }
        },

        _selectionChanged: function (evt) {
            evt.stopPropagation();
            this._clearSelection();
            
            var selectedOptions = query(this.select).children('option[value = "' + this.select.value + '"]');

            if (!selectedOptions || selectedOptions.length === 0) {
                throw 'Could not find selected historical layer';
            } 
            var selectedOption = selectedOptions[0];

            var dataLayerNameAttribute = selectedOption.attributes['data-layer-name'];

            if (dataLayerNameAttribute !== undefined) {
                domClass.add(this.domNode, 'active');

                var selectedDelegate = this._optionDelegates[dataLayerNameAttribute.value];

                if (!selectedDelegate) {
                    throw 'Could not find the historical layer selected action delegate';
                }
                    selectedDelegate(selectedOption, true);
                    this._lastSelectedOption = selectedOption;
            } else {
                domClass.remove(this.domNode, 'active');
            }
            
        },

        _updateVisibility: function() {
            if (this.select.selectedIndex === 0) {
                domClass.add(this.stepBackward, 'disabled');
            } else {
                domClass.remove(this.stepBackward, 'disabled');
            }

            if (this.select.selectedIndex > 0 && this.select.selectedIndex === (this.select.options.length - 1)) {
                domClass.add(this.stepForward, 'disabled');
            } else {
                domClass.remove(this.stepForward, 'disabled');
            }
        },

        _optionDelegates: {},

        addHistoricalLayer: function (historicalLayer, dataLayerId, onSelectDelegate) {

            domConstruct.create('option', {
                id: 'layerControl-' + historicalLayer.id,
                'data-layer-id': dataLayerId,
                'data-layer-name': historicalLayer.id,
                'data-visible-layers': historicalLayer.visibleLayersIds || "",
                'data-sub-layer-to-include': historicalLayer.subLayerToInclude || "",
                'data-hide-layers-with-prefix': historicalLayer.hideLayersWithPrefix || "",
                'data-show-layers-with-prefix': historicalLayer.showLayersWithPrefix || "",
                'data-historical-layer': historicalLayer.historicalLayer || "",
                'data-historical-year': historicalLayer.title || "",
                value: historicalLayer.title,
                innerHTML: historicalLayer.title
            }, this.select, 'last');

            this._optionDelegates[historicalLayer.id] = onSelectDelegate;
        }
    });
});