/*property
    _initBasemaps, _initGallery, _initLayer, _initLayers, _initLegend,
    _initMap, _initWidgets, _onWebMapLoad, _postMapLoadInit, _wireEvents,
    addLayer, apiOptions, basemapGallery, basemaps, class, className, color,
    constructor, corners, create, createWebMap, customModule, direction,
    domNode, dynamic, el, feature, forEach, galleryId, geocoder,
    getDefinitionExpression, getMapHeight, getRenderer, google, height,
    hideSpinner, hitch, homeButton, homeNode, hwaccel, id, infoWindow,
    inherited, itemId, layer, layerInfos, layerOrder, layers, left, legend,
    legendNodeId, length, lines, locateButton, locateNode, log, map, mapNode,
    mapOptions, mixin, mouseOutHandler, name, on, operationalLayers, options,
    own, postCreate, publish, push, radius, remove, rotate, scalebar,
    scalebarUnit, searchNode, setDefinitionExpression, setRenderer,
    setVisibleLayers, shadow, showArcGISBasemaps, showGraphicTooltip,
    showSpinner, speed, spin, spinner, spinnerNode, startup, stop,
    streetViewControl, templateString, then, thumbnailUrl, tiled, title,
    toggleReference, top, trail, type, unshift, url, v, visibleLayers, widgets,
    width, zIndex
*/
define([
    'dojo/_base/declare',
    'dojo/_base/array',
    'dojo/_base/lang',
    'dojo/dom-class',
    'dojo/topic',
    'dojo/dom-construct',
    'dojo/on',
    'dijit/_WidgetBase',
    'dijit/_TemplatedMixin',
    'esri/dijit/Scalebar',
    'esri/dijit/HomeButton',
    'esri/dijit/Geocoder',
    'esri/dijit/Legend',
    'esri/dijit/BasemapLayer',
    'esri/dijit/Basemap',
    'esri/dijit/BasemapGallery',
    'bootstrap-map-js/js/bootstrapmap',
    'spin-js/spin',
    'dojo/text!./templates/Map.html',
    'dojo/has',
    'esri/dijit/PopupMobile',
    'esri/layers/WebTiledLayer',
    'agsjs/layers/GoogleMapsLayer'

], function (declare, array, lang, domClass, topic, domConstruct, on, _WidgetBase, _TemplatedMixin,
    Scalebar, HomeButton,  Geocoder, Legend, BasemapLayer, Basemap, BasemapGallery,
    BootstrapMap, Spinner, template, has, PopupMobile) {
    return declare([_WidgetBase, _TemplatedMixin], {
        templateString: template,

        postCreate: function () {
            this.inherited(arguments);
            // NOTE: BootstrapMap needs to work off an id
            this.mapNode.id = this.id + 'Map';
            this._initMap();
        },

        _wireEvents: function () {
            // summary:
            // wire events
            //
            this.map.on('load', lang.hitch(this, this._postMapLoadInit));
            this.map.on('update-start', lang.hitch(this, 'showSpinner'));
            this.map.on('update-end', lang.hitch(this, 'hideSpinner'));
        },
        _postMapLoadInit: function () {
            this._initGallery();
            topic.publish('mapcontrols/loaded');
        },
        showSpinner: function () {
            // summary:
            // sets up and shows the spinner
            //
            var opts = {
                lines: 9, // The number of lines to draw
                length: 4, // The length of each line
                width: 3, // The line thickness
                radius: 4, // The radius of the inner circle
                corners: 1, // Corner roundness (0..1)
                rotate: 0, // The rotation offset
                direction: 1, // 1: clockwise, -1: counterclockwise
                color: '#000', // #rgb or #rrggbb or array of colors
                speed: 1, // Rounds per second
                trail: 60, // Afterglow percentage
                shadow: false, // Whether to render a shadow
                hwaccel: true, // Whether to use hardware acceleration
                className: 'spinner', // The CSS class to assign to the spinner
                zIndex: 100, // The z-index (defaults to 2000000000)
                top: '50%', // Top position relative to parent in px
                left: '50%' // Left position relative to parent in px
            };

            if (!this.spinner) {
                this.spinner = new Spinner(opts).spin(this.spinnerNode);
            } else {
                if (!this.spinner.el) {
                    // only start spinner if not already started
                    this.spinner.spin(this.spinnerNode);
                }
            }
        },

        hideSpinner: function () {
            // summary:
            // hides the spinner 
            //
            if (this.spinner) {
                this.spinner.stop();
            }
        },

        // initalize map from configuration parameters
        _initMap: function () {
            if (!this.options) {
                this.options = {};
            }
            if (has("device-width") <= 650) {
                this.options.infoWindow = new PopupMobile(null, domConstruct.create("div"));
            }
            
            this.showSpinner();

            if (this.itemId) {
                BootstrapMap.createWebMap(this.itemId, this.mapNode.id, this.options).then(lang.hitch(this, '_onWebMapLoad'));
            } else {
                this.map = BootstrapMap.create(this.mapNode.id, this.options);
                this._wireEvents();
                this._initLayers();
                this._initWidgets();
            }
        },
        _initBasemaps: function () {
            var basemapList = [];
            if (this.basemaps) {
                this.basemaps.forEach(function (currentValue) {
                    var options = {
                        id: currentValue.id,
                        title: currentValue.title,
                        thumbnailUrl: currentValue.thumbnailUrl
                    };
                    if (currentValue.type) {
                        options.layers = [new BasemapLayer({ type: currentValue.type })];
                    } else if (currentValue.url) {
                        options.layers = [new BasemapLayer({ url: currentValue.url })];
                    }
                    basemapList.push(new Basemap(options));
                }, this);
                return basemapList;
            } 
            throw new ReferenceError("basemapLayers has not been initialized yet. Please call this.initializeBaseMaps() before this.createBasemapGallery(divName).");
        },
        _initGallery: function () {
            //console.log("initiating gallery...");
            if (this.galleryId) {
                this.basemapGallery = new BasemapGallery({
                    basemaps: this._initBasemaps(this.basemaps),
                    showArcGISBasemaps: false,
                    toggleReference: true,
                    google: {
                        apiOptions: {
                            v: '3.6' // use a specific version is recommended for production system.
                        },
                        mapOptions: {
                            streetViewControl: false
                        }
                    },
                    map: this.map
                }, this.galleryId);

                this.basemapGallery.startup();
            } else {
                //if (console) {//if console object exists then write to it's log can do this with   console && console.error()   but JSLint complains about it.
                //    console.error("a div in which to create the basemap gallery was not specified...");
                //}
                //TODO is there a better way of doing this without using throw?
                throw new ReferenceError('No div id specified: a new BasemapGallery object requires as an argument the id of a div element where it will create the gallery.');
            }
        },
        // set reference to the map
        // then show legend and map widgets
        _onWebMapLoad: function (response) {
            //var layerInfos;
            this.map = response.map;
            this._wireEvents();
            //if (this.legendNodeId) {
            //    layerInfos = arcgisUtils.getLegendLayers(response);
            //    if (this.map.loaded) {
            //        //this._initLegend(layerInfos);
            //    } else {
            //        this.map.on('load', function () {
            //            //self._initLegend(layerInfos);
            //        });
            //    }
            //}
            this._initWidgets();
            topic.publish('webmap/load', response);
        },

        // init map layers from options instead of a web map
        _initLayers: function () {
            if (!this.operationalLayers) {
                return;
            }
            var layers = [],
                layerTypes = {
                    dynamic: 'ArcGISDynamicMapService',
                    feature: 'Feature',
                    tiled: 'ArcGISTiledMapService'
                },
            // loading all the required modules first ensures the layer order is maintained
                modules = [];
            array.forEach(this.operationalLayers, function (operationalLayer) {
                var type = layerTypes[operationalLayer.type];
                if (type) {
                    modules.push('esri/layers/' + type + 'Layer');
                } else {
                    console.log('Layer type not supported: ', operationalLayer.type);
                }
            }, this);
            require(modules, lang.hitch(this, function () {
                var layerInfos = [];
                array.forEach(this.operationalLayers, function (operationalLayer) {
                    var type = layerTypes[operationalLayer.type];
                    if (type) {
                        require(['esri/layers/' + type + 'Layer'], lang.hitch(this, '_initLayer', operationalLayer, layers, layerInfos));
                    }
                }, this);
                array.forEach(layers, function (layer) {
                    this.map.addLayer(layer, layer.layerOrder || 0);
                }, this);
                //this._initLegend(layerInfos);
            }));
        },
        _initLayer: function (operationalLayer, layers, layerInfos, LayerClass) {
            var newLayer = new LayerClass(operationalLayer.url, operationalLayer.options);
            if (operationalLayer.options.visibleLayers && operationalLayer.options.visibleLayers.constructor === Array) {
                newLayer.setVisibleLayers(operationalLayer.options.visibleLayers);
            }

            if (operationalLayer.customModule) {

                // set renderer
                if (operationalLayer.customModule.getRenderer) {                  
                        newLayer.setRenderer(operationalLayer.customModule.getRenderer());
                }

                // set definition expression
                if (operationalLayer.customModule.getDefinitionExpression) {
                    newLayer.setDefinitionExpression(operationalLayer.customModule.getDefinitionExpression());
                }

                // show tooltip
                if (operationalLayer.customModule.showGraphicTooltip) {
                    on(newLayer, "mouse-over", lang.hitch(operationalLayer.customModule, operationalLayer.customModule.showGraphicTooltip));
                }

                if (operationalLayer.customModule.mouseOutHandler) {
                    on(newLayer, "mouse-out", lang.hitch(operationalLayer.customModule, operationalLayer.customModule.mouseOutHandler));
                }
                
            }

            newLayer.layerOrder = operationalLayer.layerOrder || 0; // default setting is the bottom

            // unshift instead of push to keep layer ordering on map intact
            layers.unshift(newLayer);
            layerInfos.unshift({
                layer: newLayer,
                title: operationalLayer.title || newLayer.name
            });
        },

        _initLegend: function (layerInfos) {
            if (!this.legendNodeId) {
                return;
            }
            this.legend = new Legend({
                map: this.map,
                layerInfos: layerInfos
            }, this.legendNodeId);
            this.legend.startup();
        },

        // init map widgets if they are in config
        _initWidgets: function () {
            if (!this.widgets) {
                return;
            }

            // scalebar
            if (this.widgets.scalebar) {
                this.scalebar = new Scalebar(lang.mixin({
                    map: this.map,
                    scalebarUnit: 'dual'
                }, this.widgets.scalebar));
            }

            // home button
            if (this.widgets.homeButton) {
                this.homeButton = new HomeButton(lang.mixin({
                    map: this.map
                }, this.widgets.homeButton), this.homeNode);
                this.homeButton.startup();
            }

            // locate button
            //if (this.widgets.locateButton) {
            //    this.locateButton = new LocateButton(lang.mixin({
            //        map: this.map,
            //        'class': 'locate-button'
            //    }, this.widgets.locateButton), this.locateNode);
            //    this.locateButton.startup();
            //}

            // geocoder
            if (this.widgets.geocoder) {
                this.geocoder = new Geocoder(lang.mixin({
                    map: this.map,
                    'class': 'geocoder'
                }, this.widgets.geocoder), this.searchNode);
                this.geocoder.startup();
                this.own(this.geocoder.on('select', function () {
                    domClass.remove(this.geocoder.domNode, 'shown');
                }));
            }
        },

        getMapHeight: function () {
            if (this.map) {
                return this.map.height;
            }
            return 0;
        }

    });
});