﻿/*property
    STYLE_SOLID, _addLayerLinks, _addRelatedLinks, _addZoomToScale,
    _buildLayerControls, _hideOrShowLayers,
    _createLinkAnchorForRelatedLink, _currentHistoricalLayerSelector,
    _displayLayerForNode, _getAnchorOptionsforGlossaryLinks,
    _getAnchorOptionsforIframeChart, _getAnchorOptionsforZoom,
    layerControlClickHandler, a, add, addGraphicFeatureToLayer,
    addHistoricalLayer, aewError, at, attr, attributes, byId, class,
    hideLayersWithPrefix, closeToolTipDialog, concat, contains, content,
    create, createGraphicsLayer, cssClass, destroy,
    display, domNode, showLayersWithPrefix, execute, filter, forEach,
    geometry, get, getLayer, getSimpleFillSymbol, graphicsLayerIds, height, hide, historicalLayer,
    hitch, href, id, indexOf, infoTemplate, infoWindow, innerHTML, layer,
    layerConfig, layerIds, layerOrder, length, link, map, modal, multiLayers,
    nodeName, nodeToAppendTo, on, onError, onclick, options, outFields, pageX,
    pageY, parentElement, place, publish, push, queryFeatureLayer,
    relatedLinks, reorderLayer, reorderLayers, returnGeometry, setLevel,
    setSymbol, setVisibility, setVisibleLayers, showToolTipDialog, sort, split,
    startup, stopPropagation, style, subLayerToInclude, symbol, target, title,
    toUpperCase, toggle, type, url, visible, visibleLayers, visibleLayersIds,
    where, width, x, y, zoomToLevel,modalClass,currentTarget,value,modalCssClass,
    toLowerCase
*/
define([
    'dojo/_base/lang',
    'dojo/_base/Color',
    'dojo/_base/array',
    'dojo/dom',
    'dojo/dom-class',
    'dojo/dom-attr',
    'dojo/dom-construct',
    'dojo/query',
    'dojo/topic',
    'dijit/TooltipDialog',
    "dijit/place",
    "dijit/registry",
    'esri/layers/GraphicsLayer',
    'esri/symbols/SimpleLineSymbol',
    'esri/symbols/SimpleFillSymbol',
    'esri/symbols/PictureMarkerSymbol',
    'esri/tasks/QueryTask',
    'esri/tasks/query',
    'esri/graphic',
    './HistoricalLayerSelector',
    'dojo-bootstrap/Modal'
], function (lang, Color, array, dom, domClass, domAttr, domConstruct, query, topic, 
    TooltipDialog, place, registry, GraphicsLayer, SimpleLineSymbol, SimpleFillSymbol, PictureMarkerSymbol,
    QueryTask, Query, Graphic, HistoricalLayerSelector) {
    'use strict';
    return {
        // creates a new graphics layer
        createGraphicsLayer: function (id, isVisible) {
            var layer = new GraphicsLayer({
                id: id,
                onError: this.aewError,
                visible: isVisible
            });
            return layer;
        },
        // executes a query operation on layer
        queryFeatureLayer: function (successCallback, errorCallback, mapServerUrl, fieldArray, iniExtent, where) {
            var def, queryTask, layerQuery = new Query();
            layerQuery.returnGeometry = true;
            layerQuery.outFields = fieldArray || ["*"];
            layerQuery.geometry = iniExtent;

            if (where) {
                layerQuery.where = where;
            }

            queryTask = new QueryTask(mapServerUrl);
            def = queryTask.execute(layerQuery, successCallback, errorCallback);
            return def;
        },
        

        // build layer controls (checkboxes/ zoom link / chart link)
        _buildLayerControls: function (args) {
            var node = dom.byId(args.nodeToAppendTo), layerVisibleClass, layerMarkup, contentNode;

            args._hideOrShowLayers = this._hideOrShowLayers;
            args._displayLayerForNode = this._displayLayerForNode;
            if (args.layerConfig.options.multiLayers) {
                array.forEach(args.layerConfig.options.multiLayers, function (multiLayer) {
                    if (multiLayer.historicalLayer === true) {
                        if (!this._currentHistoricalLayerSelector) {
                            this._currentHistoricalLayerSelector = new HistoricalLayerSelector({}, domConstruct.create('div', {}, node, 'last'));
                        }

                        this._currentHistoricalLayerSelector.addHistoricalLayer(multiLayer, args.layer.id, lang.hitch(args, this._displayLayerForNode));

                    } else {
                        this._currentHistoricalLayerSelector = undefined;

                    if (multiLayer.id) {
                        layerVisibleClass = args.layer.visible ? "active" : "";
                        layerMarkup = "<li tabindex='-1' class='layerControl " + layerVisibleClass
                            + "' id='layerControl-" + multiLayer.id
                            + "' data-layer-id='" + args.layer.id
                            + "' data-layer-name='" + multiLayer.id
                            + "' data-visible-layers='" + (multiLayer.visibleLayersIds || "")
                            + "' data-sub-layer-to-include='" + (multiLayer.subLayerToInclude || "")
                            + "' data-hide-layers-with-prefix='" + (multiLayer.hideLayersWithPrefix || "")
                            + "' data-show-layers-with-prefix='" + (multiLayer.showLayersWithPrefix || "")
                            + "' data-historical-layer='" + (multiLayer.historicalLayer || "")
                            + "' data-historical-year='" + (multiLayer.title || "")
                            + "'></li>";
                        contentNode = domConstruct.place(layerMarkup, node, 'last');
                        domConstruct.create('span', { innerHTML: multiLayer.title, 'class': 'layerControlLabel' }, contentNode, 'last');

                        // add zoom to scale
                        if (multiLayer.zoomToLevel) {
                            lang.hitch(this, this._addZoomToScale, { map: args.map, zoomToLevel: multiLayer.zoomToLevel }, contentNode)();
                        }
                        // add layer links
                        if (multiLayer.link) {
                            lang.hitch(this, this._addLayerLinks, multiLayer, contentNode)();
                        }
                        // add related links
                        if (multiLayer.relatedLinks) {
                            lang.hitch(this, this._addRelatedLinks, multiLayer.relatedLinks, contentNode)();
                        }
                    } else {
                        // just create a label with title
                        domConstruct.create("div", { innerHTML: '<span class="contentLabel">' + multiLayer.title + '</span>' }, node, 'last');
                    }
                    }
                }, this);
            } else {
                layerVisibleClass = args.layer.visible ? "active" : "";
                layerMarkup = "<li tabindex='-1' class='layerControl " + layerVisibleClass
                    + "' id='layerControl-" + args.layer.id
                    + "' data-layer-id='" + args.layer.id
                    + "' data-layer-name='" + args.layer.id
                    + "' data-visible-layers='" + (args.layerConfig.options.visibleLayers || "")
                    + "' data-hide-layers-with-prefix='" + (args.layerConfig.hideLayersWithPrefix || "")
                    + "' data-show-layers-with-prefix='" + (args.layerConfig.showLayersWithPrefix || "")
                    + "'></li>";
                contentNode = domConstruct.place(layerMarkup, node, 'last');
                domConstruct.create('span', { innerHTML: args.layerConfig.title, 'class': 'layerControlLabel' }, contentNode, 'last');

                //TODO: do we need this kind of reverse event control from the layer that will clear the checked state?
                //layer.on("visibility-change", function (event) {
                //    if (typeof event === 'object') {
                //        checkBox.setChecked(event.visible);
                //    }
                //});

                // add zoom to scale 
                if (args.layerConfig.zoomToLevel) {
                    lang.hitch(this, this._addZoomToScale, { map: args.map, zoomToLevel: args.layerConfig.zoomToLevel }, contentNode)();
                }

                // add layer links
                if (args.layerConfig.link) {
                    lang.hitch(this, this._addLayerLinks, args.layerConfig, contentNode)();
                }

                // add related links
                if (args.layerConfig.relatedLinks) {
                    lang.hitch(this, this._addRelatedLinks, args.layerConfig.relatedLinks, contentNode)();
                }
            }
        },
        _addRelatedLinks: function (relatedLinks, contentNode) {
            array.forEach(relatedLinks, lang.hitch(this, function (link) {
                var linkListItem = domConstruct.create("li", {
                    'class': 'layerRelatedLinkItem'
                }, contentNode, 'after');

                this._createLinkAnchorForRelatedLink(link.title, link.url, linkListItem, "last", link.type, "layerRelatedLink", link.modalCssClass);
            }));
        },
        _addZoomToScale: function(options, contentNode) {
            var anchorOptions = this._getAnchorOptionsforZoom(options.zoomToLevel, options.map, "icon floater-right glyphicon glyphicon-zoom-in dark-blue-txt");
            domConstruct.create('span', anchorOptions, contentNode, 'last');
        },
        _addLayerLinks: function(options, contentNode) {
            var anchorOptions = {};
            switch (options.link.type) {
                case 'iframe':
                    anchorOptions = this._getAnchorOptionsforIframeChart(
                        options.link.title, options.link.url,
                        options.link.cssClass + " icon floater-right");
                        //"icon floater-right glyphicon glyphicon-modal-window dark-blue-txt");
                    break;
            }
            domConstruct.create('span', anchorOptions, contentNode, 'last');
        },

        // hide or show layers
        _hideOrShowLayers: function (subLayerGroups, ignore, hide) {
            var i;
            array.filter(subLayerGroups, function (item) {
                return item !== 'undefined' && item !== "" && item !== null;
            });
            for (i = 0; i < subLayerGroups.length; i += 1) {
                if (hide) {
                    topic.publish('map/layers/hide-by-layer-name', subLayerGroups[i]);
                } else {
                    topic.publish('map/layers/show-by-layer-name', subLayerGroups[i]);
                }
            }
        },

        // based on node attributes show/hide layers
        _displayLayerForNode: function (node, isActive, map) {

            if (map === undefined)
            {
                map = this.map;
            }

            if (!node || node === null) {
                throw 'node cannot be null';
            }

            // hide infowindow
            map.infoWindow.hide();

            var targetLayerId = domAttr.get(node, 'data-layer-id'),
                targetVisibleLayerIds = (domAttr.get(node, 'data-visible-layers') !== "") ? domAttr.get(node, 'data-visible-layers').split(',') : [],
                targetLegendId = (targetVisibleLayerIds.length > 0) ? targetLayerId + '-' + targetVisibleLayerIds : targetLayerId,
                targetLayer, existingVisibleLayers = [], layersToAddOrRemove = [], relatedSubLayer, i,
                subLayerToInclude = domAttr.get(node, 'data-sub-layer-to-include'),
                layersToHide = (domAttr.get(node, 'data-hide-layers-with-prefix') !== "") ? domAttr.get(node, 'data-hide-layers-with-prefix').split(',') : [],
                layersToShow = (domAttr.get(node, 'data-show-layers-with-prefix') !== "") ? domAttr.get(node, 'data-show-layers-with-prefix').split(',') : [],
                testForUndefinedOrEmpty = function (item) {
                    return item !== 'undefined' && item !== "" && item !== null;
                };
            //console.warn("still need to add code to update Ruwani's new legend.");
            targetLayer = map.getLayer(targetLayerId);

            //update legend TODO: this needs to be refactored to use pub/sub model or something
            dom.byId(targetLegendId).style.display = isActive === true ? 'block' : 'none';

            // get layers to add or remove
            if (targetVisibleLayerIds) {
                array.filter(targetVisibleLayerIds, testForUndefinedOrEmpty);
                for (i = 0; i < targetVisibleLayerIds.length; i += 1) {
                    layersToAddOrRemove.push(targetVisibleLayerIds[i]);
                }
            }

            if (layersToAddOrRemove.length > 0) {
                if (isActive) {

                    if (!targetLayer.visible) {
                        targetLayer.setVisibleLayers(layersToAddOrRemove, false);
                        targetLayer.setVisibility(isActive);
                    } else {
                        //adding layers
                        existingVisibleLayers = targetLayer.visibleLayers.concat(layersToAddOrRemove);
                        targetLayer.setVisibleLayers(existingVisibleLayers, false);
                    }

                } else {

                    //removing layers
                    existingVisibleLayers = targetLayer.visibleLayers.filter(function (item) {
                        return layersToAddOrRemove.indexOf(item) < 0;
                    });

                    if (existingVisibleLayers.length === 0) {
                        targetLayer.setVisibility(isActive);
                    } else {
                        targetLayer.setVisibleLayers(existingVisibleLayers, false);
                    }
                }
            }
            else {
                targetLayer.setVisibility(isActive);
            }

            // hide layers
            if (layersToHide.length > 0 && isActive) {
                this._hideOrShowLayers(layersToHide, node, true);
            }

            // show layers
            if (layersToShow.length > 0 && isActive) {
                this._hideOrShowLayers(layersToShow, node, false);
            }

            relatedSubLayer = map.getLayer(subLayerToInclude);
            if (relatedSubLayer) {
                relatedSubLayer.setVisibility(isActive);
            }
            topic.publish('UpdateState/LayerChange'); // trigger app.updateState() to save visibleLayersId in state
        },
        
        // click handler for left nav nodes
        layerControlClickHandler: function (event, theMap) {
            
            //sometimes the target is a child node
            var node = event.target.nodeName.toUpperCase() === 'LI' ? event.target : event.target.parentElement, isActive;
            
            domClass.toggle(node, "active");
            isActive = domClass.contains(node, 'active');
            this._displayLayerForNode(node, isActive, theMap);
        },

        // get zoom to scale anchor options
        _getAnchorOptionsforZoom: function (zoomLevel, map, cssClass) {
            var anchorOption = {
                target: '_blank',
                title: 'zoom to scale',
                'class': cssClass,
                onclick: function (e) {
                    map.setLevel(zoomLevel);
                    e.stopPropagation();
                }
            };
            return anchorOption;
        },

        // get iframe chart anchor options
        _getAnchorOptionsforIframeChart: function (title, url, cssClass) {
            var anchorOption = {
                target: '_blank',
                title: title,
                'class': cssClass,
                onclick: function (e) {
                    query('.iframe-modal .modal-title').attr('innerHTML', '');
                    query('.iframe-modal').on('show.bs.modal', function () {
                        query('#modalFrame').attr('src', url);
                    });
                    query('[id="iframeModalDiv"]').modal('show');
                    e.stopPropagation();
                }
            };

            return anchorOption;
        },

        _createLinkAnchorForRelatedLink: function (title, url, refNode, pos, type, cssClass, modalCssClass) {
            var anchorOptions, anchorNode, iconClass;

            switch (type) {
                case 'link':
                    iconClass = "glyphicon glyphicon-new-window";
                    anchorOptions = {
                        href: url,
                        target: '_blank',
                        'class': cssClass
                    };
                    break;
                case 'modal':
                    iconClass = "glyphicon glyphicon-info-sign";
                    anchorOptions = {
                        target: '_blank',
                        'class': cssClass
                    };
                    if (title.toLowerCase() === "glossary") {
                        anchorOptions.onclick = function (e) {
                            topic.publish("PortalGlossary/ShowModal");
                            e.stopPropagation();
                        };
                    }
                    break;
                case 'iframe':
                    iconClass = "glyphicon glyphicon-info-sign";
                    anchorOptions = {
                        target: '_blank',
                        'class': cssClass,
                        modalClass: modalCssClass,
                        onclick: function (e) {
                            /******************************************************************************************/
                            //This is assuming that an instance of IFrameModal has been created and added to the DOM. 
                            //Thus this function should probably be provided by that module... 
                            //so it needs to be refactored to find a more appropriate place in order to reduce coupling
                            //and to also make the function testable.
                            //In fact, _buildLayerControl should probably be moved out into some layout module...

                            //set modal window style class
                            if (e.currentTarget.attributes.modalClass.value === 'undefined') {
                                query('[id ="navBarDialog"]').attr('class', 'modal-dialog vertical-align-center modalContentMax');
                            }
                            else {
                                query('[id ="navBarDialog"]').attr('class', 'modal-dialog vertical-align-center ' + e.currentTarget.attributes.modalClass.value);
                            }

                            query('.iframe-modal .modal-title').attr('innerHTML', title);
                            query('.iframe-modal').on('show.bs.modal', function () {
                                query('#modalFrame').attr('src', url);                                
                            });
                            query('[id="iframeModalDiv"]').modal('show');

                            /******************************************************************************************/
                            e.stopPropagation();
                        }
                    };
                    break;
            }

            anchorNode = domConstruct.create("a", anchorOptions, refNode, pos);
            domConstruct.create("span", { 'class': iconClass, "aria-hidden": "true" }, anchorNode, "last");
            domConstruct.create("span", { 'class': "layerRelatedLinkTitle", innerHTML: title }, anchorNode, "last");
        },

        // get glossaryLink
        _getAnchorOptionsforGlossaryLinks: function (title, keywordId, cssClass) {
            var anchorOption = {
                        target: '_blank',
                        innerHTML: title,
                        'class': cssClass,
                        onclick: function (e) {
                            topic.publish('PortalGlossary/ShowModal', keywordId);
                            e.stopPropagation();
                        }
                    };
            return anchorOption;
        },
        getSimpleFillSymbol: function (fillColour, fillTransparency, borderColour, borderTransparency, borderWidth) {
            var fillColor = new Color(fillColour),
                borderColor = new Color(borderColour),
                width = 1;

            fillColor.a = fillTransparency;
            borderColor.a = borderTransparency;
            if (borderWidth) {
                width = borderWidth;
            }
            return new SimpleFillSymbol(SimpleFillSymbol.STYLE_SOLID,
                    new SimpleLineSymbol(
                        SimpleLineSymbol.STYLE_SOLID,
                        borderColor,
                        width),
                fillColor);
        },
        addGraphicFeatureToLayer: function (layer, feature, icon, idHelper) {
            //id helper is used to ensure we have unique ids, instead of using the id from a copy of the feature
            if (feature) {
                if (feature.attributes) {
                    if (icon.width && icon.height) {
                        feature.setSymbol(new PictureMarkerSymbol(icon.url, icon.width, icon.height));
                    } else {
                        //icon is actually a symbol object
                        feature.setSymbol(icon);
                    }
                    if (idHelper) {
                        feature.attributes.id = idHelper;
                    }
                    layer.add(new Graphic(feature.geometry, feature.symbol, feature.attributes, feature.infoTemplate));
                }
            }
        },
        reorderLayers: function (map) {
            var layer, j, allVisibleLayers = [];

            // GraphicsLayers and FeatureLayers are maintained in graphicsLayerIds. all others stored in layerIds
            // Layer order defined in config.js based on following rules:
            // Layer 0: all basemaps 
            // layer 1: luf, powerlines, access, oilsandsBusinessData, caribou, Biodiversity, ProjectBoundaries, all Lands layer
            // layer 2: tailingsPond
            // Layer 3: OS_Projects, industrialEmissions, aqhiLayer, riverFlowStations, riverQualityStations, lakeLevelStations, riverFlowStations

            for (j = 0; j < map.layerIds.length; j += 1) {
                layer = map.getLayer(map.layerIds[j]);
                if (!layer.layerOrder) { // if layerOrder is undefined set it to 0
                    layer.layerOrder = 0;
                }
                if (layer.visible) {
                    allVisibleLayers.push(layer);
                }
            }

            for (j = 0; j < map.graphicsLayerIds.length; j += 1) {
                layer = map.getLayer(map.graphicsLayerIds[j]);
                if (!layer.layerOrder) { // if undefined
                    layer.layerOrder = 0;
                }
                if (layer.visible) {
                    allVisibleLayers.push(layer);
                }
            }
            // sort all layers based on descending layer order, seems arcgis requires top layer to be reordered first
            allVisibleLayers.sort(function (a, b) {
                if (a.layerOrder > b.layerOrder) { return -1; }
                if (a.layerOrder < b.layerOrder) { return 1; }
                return 0;
            });

            //var test = allVisibleLayers.map(function (layer) { return layer.layerOrder + "-" + layer.id; });
            allVisibleLayers.forEach(function (layer) {
                map.reorderLayer(layer, layer.layerOrder);
            });
        },
        showToolTipDialog: function (event, dialogId, tipContent, tipStyle) {
            var dialog = registry.byId(dialogId);

            if (dialog) {
                dialog.destroy();
            }
            if (tipStyle) {
                dialog = new TooltipDialog({
                    id: dialogId,
                    content: tipContent,
                    style: tipStyle
                });
            } else {
                dialog = new TooltipDialog({
                    id: dialogId,
                    content: tipContent,
                    'class': "dark-blue-txt"
                });
            }
            
            dialog.startup();
            place.at(dialog.domNode, { x: event.pageX, y: event.pageY }, ["TL", "BL"], { x: 10, y: 10 });
        },
        closeToolTipDialog: function (dialogId) {
            var dialog = registry.byId(dialogId);
            if (dialog) {
                dialog.destroy();
            }
        }
    };
});
