﻿define([
  'dojo/_base/array',
  'dojo/promise/all',
  'dojo/Deferred',
  './modules/ContentGroupLink',
  './modules/ContentGroupOperationalLayerTitle',
  './modules/ContentGroupOperationalLayerMultiLayerTitle',
  './modules/ContentGroupOperationalLayerMultiLayerLink',
  './modules/ContentGroupOperationalLayerRelatedLink',
  './modules/MapLayerOSIPProject'
], function (array, all, Deferred,
    //modules
    ContentGroupLink,
    ContentGroupOperationalLayerTitle,
    ContentGroupOperationalLayerMultiLayerTitle,
    ContentGroupOperationalLayerMultiLayerLink,
    ContentGroupOperationalLayerRelatedLink,
    MapLayerOSIPProject
) {
    'use strict';
    return {
        getSearchModules: function() {
            if (!this.searchModules) {
                this.searchModules = this.initializeSearchModules();
            }
            return this.searchModules;
        },
        initializeSearchModules: function () {
            return [
                new ContentGroupLink(),
                new ContentGroupOperationalLayerTitle({ moduleIdentifier: 'ContentGroupOperationalLayerTitle', expressionPath: "//contentGroups/group/operationalLayers[contains(title, \"${searchText}\")]" }),
                new ContentGroupOperationalLayerMultiLayerTitle({ moduleIdentifier: 'ContentGroupOperationalLayerMultiLayerTitle', expressionPath: "//contentGroups/group/operationalLayers/options/multiLayers[contains(title, \"${searchText}\")]" }),
                new ContentGroupOperationalLayerMultiLayerLink({ moduleIdentifier: 'ContentGroupOperationalLayerMultiLayerLink', expressionPath: "//contentGroups/group/operationalLayers/options/multiLayers/link[contains(title, \"${searchText}\")]" }),
                new ContentGroupOperationalLayerRelatedLink({ moduleIdentifier: 'ContentGroupOperationalLayerRelatedLink', expressionPath: "//contentGroups/group/operationalLayers/relatedLinks[contains(title, \"${searchText}\")]" }),
                new MapLayerOSIPProject(),
                new ContentGroupOperationalLayerTitle({ moduleIdentifier: 'ContentSubGroupOperationalLayerTitle', expressionPath: "//contentGroups/group/operationalLayers/subGroups/operationalLayers/subGroups/operationalLayers[contains(title, \"${searchText}\")]" }),
                new ContentGroupOperationalLayerRelatedLink({ moduleIdentifier: 'ContentSubGroupOperationalLayerRelatedLink', expressionPath: "//contentGroups/group/operationalLayers/subGroups/operationalLayers/subGroups/operationalLayers/relatedLinks[contains(title, \"${searchText}\")]" }),
                new ContentGroupOperationalLayerMultiLayerTitle({ moduleIdentifier: 'ContentSubGroupOperationalLayerMultiLayerTitle', expressionPath: "//contentGroups/group/operationalLayers/subGroups/operationalLayers/subGroups/operationalLayers/options/multiLayers[contains(title, \"${searchText}\")]" })
            ];
        },
        search: function (searchText) {
            var deferredResults = {};

            array.forEach(this.getSearchModules(), function (searchModule) {
                deferredResults[searchModule.searchModuleIdentifier] = searchModule.searchAsync(searchText);
            });

            var anyResults = false;
            var groupedResults = {};

            var deferred = new Deferred();

            all(deferredResults).then(function (completedResults) {
                Object.keys(completedResults).forEach(function (searchModuleIdentifier) {
                    var moduleResults = completedResults[searchModuleIdentifier];

                    if (moduleResults.length > 0) {
                        anyResults = true;

                        array.forEach(moduleResults, function (moduleResult) {
                            if(!groupedResults.hasOwnProperty(moduleResult.resultType)) {
                                groupedResults[moduleResult.resultType] = [moduleResult];
                            } else {
                                groupedResults[moduleResult.resultType].push(moduleResult);
                            }
                        });
                    }
                });
                
                if (anyResults === true) {
                    deferred.resolve(groupedResults);
                } else {
                    deferred.resolve(null);
                }
            });

            return deferred;
        }
    };
});