﻿/*property
    ENTER, _attachEventHandlers, add, clearSearchButton, focus, inherited,
    keyCode, log, postCreate, publish, remove, searchButton, searchButtonIcon,
    searchInput, strings, subscribe, templateString, value
*/
define([
  'dojo/_base/declare',
  'dojo/topic',
  'dojo/on',
  'dojo/keys',
  'dojo/dom-class',

  'dijit/_WidgetBase',
  'dijit/_TemplatedMixin',

  'dojo/text!./templates/SearchBar.html',
  'dojo/i18n!app/layout/nls/strings',

  'dojo-bootstrap/Collapse',
  'dojo-bootstrap/Dropdown'
], function (
  declare, topic, on, keys, domClass,
  _WidgetBase, _TemplatedMixin,
  template, strings
) {
    return declare([_WidgetBase, _TemplatedMixin], {
        templateString: template,
        strings: strings,

        postCreate: function () {
            this.inherited(arguments);
            this._attachEventHandlers();
        },

        _attachEventHandlers: function () {
            var self = this;

            topic.subscribe('SearchEngine/ResultsReady', function() {
                domClass.remove(self.searchButtonIcon, 'glyphicon-refresh spinning');
                domClass.add(self.searchButtonIcon, 'glyphicon-search');
            });

            var searchHandler = function(ignore) {
                try {
                    var searchText = self.searchInput.value;

                    if (searchText) {
                        domClass.remove(self.searchButtonIcon, 'glyphicon-exclamation-sign');
                        domClass.remove(self.searchButtonIcon, 'glyphicon-search');
                        domClass.add(self.searchButtonIcon, 'glyphicon-refresh spinning');
                        topic.publish('SearchBar/SearchInvoked', searchText);
                    } else {
                        domClass.add(self.searchInput, 'has-error');
                        setTimeout(function() {
                            domClass.remove(self.searchInput, 'has-error');
                        }, 300);
                        self.searchInput.focus();
                    }
                    return false;
                } catch (e) {
                    console.log(e);
                    domClass.remove(self.searchButtonIcon, 'glyphicon-refresh spinning');
                    domClass.add(self.searchButtonIcon, 'glyphicon-exclamation-sign');
                } finally {
                    return false;
                }
            };

            on(self.searchButton, 'click', function (event) {
                searchHandler(event);
            });
            on(self.searchInput, 'keypress', function (event) {
                if (event.keyCode === keys.ENTER) {
                    searchHandler(event);
                }
            });
            on(self.searchInput, 'keyup', function (ignore) {
                if (self.searchInput.value) {
                    domClass.remove(self.clearSearchButton, 'hidden');
                } else {
                    domClass.add(self.clearSearchButton, 'hidden');
                }
            });
            on(self.clearSearchButton, 'click', function (ignore) {
                self.searchInput.value = '';
                topic.publish('map/execute', function () { topic.publish('map/hideSearchLayer'); });
                domClass.add(self.clearSearchButton, 'hidden');
            });
        }
    });
});