﻿/*property
    _setResultsPanelGroupAttr, _setTitleAttr, add, class, create, domNode,
    empty, field, forEach, glyphIconClass, hasOwnProperty, hitch, href,
    innerHTML, keys, length, matchedValue, modal, modalSearchResultsTitle,
    navigateAction, navigateUrl, node, postCreate, remove, resultsTableBody,
    resultsTitle, rowspan, searchResults, searchTerm, searchText, set, strings,
    subscribe, substitute, target, templateString, title, type
*/
define([
  'dojo/_base/declare',
  'dojo/_base/lang',
  'dojo/topic',
  'dojo/query',
  'dojo/string',
  'dojo/dom-construct',
  'dojo/on',
  'dojo/dom-class',
  'dijit/_WidgetBase',
  'dijit/_TemplatedMixin',
  'dojo/text!./templates/SearchResultsModal.html',
  'dojo/i18n!app/layout/nls/strings',
  'dojo-bootstrap/Modal'
], function (declare, lang, topic, query, string, domConstruct, on, domClass,
  _WidgetBase, _TemplatedMixin,
  template, strings
) {
    'use strict';
    return declare([_WidgetBase, _TemplatedMixin], {
        templateString: template,
        strings: strings,
        _setTitleAttr: {
            node: 'titleNode',
            type: 'innerHTML'
        },

        _setResultsPanelGroupAttr: {
            node: 'resultsPanelGroupNode',
            type: 'innerHTML'
        },

        // get default title/content from i18n strings
        postCreate: function () {
            topic.subscribe('SearchEngine/ResultsReady', lang.hitch(this, function (searchResultsModel) {
                var isFirstResultOfGroup;
                this.set('title', string.substitute(strings.modalSearchResultsTitle, { searchTerm: searchResultsModel.searchText }));
                domConstruct.empty(this.resultsTableBody);
                if (!searchResultsModel.searchResults) {
                    domClass.add(this.domNode, 'search-results-not-found');
                    domClass.remove(this.domNode, 'search-results-found');
                } else {
                    domClass.add(this.domNode, 'search-results-found');
                    domClass.remove(this.domNode, 'search-results-not-found');

                    Object.keys(searchResultsModel.searchResults).forEach(lang.hitch(this, function(resultGroupName) {
                        if (searchResultsModel.searchResults.hasOwnProperty(resultGroupName)) {
                            isFirstResultOfGroup = true;

                            searchResultsModel.searchResults[resultGroupName].forEach(lang.hitch(this, function(searchResult) {
                                var resultRow = domConstruct.create('tr', {}, this.resultsTableBody, 'last');

                                if (isFirstResultOfGroup === true) {
                                    isFirstResultOfGroup = false;
                                    domConstruct.create("td", {
                                        innerHTML: resultGroupName,
                                        rowspan: searchResultsModel.searchResults[resultGroupName].length,
                                        'class': 'search-result-type-cell'
                                    }, resultRow, 'last');
                                }

                                // cells: Icon/Title, Field, Matched
                                var titleCell = domConstruct.create('td', {
                            
                                }, resultRow, 'last');

                                var titleAnchor = domConstruct.create("a", {
                                    //href: searchResult.navigateUrl || 'javascript:;',
                                    href: searchResult.navigateUrl || '#',
                                    target: (searchResult.navigateUrl) ? '_blank' : ''
                                }, titleCell, 'last');

                                domConstruct.create("span", {
                                        title: searchResult.title,
                                        'class': 'icon glyphicon ' + searchResult.glyphIconClass + ' search-result-icon',
                                        'aria-hidden': true
                                    },
                                    titleAnchor, 'last');

                                domConstruct.create("span", {
                                        innerHTML: searchResult.title
                                    },
                                    titleAnchor, 'last');

                                if (!searchResult.navigateUrl) {
                                    if (searchResult.navigateAction) {
                                        on(titleAnchor, 'click', function() {
                                            searchResult.navigateAction();
                                            query('#searchResultsModalDiv').modal('hide');
                                        });
                                    } else {
                                        throw 'Navigation not configured for ' + this.resultsTitle;
                                    }
                                }

                                domConstruct.create('td', {
                                    innerHTML: searchResult.field
                                }, resultRow, 'last');

                                domConstruct.create('td', {
                                    innerHTML: searchResult.matchedValue
                                }, resultRow, 'last');

                            }));
                        }
                    }));
                }

                query('#searchResultsModalDiv').modal('show');
            }));
        }

    });
});