﻿define([
    'dojo/_base/declare',
    'dojo/_base/lang',
    'dojo/io-query',
    'app/utils/SimpleEncoder',
    'history.js/dojo.history' //Creates global History object
], function (declare, lang, ioQuery, encoder) {
    'use strict';
    return declare(null, {
        encode: true,
        cleanLoad: true,
        justSavedState: false,
        justRestoredState: false,
        queryStringParameter: "state",
        queryStringStub: null,
        constructor: function (options) {
            if (!options) {
                //if no options were passed then create the options objects so the following if statements don't produce errors.
                options = {};
            }
            History.options.busyDelay = 500;//https://github.com/browserstate/history.js#options
            if (options.queryStringParameter) {
                this.queryStringParameter = options.queryStringParameter;
            }
            this.queryStringStub = "?" + this.queryStringParameter + "=";
            if (options.getState) {
                this.getState = options.getState;
            }
            if (options.onStateChange) {
                //if user provided onStateChange function then use that instead.
                this.onStateChange = options.onStateChange;
            }
            if (options.restoreState) {
                //if user provided restoreState function then use that instead.
                this.restoreState = options.restoreState;
            }
            if (options.encode !== undefined) {
                this.encode = options.encode;
            }
            History.Adapter.bind(window, 'statechange', lang.hitch(this, this.onStateChange));
        },

        saveState: function () {
            /// <summary>save the current state of the application.</summary>
            if (!this.justRestoredState && !this.cleanLoad) {
                this.justSavedState = true;
                var state = this.getState(), encodedState;
                if (this.encode) {
                    encodedState = encoder.encodeString(JSON.stringify(state));
                } else {
                    //still need to use encodeURI so that all characters are safe to use in the URI
                    encodedState = encodeURI(JSON.stringify(state));
                }
                History.pushState(state, null, this.queryStringStub + encodedState);
            } else {
                this.justRestoredState = false;
            }
        },

        ///  This function should return an object containing all the 
        getState: function () {
            /// <summary>getState is a delegate function defined/overriden by the application.</summary>
            /// <returns type="Object">An object containing anything that should be saved in the state.</returns>
            var message = "getState has not been defined by the application.";
            console.log(message);
            return {
                message: message
            };
        },
        getStateFromHistory: function() {
            return History.getState();
        },
        onStateChange: function () {
            if (!this.justSavedState && !this.cleanLoad) {
                var state = History.getState();
                this.restoreState(state);
                this.justRestoredState = true;
            } else {
                this.justSavedState = false;
                this.cleanLoad = false;
            }
        },
        //onAnchorChange: function (e) {
        //    console.log("window anchor change", e);
        //    var state = History.getState();
        //    console.log(state);
        //},
        getStateFromQueryString: function () {
            /// <summary>This function is for loading the state from the query string at page load.</summary>
            var uri = location.href,
                query = uri.substring(uri.indexOf("?") + 1, uri.length),
                queryObject = ioQuery.queryToObject(query), state = null,
                parameter = queryObject[this.queryStringParameter];
            if (parameter !== undefined) {
                try {
                    if (this.encode) {
                        state = JSON.parse(encoder.decodeString(queryObject[this.queryStringParameter]));
                    } else {
                        state = JSON.parse(decodeURI(queryObject[this.queryStringParameter]));
                    }
                } catch (e) {
                    if (e instanceof SyntaxError) {
                        //JSON.parse failed so just return the value
                        if (this.encode) {
                            state = encoder.decodeString(queryObject[this.queryStringParameter]);
                        } else {
                            state = decodeURI(queryObject[this.queryStringParameter]);
                        }
                    } else {
                        console.error(e);
                    }
                } 
            }
            return state;
        },
        restoreState: function (state) {
            /// <summary>restoreState is a delegate function defined/overriden by the application that should restore the state of the application using the provided state object.</summary>
            /// <returns type="boolean">Whether or not the state was successfully restored.</returns>
            var message = "restoreState has not been defined by the application.",
                result = {
                    message: message,
                    state: state
                };
            console.log(result);
            return false;
        }
    });
});