﻿define([
    'dojo/_base/array',
    'dojo/_base/lang',
    'dojox/encoding/base64'
], function (array, lang, base64) {
    'use strict';
    return {
        encodeString: function(text) {
            return base64.encode(this.stringToByteArray(text));
        },
        decodeString: function(encodedText) {
            return this.byteArrayToString(base64.decode(encodedText));
        },
        stringToByteArray: function(text) {
            var bytes = [], i, len;
            text = encodeURI(text);//we encode the text so that any characters outside the Latin1 set can also be converted.
            for (i = 0, len = text.length; i < len; i++) {//ignoring jslint error on this line. storing the length in a var prevents it from being computed each iteration and improves performance. http://jsperf.com/loops/70
                bytes.push(text.charCodeAt(i));
            }
            return bytes;
        },
        byteArrayToString: function(byteArray) {
            var result = "", i, len;
            for (i = 0, len = byteArray.length; i < len; i++) {
                result += String.fromCharCode(byteArray[i]);
            }
            return decodeURI(result);
        }
    };
});
