// This file in the main entry point for defining grunt tasks and using grunt plugins.
// Click here to learn more. http://go.microsoft.com/fwlink/?LinkID=513275&clcid=0x409
/*jslint 
    node: true
*/
module.exports = function (grunt) {
    'use strict';
    grunt.initConfig({
        bower: {
            install: {
                options: {
                    targetDir: "Scripts/lib",
                    layout: "byComponent",
                    cleanTargetDir: false,
                    cleanBowerDir: false,
                    verbose: true
                }
            }
        },
        intern: {
            dev: {
                options: {
                    runType: 'client',
                    config: 'tests/intern'
                }
            }
        },
        esri_slurp: {
            dev: {
                options: {
                    version: '3.20',
                    packageLocation: 'Scripts/lib/esri',
                    beautify: true
                },
                dest: 'Scripts/lib/esri'
            }
        },
        copy: {
            replace_esri_profile: {
                //This task replaces the esri build profile with an edited version that includes the GeometryEngine and GeometryEngineAsync
                files: [
                    { expand: true, cwd: 'profiles', src: ['esri.profile.js'], dest: 'Scripts/lib/esri/'}
                ]
            },
            release_bundle: {
                //This task creates a folder containing all of the files required for a release deployment. 
                //The Web.config is added and modified to set debug to false in the xmlpoke:update_release_config task
                files: [
                    { expand: true, src: ['bin/**'], dest: 'deploy/' },
                    { expand: true, src: ['App_Start/**'], dest: 'deploy/' },
                    { expand: true, src: ['Content/**'], dest: 'deploy/' },
                    { expand: true, src: ['Images/**'], dest: 'deploy/' },
                    { expand: true, src: ['Scripts/agsjs/**'], dest: 'deploy/' },
                    { expand: true, src: ['Scripts/app/**'], dest: 'deploy/' },
                    { expand: true, src: ['Scripts/lib/bootstrap/**'], dest: 'deploy/' },
                    { expand: true, src: ['Scripts/lib/bootstrap-map-js/**'], dest: 'deploy/' },
                    { expand: true, src: ['Scripts/lib/defiantjs/**'], dest: 'deploy/' },
                    { expand: true, src: ['Scripts/lib/dojo-bootstrap/**'], dest: 'deploy/' },
                    { expand: true, src: ['Scripts/lib/history.js/**'], dest: 'deploy/' },
                    { expand: true, src: ['Scripts/lib/spin.js/**'], dest: 'deploy/' },
                    { expand: true, src: ['Global.asax'], dest: 'deploy/' },
                    { expand: true, src: ['packages.config'], dest: 'deploy/' },
                    { expand: true, src: ['Views/**'], dest: 'deploy/' }

                ]
            },
            release_bundle_min: {
                //This task creates a folder containing all of the minified files required for a release deployment. dojo_build needs to run before this task.
                //The Web.config is added and modified to set debug to false in the xmlpoke:update_release_config task
                files: [
                    { expand: true, src: ['bin/**'], dest: 'deploy/' },
                    { expand: true, src: ['App_Start/**'], dest: 'deploy/' },
                    { expand: true, src: ['Content/**'], dest: 'deploy/' },
                    { expand: true, src: ['Images/**'], dest: 'deploy/' },
                    { expand: true, src: ['Scripts/lib/bootstrap/**'], dest: 'deploy/' },
                    { expand: true, cwd: 'dist/', src: ['app/dojoConfig.js'], dest: 'deploy/Scripts/' },
                    { expand: true, cwd: 'dist/', src: ['app/content/images/**'], dest: 'deploy/Scripts/' },
                    { expand: true, cwd: 'dist/', src: ['app/content/data/**'], dest: 'deploy/Scripts/' },
                    { expand: true, cwd: 'dist/', src: ['agsjs/dijit/images/**'], dest: 'deploy/Scripts/' },
                    { expand: true, cwd: 'dist/dojo/', src: ['dojo.js', 'dojo.js.map'], dest: 'deploy/Scripts/dojo/', nonull: true },
                    { expand: true, cwd: 'dist/dojo/', src: ['nls/*.js', 'nls/*.map', '!nls/*.uncompressed.js', '!nls/*.consoleStripped.js'], dest: 'deploy/Scripts/dojo/', nonull: true },
                    { expand: true, cwd: 'dist/dojo/', src: ['cldr/nls/**/*.js', 'cldr/nls/**/*.map', '!cldr/nls/**/*.uncompressed.js', '!cldr/nls/**/*.consoleStripped.js'], dest: 'deploy/Scripts/dojo/', nonull: true },
                    { expand: true, cwd: 'dist/', src: ['dojo/resources/**'], dest: 'deploy/Scripts/', nonull: true },
                    { expand: true, cwd: 'dist/', src: ['bootstrap-map-js/css/bootstrapmap.css'], dest: 'deploy/Scripts/lib/' },
                    { expand: true, cwd: 'dist/', src: ['esri/css/**'], dest: 'deploy/Scripts/lib/' },
                    { expand: true, cwd: 'dist/', src: ['esri/dijit/images/**'], dest: 'deploy/Scripts/', nonull: true },
                    { expand: true, cwd: 'dist/', src: ['esri/geometry/geometryenginewebworker.js'], dest: 'deploy/Scripts/' },
                    { expand: true, src: ['Global.asax'], dest: 'deploy/' },
                    { expand: true, src: ['packages.config'], dest: 'deploy/' },
                    { expand: true, src: ['Views/**'], dest: 'deploy/' }
                ]
            }
        },
        clean: {
            esri: ['Scripts/lib/esri'],
            lib: ['Scripts/lib'],
            release_bundle: ['deploy'],
            dist: ['dist']
        },
        xmlpoke: {
            set_dojo_build_type: {
                options: {
                    replacements: [
                        {
                            xpath: "configuration/appSettings/add[@key='buildType']/@value",
                            value: 'dojo'
                        },
                        {
                            xpath: 'configuration/system.web/compilation/@debug',
                            value: 'false'
                        }
                    ]
                },
                files: {
                    'deploy/Web.config': 'Web.config',
                    'deploy/Web.Debug.config': 'Web.Debug.config',
                    'deploy/Web.Dev.Int.config': 'Web.Dev.Int.config',
                    'deploy/Web.Release.config': 'Web.Release.config'
                }
            },
            set_cdn_build_type: {
                options: {
                    replacements: [
                        {
                            xpath: "configuration/appSettings/add[@key='buildType']/@value",
                            value: 'cdn'
                        },
                        {
                            xpath: 'configuration/system.web/compilation/@debug',
                            value: 'false'
                        }
                    ]
                },
                files: {
                    'deploy/Web.config': 'Web.config',
                    'deploy/Web.Debug.config': 'Web.Debug.config',
                    'deploy/Web.Dev.Int.config': 'Web.Dev.Int.config',
                    'deploy/Web.Release.config': 'Web.Release.config'
                }
            }
        },
        dojo: {
            // dojo build configuration, mainly taken from dojo boilerplate
            dist: {
                options: {
                    profile: 'profiles/app.profile.js' // Profile for build
                }
            },
            options: {
                dojo: 'Scripts/lib/dojo/dojo.js', // Path to dojo.js file in dojo source
                load: 'build', // Optional: Utility to bootstrap (Default: 'build')
                // profiles: [], // Optional: Array of Profiles for build
                // appConfigFile: '', // Optional: Config file for dojox/app
                // package: '', // Optional: Location to search package.json (Default: nothing)
                // packages: [], // Optional: Array of locations of package.json (Default: nothing)
                // require: '', // Optional: Module to require for the build (Default: nothing)
                // requires: [], // Optional: Array of modules to require for the build (Default: nothing)
                releaseDir: 'dist', // Optional: release dir rel to basePath (Default: 'release')
                cwd: './', // Directory to execute build within
                // dojoConfig: '', // Optional: Location of dojoConfig (Default: null),
                // Optional: Base Path to pass at the command line
                // Takes precedence over other basePaths
                // Default: null
                basePath: './'
            }
        }
    });

    // This command registers the default task which will install bower packages into lib
    grunt.registerTask('bower', ['bower:install']);
    grunt.registerTask('default', ['bower:install', 'slurp']);
    grunt.registerTask('clean:all', ['clean:lib', 'clean:dist', 'clean:release_bundle']);
    grunt.registerTask('slurp', ['clean:esri', 'esri_slurp:dev', 'copy:replace_esri_profile']);
    grunt.registerTask('test', ['intern']);
    grunt.registerTask('dojo_build', ['copy:replace_esri_profile', 'clean:dist', 'dojo']);
    grunt.registerTask('create_dojo_release', ['clean:release_bundle', 'copy:release_bundle_min', 'xmlpoke:set_dojo_build_type']);
    grunt.registerTask('create_cdn_release', ['clean:release_bundle', 'copy:release_bundle', 'xmlpoke:set_cdn_build_type']);
    grunt.registerTask('build_and_release', ['dojo_build', 'create_dojo_release']);
    grunt.registerTask('all', ['clean:all', 'bower']);

    // The following line loads the grunt plugins.
    // This line needs to be at the end of this this file.
    grunt.loadNpmTasks("grunt-bower-task");
    grunt.loadNpmTasks('grunt-esri-slurp');
    grunt.loadNpmTasks('grunt-contrib-clean');
    grunt.loadNpmTasks('grunt-contrib-copy');
    grunt.loadNpmTasks('grunt-xmlpoke');
    grunt.loadNpmTasks('intern');
    grunt.loadNpmTasks('grunt-dojo');
};