﻿/*property
    AQHIValue, Abbreviation, Address, AirshedName, CommunityStationName,
    Description, DeterminantParameter, Elevation, HasData, HealthRisk, Id,
    LastUpdated, Latitude, Longitude, MonitorsAQI, ObjectID, ReadingDate,
    StationName, Type, URL, _getAQHIIcon, _getAllAQHIStations, async,
    attributeField, attributes, breaks, dataUrl, deepEqual, defaultSymbol,
    equal, fail, getRenderer, include, infoWindowHandlerContent,
    infoWindowHandlerTitle, infos, isNotNull, isObject, isTrue, length,
    libraryUrl, log, name, reject, resolve, setup, some, strictEqual, symbol,
    then, url, innerHTML, childNotes
*/

define([
    'intern!object',
    'intern/chai!assert',
    'dojo/_base/array',
    'dojo/query',
    'esri/renderers/ClassBreaksRenderer',
    'app/content/AQHIContent'
], function (registerSuite, assert, array, query, ClassBreaksRenderer, AQHIContent) {
    'use strict';
    var aqhiContentModule,
        expectedAQHIIcon1 = '/Scripts/app/content/images/air/aqhi1.png',
        expectedAQHIIcon2 = '/Scripts/app/content/images/air/aqhi2.png',
        expectedAQHIIcon3 = '/Scripts/app/content/images/air/aqhi3.png',
        expectedAQHIIcon4 = '/Scripts/app/content/images/air/aqhi4.png',
        expectedAQHIIcon5 = '/Scripts/app/content/images/air/aqhi5.png',
        expectedAQHIIcon6 = '/Scripts/app/content/images/air/aqhi6.png',
        expectedAQHIIcon7 = '/Scripts/app/content/images/air/aqhi7.png',
        expectedAQHIIcon8 = '/Scripts/app/content/images/air/aqhi8.png',
        expectedAQHIIcon9 = '/Scripts/app/content/images/air/aqhi9.png',
        expectedAQHIIcon10 = '/Scripts/app/content/images/air/aqhi10.png',
        expectedAQHIIconPlus = '/Scripts/app/content/images/air/aqhiPlus.png';
    registerSuite({
        name: 'AQHI Content module tests',
        setup: function () {
            aqhiContentModule = new AQHIContent({ dataUrl: 'http://aemeris.alberta.ca/data/', libraryUrl: 'http://aemeris.alberta.ca/library/' });
        },

        'Test Get All Air Quality Stations': function () {
            var def = this.async(1000), stationData, expectedStation = {
                Id: 49,
                HasData: false,
                MonitorsAQI: false,
                AQHIValue: 0,
                HealthRisk: "Unknown",
                DeterminantParameter: "Unknown",
                ReadingDate: "/Date(-62135571600000)/",
                LastUpdated: "Last updated unknown.",
                StationName: "Smoky Heights",
                CommunityStationName: "Smoky Heights",
                Abbreviation: "03PASZA",
                AirshedName: "Peace AirShed Zone Association",
                Type: "Operational",
                Description: "Not Available",
                URL: "http://www.paza.ca/",
                Latitude: 55.405,
                Longitude: -118.275,
                Elevation: "Not Available",
                Address: "Unknown"
            };
            aqhiContentModule._getAllAQHIStations().then(function (data) {
                if (data.length === 0) {
                    assert.fail("Stations not available");
                    def.reject();
                } else {
                    array.some(data, function (item) {
                        if (item.Id === expectedStation.Id) {
                            stationData = item;
                            return true;
                        }
                    });
                    assert.deepEqual(stationData, expectedStation, 'Unexpected station data.');
                    def.resolve(data);
                }
            },
             function (error) {
                 console.log(error);
                 def.reject();
             });
        },

        'Test Get renderer': function () {
            var renderer = aqhiContentModule.getRenderer(), expectedDefaultIcon = '/Scripts/app/content/images/air/aqhi_white.png',
                expectedBreaks = 11, expectedAttributeField = 'AQHIValue';

            assert.isTrue(renderer instanceof ClassBreaksRenderer, 'Get Renderer doesn\'t return expected object');
            assert.isObject(renderer, 'expects an object');

            assert.include(renderer.defaultSymbol.url, expectedDefaultIcon, 'station doesn\'t have expected icon');
            assert.equal(renderer.breaks.length, expectedBreaks, 'Unexpected no. of breaks');
            assert.equal(renderer.attributeField, expectedAttributeField, 'Unexpected attribute field ');

            assert.include(renderer.infos[0].symbol.url, expectedAQHIIcon1, 'Unexpected icon');
            assert.include(renderer.infos[1].symbol.url, expectedAQHIIcon2, 'Unexpected icon');
            assert.include(renderer.infos[2].symbol.url, expectedAQHIIcon3, 'Unexpected icon');
            assert.include(renderer.infos[3].symbol.url, expectedAQHIIcon4, 'Unexpected icon');
            assert.include(renderer.infos[4].symbol.url, expectedAQHIIcon5, 'Unexpected icon');
            assert.include(renderer.infos[5].symbol.url, expectedAQHIIcon6, 'Unexpected icon');
            assert.include(renderer.infos[6].symbol.url, expectedAQHIIcon7, 'Unexpected icon');
            assert.include(renderer.infos[7].symbol.url, expectedAQHIIcon8, 'Unexpected icon');
            assert.include(renderer.infos[8].symbol.url, expectedAQHIIcon9, 'Unexpected icon');
            assert.include(renderer.infos[9].symbol.url, expectedAQHIIcon10, 'Unexpected icon');
            assert.include(renderer.infos[10].symbol.url, expectedAQHIIconPlus, 'Unexpected icon');
            

        },

        'Test InfoWindow Title handler': function () {
            var title, expectedTitle = 'Red Deer Air Quality',
                graphicObject = {
                    attributes: {
                        StationName: 'Red Deer',
                        Abbreviation: null,
                        AirshedName: null,
                        Type: 'Community',
                        ObjectID: 64,
                        CommunityStationName: null,
                        AQHIValue: 2,
                        HealthRisk: 'Low',
                        LastUpdated: 'Last updated 34 minutes ago.'
                    }
                };


            title = aqhiContentModule.infoWindowHandlerTitle(graphicObject);
            assert.strictEqual(title, expectedTitle, 'InfoWindowHandlerTitle error');

            graphicObject = {
                attributes: {
                    StationName: 'Edmonton',
                    Abbreviation: null,
                    AirshedName: null,
                    Type: 'Community',
                    ObjectID: 64,
                    CommunityStationName: null,
                    AQHIValue: 3,
                    HealthRisk: 'Low',
                    LastUpdated: 'Last updated 34 minutes ago.'
                }
            };
            expectedTitle = 'Edmonton Air Quality';

            title = aqhiContentModule.infoWindowHandlerTitle(graphicObject);
            assert.strictEqual(title, expectedTitle, 'InfoWindowHandlerTitle error');
        },

        'Test InfoWindow Content handler': function () {
            var graphicObject = {
                attributes: {
                    StationName: 'Red Deer',
                    Abbreviation: null,
                    AirshedName: null,
                    Type: 'Community',
                    ObjectID: 64,
                    CommunityStationName: null,
                    AQHIValue: 2,
                    HealthRisk: 'Low',
                    LastUpdated: 'Last updated 34 minutes ago.'
                }
            },
            contentNode = aqhiContentModule.infoWindowHandlerContent(graphicObject),
            sectionList = query('.infoWindowSection', contentNode),
            sectionContent = null;

            assert.equal(sectionList.length, 4, 'section number is wrong');
            sectionContent = sectionList[0].innerHTML;
            assert.include(sectionContent, 'Last updated 34 minutes ago.', 'content does not match');
            
            sectionContent = query(':first-child', sectionList[1])[0].innerHTML;
            assert.include(sectionContent, 'View/Download Historic Station Readings', 'content does not match');

            sectionContent = query(':first-child', sectionList[2])[0].innerHTML;
            assert.include(sectionContent, 'More data on Air Quality Health Index', 'content does not match');

            sectionContent = query(':first-child', sectionList[3])[0].innerHTML;
            assert.include(sectionContent, 'Disclaimer', 'content does not match');

            graphicObject = {
                attributes: {
                    StationName: 'Fort McKay',
                    Abbreviation: '01WBEA',
                    AirshedName: 'Wood Buffalo Environmental Association',
                    Type: 'Operational',
                    ObjectID: 27,
                    CommunityStationName: 'Fort McKay',
                    AQHIValue: 5,
                    HealthRisk: 'Moderate',
                    LastUpdated: 'Last updated 34 minutes ago.'
                }
            };
            contentNode = aqhiContentModule.infoWindowHandlerContent(graphicObject);
            sectionList = query('.infoWindowSection', contentNode);

            assert.equal(sectionList.length, 5, 'section number is wrong');
            sectionContent = sectionList[0].innerHTML;
            assert.include(sectionContent, 'Last updated 34 minutes ago.', 'content does not match');

            sectionContent = query(':first-child', sectionList[1])[0].innerHTML;
            assert.include(sectionContent, 'Substance Measurements', 'content does not match');

            sectionContent = query(':first-child', sectionList[2])[0].innerHTML;
            assert.include(sectionContent, 'View/Download Historic Station Readings', 'content does not match');

            sectionContent = query(':first-child', sectionList[3])[0].innerHTML;
            assert.include(sectionContent, 'More data on Air Quality Health Index', 'content does not match');

            sectionContent = query(':first-child', sectionList[4])[0].innerHTML;
            assert.include(sectionContent, 'Disclaimer', 'content does not match');

        },

        'Test Get AQHI Icon': function () {
            var aqhiValue = 1, iconPath;
            iconPath = aqhiContentModule._getAQHIIcon(aqhiValue);
            assert.include(iconPath, expectedAQHIIcon1, 'Unexpected icon');

            aqhiValue = 2;
            iconPath = aqhiContentModule._getAQHIIcon(aqhiValue);
            assert.include(iconPath, expectedAQHIIcon2, 'Unexpected icon');

            aqhiValue = 3;
            iconPath = aqhiContentModule._getAQHIIcon(aqhiValue);
            assert.include(iconPath, expectedAQHIIcon3, 'Unexpected icon');

            aqhiValue = 4;
            iconPath = aqhiContentModule._getAQHIIcon(aqhiValue);
            assert.include(iconPath, expectedAQHIIcon4, 'Unexpected icon');

            aqhiValue = 5;
            iconPath = aqhiContentModule._getAQHIIcon(aqhiValue);
            assert.include(iconPath, expectedAQHIIcon5, 'Unexpected icon');

            aqhiValue = 6;
            iconPath = aqhiContentModule._getAQHIIcon(aqhiValue);
            assert.include(iconPath, expectedAQHIIcon6, 'Unexpected icon');

            aqhiValue = 7;
            iconPath = aqhiContentModule._getAQHIIcon(aqhiValue);
            assert.include(iconPath, expectedAQHIIcon7, 'Unexpected icon');

            aqhiValue = 8;
            iconPath = aqhiContentModule._getAQHIIcon(aqhiValue);
            assert.include(iconPath, expectedAQHIIcon8, 'Unexpected icon');

            aqhiValue = 9;
            iconPath = aqhiContentModule._getAQHIIcon(aqhiValue);
            assert.include(iconPath, expectedAQHIIcon9, 'Unexpected icon');

            aqhiValue = 10;
            iconPath = aqhiContentModule._getAQHIIcon(aqhiValue);
            assert.include(iconPath, expectedAQHIIcon10, 'Unexpected icon');

            aqhiValue = 11;
            iconPath = aqhiContentModule._getAQHIIcon(aqhiValue);
            assert.include(iconPath, expectedAQHIIconPlus, 'Unexpected icon');

            aqhiValue = 15;
            iconPath = aqhiContentModule._getAQHIIcon(aqhiValue);
            assert.include(iconPath, expectedAQHIIconPlus, 'Unexpected icon');
        }
    });
});
