﻿/*property
    Archive_Id, Archive_Name, _getAirQualityStationName,
    _getIndustryEmissionStationName, async, attributes, dataUrl, defaultLabel,
    defaultSymbol, equal, fail, getRenderer, include, infoWindowHandlerContent,
    infoWindowHandlerTitle, isNotNull, isObject, isTrue, length, libraryUrl,
    log, name, notInclude, reject, resolve, setup, strictEqual, then, url, innerHTML, childNotes,
    emissionStationName, some
*/

define([
    'intern!object',
    'intern/chai!assert',
    'esri/renderers/UniqueValueRenderer',
    'dojo/query',
    'app/content/AirEmissionsContent'
], function (registerSuite, assert, UniqueValueRenderer, query, AirEmissionsContent) {
    'use strict';
    var airContentModule,
        dataUrl = 'http://aemeris.alberta.ca/data/',
        libraryUrl = 'http://aemeris.alberta.ca/library/';
    registerSuite({
        name: 'Air Emissions Content module tests',
        setup: function () {
            airContentModule = new AirEmissionsContent({ dataUrl: dataUrl, libraryUrl: libraryUrl });
        },
        'Test Constructor': function () {
            assert.strictEqual(airContentModule.dataUrl, dataUrl, "Constructor doesn't return expected dataUrl.");
            assert.strictEqual(airContentModule.libraryUrl, libraryUrl, "Constructor doesn't return expected libraryUrl.");
            
            var hasValidData = false, def = this.async(5000);
            setTimeout(function () {
                assert.isTrue(airContentModule.emissionStationName.length > 0, "Constructor doesn't return webservice data.");
                hasValidData = airContentModule.emissionStationName.some(function (station) {
                    if (station.length > 0) {
                        return true;
                    }
                });
                assert.isTrue(hasValidData, "Constructor doesn't contain valid station names.");
                def.resolve();
            }, 3000); // need to wait for webservice data  
        },
        'Test Get renderer': function () {
            var renderer = airContentModule.getRenderer(), expectedStationIcon = '/Scripts/app/content/images/air/aqhi_black.png',
                expectedStationLabel = 'Industry Monitoring Station';
            assert.isTrue(renderer instanceof UniqueValueRenderer, "Get Renderer doesn't return expected object");
            assert.isObject(renderer, "expects an object");

            assert.equal(renderer.defaultLabel, expectedStationLabel, 'Unexpected label');
            assert.include(renderer.defaultSymbol.url, expectedStationIcon, 'station doesn\'t have expected icon');
        },

        'Test InfoWindow Title handler': function () {
            var title, graphicObject = { attributes: { Archive_Id: 1068, Archive_Name: 'Buffalo Viewpoint' } },
                expectedTitle = 'Buffalo Viewpoint Air Quality';
            title = airContentModule.infoWindowHandlerTitle(graphicObject);
            assert.strictEqual(title, expectedTitle, 'InfoWindowHandlerTitle error');

            graphicObject = { attributes: { Archive_Id: 1226, Archive_Name: 'CNRL Horizon' } };
            expectedTitle = 'CNRL Horizon Air Quality';
            title = airContentModule.infoWindowHandlerTitle(graphicObject);
            assert.strictEqual(title, expectedTitle, 'InfoWindowHandlerTitle error');
        },

        'Test InfoWindow Content handler': function () {
            var graphicObject = { attributes: { Archive_Id: 1068, Archive_Name: 'Buffalo Viewpoint' } },
                contentNode = airContentModule.infoWindowHandlerContent(graphicObject),
                sectionList = query('.infoWindowSection', contentNode),
                sectionContent = null;

            assert.equal(sectionList.length, 5, 'section number is wrong');
            sectionContent = query(':first-child', sectionList[0])[0].innerHTML;
            assert.include(sectionContent, 'Substance Measurements', 'Substance Measurements content does not exist');

            sectionContent = query(':first-child', sectionList[1])[0].innerHTML;
            assert.include(sectionContent, 'View/Download Historic Station Readings', 'View/Download Historic Station Readings content does not exist');

            sectionContent = query(':first-child', sectionList[2])[0].innerHTML;
            assert.include(sectionContent, 'More data on Air Quality Health Index', 'More data on Air Quality Health Index content does not exist');

            sectionContent = query(':first-child', sectionList[3])[0].innerHTML;
            assert.include(sectionContent, 'Disclaimer', 'Disclaimer content does not exist');
            
            sectionContent = query(':first-child', sectionList[4])[0].innerHTML;
            assert.include(sectionContent, 'Link to Airshed', 'Link to Airshed content does not exist');

            graphicObject = { attributes: { Archive_Id: 1167, Archive_Name: 'Smoky Heights' } };
            contentNode = airContentModule.infoWindowHandlerContent(graphicObject);
            sectionList = query('.infoWindowSection', contentNode);

            assert.equal(sectionList.length, 4, 'section number is wrong');
            sectionContent = query(':first-child', sectionList[0])[0].innerHTML;
            assert.include(sectionContent, 'Substance Measurements', 'Substance Measurements content does not exist');

            sectionContent = query(':first-child', sectionList[1])[0].innerHTML;
            assert.include(sectionContent, 'View/Download Historic Station Readings', 'View/Download Historic Station Readings content does not exist');

            sectionContent = query(':first-child', sectionList[2])[0].innerHTML;
            assert.include(sectionContent, 'More data on Air Quality Health Index', 'More data on Air Quality Health Index content does not exist');

            sectionContent = query(':first-child', sectionList[3])[0].innerHTML;
            assert.include(sectionContent, 'Disclaimer', 'Disclaimer content does not exist');
        },

        'Test Get Industry Emission station Name': function () {
            var stationName, graphicObject = { attributes: { Archive_Id: 1068, Archive_Name: 'Buffalo Viewpoint' } }, expectedStationName = 'Buffalo Viewpoint';
            stationName = airContentModule._getIndustryEmissionStationName(graphicObject);
            assert.equal(stationName, expectedStationName, 'Unexpected station name');

            graphicObject = { attributes: { Archive_Id: 1066, Archive_Name: 'Mildred Lake' } };
            expectedStationName = 'Mildred Lake';
            stationName = airContentModule._getIndustryEmissionStationName(graphicObject);
            assert.equal(stationName, expectedStationName, 'Unexpected station name');
        }
    });
});
