﻿/*property
    Banff, Bischto, LOCALRANG, LOCALRANGE, STATUS, STYLE_SOLID, SUBUNIT,
    _caribouStatus, _caribouSymbol, _getCaribouStatus, _layer,
    _loadCaribouRangeSuccess, _loadCaribouStatus, a, addGraphics, async,
    attributes, color, deepEqual, fail, features, geometry, getRenderer,
    graphics, include, infoWindowHandlerContent, infoWindowHandlerTitle,
    isTrue, label, length, name, outFields, outline, reject, resolve, rings,
    setSymbol, setup, some, spatialReference, strictEqual, stringify, style,
    symbol, then, wkid, xmax, xmin, ymax, ymin,Bischto,status,year,message,Narraway,
    Little Smoky,Red Earth,Caribou Mountains
*/

define([
    'intern!object',
    'intern/chai!assert',
    'esri/symbols/SimpleLineSymbol',
    'esri/symbols/SimpleFillSymbol',
    'esri/renderers/SimpleRenderer',
    'esri/layers/GraphicsLayer',
    'esri/geometry/Polygon',
    'esri/geometry/Extent',
    'dojo/_base/Color',
    'dojo/_base/array',
    'app/content/CaribouContent'
], function (registerSuite, assert, SimpleLineSymbol, SimpleFillSymbol, SimpleRenderer, GraphicsLayer, Polygon, Extent, Color, array, CaribouContent) {
    'use strict';
    var caribouContent;
    registerSuite({
        name: 'CaribouContent module tests',
        setup: function() {
            caribouContent = new CaribouContent();
        },
        'Test Constructor': function () {
            var expectedFillColor = new Color("#678F00"),
                expectedBorderColor = new Color("#678F00");

            expectedFillColor.a = 0.6;
            expectedBorderColor.a = 0.9;

            assert.isTrue(caribouContent._caribouSymbol instanceof SimpleFillSymbol, "Constructor doesn't create expected defaultSymbol");
            assert.isTrue(caribouContent._caribouSymbol.style === SimpleFillSymbol.STYLE_SOLID, "Constructor doesn't create expected symbol style");
            assert.isTrue(caribouContent._caribouSymbol.outline instanceof SimpleLineSymbol,
                "Constructor doesn't create expected outline symbol");
            assert.isTrue(caribouContent._caribouSymbol.outline.style === SimpleFillSymbol.STYLE_SOLID,
                "Constructor doesn't create expected outline style");
            assert.strictEqual(JSON.stringify(caribouContent._caribouSymbol.outline.color), JSON.stringify(expectedBorderColor),
                "Constructor doesn't create expected outline color");
            assert.strictEqual(JSON.stringify(caribouContent._caribouSymbol.color), JSON.stringify(expectedFillColor),
                "Constructor doesn't create expected color");

            assert.isTrue(caribouContent._caribouStatus.length > 0, "Constructor doesn't load Status Data");
        },
        'Test Load Caribou Status': function () {
            caribouContent._loadCaribouStatus();
            assert.isTrue(caribouContent._caribouStatus.length > 0, "Load Caribou Status doesn't return expected object");
        },
        'Test Get Caribou Status': function () {
            var fakeCaribouStatus = [{
                    Bischto:
                    {
                        status: "Declining",
                        year: "2015",
                        message: ""
                    },
                    Narraway:
                    {
                        status: "Declining",
                        year: "2015",
                        message: ""
                    },
                    'Little Smoky':
                    {
                        status: "Declining",
                        year: "2015",
                        message: "Stable over 5 year period (with wolf control)."
                    },
                    'Red Earth':
                    {
                        status: "Stable",
                        year: "2015",
                        message: "Declining over 5 year period."
                    },
                    'Caribou Mountains':
                    {
                        status: "Stable",
                        year: "2015",
                        message: "Declining over 5 year period."
                    }
                }],
                graphicObject = { attributes: { LOCALRANGE: "Bischto", STATUS: "Declining" } },
                expectedStatus = "Declining",
                expectedMessage = "Stable over 5 year period (with wolf control).",
                actualResult = null;

            caribouContent._caribouStatus = fakeCaribouStatus;

            actualResult = caribouContent._getCaribouStatus(graphicObject);
            assert.strictEqual(actualResult.status, expectedStatus, "Get Caribou Status doesn't return expected object");

            graphicObject = { attributes: { LOCALRANGE: "Little Smoky", STATUS: "Declining" } };
            expectedStatus = "Declining";
            actualResult = caribouContent._getCaribouStatus(graphicObject);
            assert.strictEqual(actualResult.status, expectedStatus, "Get Caribou Status doesn't return expected object");
            assert.strictEqual(actualResult.message, expectedMessage, "Get Caribou Status doesn't return expected object");

            graphicObject = { attributes: { LOCALRANGE: "Caribou Mountains", STATUS: "Stable" } };
            expectedStatus = "Stable";
            actualResult = caribouContent._getCaribouStatus(graphicObject);
            assert.strictEqual(actualResult.status, expectedStatus, "Get Caribou Status doesn't return expected object");

            graphicObject = { attributes: { LOCALRANGE: "Red Earth", STATUS: "Stable" } };
            expectedStatus = "Stable";
            expectedMessage = "Declining over 5 year period.";
            actualResult = caribouContent._getCaribouStatus(graphicObject);
            assert.strictEqual(actualResult.status, expectedStatus, "Get Caribou Status doesn't return expected object");
            assert.strictEqual(actualResult.message, expectedMessage, "Get Caribou Status doesn't return expected object");
        },
        'Test Get Renderer': function() {
            var expectedFillColor = new Color("#678F00"),
                expectedBorderColor = new Color("#678F00"),
                expectedLabel = "Woodland Caribou Range",
                result = caribouContent.getRenderer();

            expectedFillColor.a = 0.6;
            expectedBorderColor.a = 0.9;

            assert.isTrue(result instanceof SimpleRenderer, "Get Renderer doesn't return expected object");

            assert.isTrue(result.symbol instanceof SimpleFillSymbol, "Get Renderer doesn't contain expected defaultSymbol");
            assert.isTrue(result.symbol.style === SimpleFillSymbol.STYLE_SOLID, "Get Renderer Symbol doesn't have expected style");
            assert.isTrue(result.symbol.outline instanceof SimpleLineSymbol,
                "Get Renderer Symbol doesn't have expected Outline Symbol");
            assert.isTrue(result.symbol.outline.style === SimpleFillSymbol.STYLE_SOLID,
                "Get Renderer Symbol doesn't have expected Outline Style");
            assert.strictEqual(JSON.stringify(result.symbol.outline.color), JSON.stringify(expectedBorderColor),
                "Get Renderer Symbol doesn't have expected Outline Color");
            assert.strictEqual(JSON.stringify(result.symbol.color), JSON.stringify(expectedFillColor),
                "Get Renderer Symbol doesn't have expected Color");

            assert.strictEqual(result.label, expectedLabel, "Get Renderer doesn't have expected label");
        },
        'Test Add Graphics': function () {
            var layer = new GraphicsLayer(),
                mapServerUtl = "https://maps.alberta.ca/genesis_tokenauth/rest/services/Wildlife_Sensitivity/20150709/MapServer/236",
                options = {
                    outFields: ['OBJECTID', 'LOCALRANGE', 'STATUS', 'SUBUNIT']
                },
                iniExtent = new Extent({
                    xmin: -14265055.060527408,
                    ymin: 6259094.656300137,
                    xmax: -11283399.461180044,
                    ymax: 8409115.387905004,
                    spatialReference: {
                        wkid: 102100
                    }
                }),
                def = this.async(5000),
                hasValidData = false;

            caribouContent._layer = null;
            caribouContent.addGraphics(layer, mapServerUtl, options, iniExtent).then(function () {
                assert.isTrue(caribouContent._layer.graphics.length > 0, "Add Graphics doesn't save any graphic objects.");
                hasValidData = array.some(caribouContent._layer.graphics, function (graphic) {
                    if (graphic.attributes.LOCALRANGE.length > 0 && graphic.geometry instanceof Polygon) {
                        return true;
                    }
                });
                assert.isTrue(hasValidData, "Add Graphics doesn't contain valid data.");
                def.resolve();
            }, function (error) {
                assert.fail("Add Graphics failed: " + error);
                def.reject();
            });
        },
        'Test InfoWindowHandlerTitle': function () {
            var graphicObject = { attributes: { LOCALRANGE: "Bischto" } },
                expectedResult = "<span>Bischto Caribou Range</span>",
                result = caribouContent.infoWindowHandlerTitle(graphicObject);

            assert.strictEqual(result, expectedResult, "infoWindowHandlerTitle doesn't return expected result.");
            assert.include(result, graphicObject.attributes.LOCALRANGE, "LOCAL RANGE was not included in the output.");

            graphicObject = { attributes: { LOCALRANGE: "Little Smoky" } };
            expectedResult = "<span>Little Smoky Caribou Range</span>";
            result = caribouContent.infoWindowHandlerTitle(graphicObject);
            assert.strictEqual(result, expectedResult, "infoWindowHandlerTitle doesn't return expected result.");
            assert.include(result, graphicObject.attributes.LOCALRANGE, "LOCAL RANGE was not included in the output.");
        },
        'Test infoWindowHandlerContent': function () {
            var fakeCaribouStatus = [{
                Bischto:
                {
                    status: "Declining",
                    year: "2015",
                    message: ""
                },
                Narraway:
                {
                    status: "Declining",
                    year: "2015",
                    message: ""
                },
                'Little Smoky':
                {
                    status: "Declining",
                    year: "2015",
                    message: "Stable over 5 year period (with wolf control)."
                },
                'Red Earth':
                {
                    status: "Stable",
                    year: "2015",
                    message: "Declining over 5 year period."
                },
                'Caribou Mountains':
                {
                    status: "Stable",
                    year: "2015",
                    message: "Declining over 5 year period."
                }
            }],
                graphicObject = { attributes: { LOCALRANGE: "Bischto", SUBUNIT: "Bischto SUBUNIT", STATUS: "Active" } },
                expectedResult = "Herd: Bischto SUBUNIT<br/>2015 Status: Declining. ";

            caribouContent._caribouStatus = fakeCaribouStatus;

            var result = caribouContent.infoWindowHandlerContent(graphicObject);
            assert.strictEqual(result, expectedResult, "infoWindowHandlerContent doesn't return expected result.");
            assert.include(result, graphicObject.attributes.SUBUNIT, "SUBUNIT was not included in the output.");

            graphicObject = { attributes: { LOCALRANGE: "Little Smoky", SUBUNIT: "Little Smoky SUBUNIT" } };
            expectedResult = "Herd: Little Smoky SUBUNIT<br/>2015 Status: Declining. Stable over 5 year period (with wolf control).";
            result = caribouContent.infoWindowHandlerContent(graphicObject);
            assert.strictEqual(result, expectedResult, "infoWindowHandlerContent doesn't return expected result.");
            assert.include(result, graphicObject.attributes.SUBUNIT, "SUBUNIT was not included in the output.");
        },
        'Test load CaribouRangeSuccess': function () {
            var polygonJson1 = {
                    rings: [
                        [[-12453909.114073994, 7837531.30460549], [-12453476.821960814, 7837381.89638761], [-12453529.211003032, 7837315.316024232], [-12453708.48359676, 7837091.813973272], [-12453533.886552928, 7837042.790879821], [-12453503.453779617, 7837063.688863605], [-12453504.896048967, 7837176.459793722], [-12453439.017883154, 7837298.942444073], [-12453404.93419509, 7837362.310930569], [-12452921.413817232, 7837163.421924531], [-12452895.831770608, 7837109.694994883], [-12452858.328823652, 7837030.930591884], [-12452513.461834066, 7835986.143460981], [-12453055.774781661, 7835882.005584454], [-12453174.878252637, 7836286.823319815], [-12453343.11338326, 7836585.560512601], [-12453874.711955976, 7837029.441900025], [-12453984.353307525, 7836988.49629312], [-12454224.652643263, 7837115.344847323], [-12454335.59572276, 7837075.130163825], [-12455122.236229392, 7837469.939551821], [-12454935.290766345, 7837803.256269633], [-12454782.729433531, 7837877.024781748], [-12454659.935141945, 7837878.621327496], [-12454134.718790125, 7837609.266838435], [-12453909.114073994, 7837531.30460549]]
                    ],
                    spatialReference: { wkid: 102100 }
                },
                polygon1 = new Polygon(polygonJson1),
                data1 = {
                    attributes: { LOCALRANGE: "Yates", STATUS: "Active", SUBUNIT: "Yates" },
                    symbol: null,
                    setSymbol: function(icon) { this.symbol = icon; },
                    geometry: polygon1
                },
                polygonJson2 = {
                    rings: [
                        [[-12452626.11517339, 7830201.994742203], [-12452598.975416098, 7830449.529109035], [-12452692.446281878, 7830429.772527036], [-12452670.851126645, 7830725.547759901], [-12452697.235900661, 7830837.264392866], [-12452652.200485127, 7830747.373989621], [-12452648.438997868, 7830735.180505703], [-12452619.966096472, 7830753.7667067], [-12452571.06856887, 7830752.401346829], [-12452523.11667832, 7830765.780817994], [-12452612.1501226, 7830990.861411893], [-12452638.85128974, 7830972.16195227], [-12452719.845923508, 7830931.380574417], [-12452731.32527345, 7830984.785034877], [-12452627.180199178, 7831135.54616383], [-12452611.420616101, 7831288.198933104], [-12452211.582141064, 7831297.307720374], [-12452129.920916935, 7831289.261551864], [-12452087.645399129, 7831271.448548877], [-12451986.952292008, 7831268.370474991], [-12452078.296643153, 7830167.615294019], [-12452118.509921858, 7830163.071686554], [-12452156.582657646, 7830148.467605501], [-12452351.853195425, 7830170.733601611], [-12452451.142178487, 7830202.700815397], [-12452626.11517339, 7830201.994742203]]
                    ],
                    spatialReference: { wkid: 102100 }
                },
                polygon2 = new Polygon(polygonJson2),
                data2 = {
                    attributes: { LOCALRANG: "Bischto", STATUS: "Active", SUBUNIT: "Bischto" },
                    symbol: null,
                    setSymbol: function(icon) { this.symbol = icon; },
                    geometry: polygon2
                },
                data = { features: [] };

            caribouContent._layer = new GraphicsLayer();
            caribouContent._loadCaribouRangeSuccess(data);

            assert.strictEqual(caribouContent._layer.graphics.length, 0,
                "load CaribouRangeSuccess should not have any graphic objects when dataset is empty.");

            data = { features: [data1, data2] };
            caribouContent._loadCaribouRangeSuccess(data);
            assert.strictEqual(caribouContent._layer.graphics.length, 2,
                "load CaribouRangeSuccess doesn't have expected graphic objects.");
            assert.deepEqual(caribouContent._layer.graphics[0].symbol, caribouContent._caribouSymbol,
                "load CaribouRangeSuccess doesn't have expected graphic symbol.");
            assert.deepEqual(caribouContent._layer.graphics[0].geometry, data1.geometry,
                "load CaribouRangeSuccess doesn't have expected graphic geometry.");
            assert.deepEqual(caribouContent._layer.graphics[0].attributes, data1.attributes,
                "load CaribouRangeSuccess doesn't have expected graphic attributes .");

            assert.deepEqual(caribouContent._layer.graphics[1].symbol, caribouContent._caribouSymbol,
                "load CaribouRangeSuccess doesn't have expected graphic symbol.");
            assert.deepEqual(caribouContent._layer.graphics[1].geometry, data2.geometry,
                "load CaribouRangeSuccess doesn't have expected graphic geometry.");
            assert.deepEqual(caribouContent._layer.graphics[1].attributes, data2.attributes,
                "load CaribouRangeSuccess doesn't have expected graphic attributes .");
        }
    });
});