﻿/*property
    AgencyCode, EarliestSample, Eighties, Location, Metals, MostRecentSample,
    Nineties, NoMetals, NoPesticides, Pesticides, PriorSeventies,
    SampleClassIndicator, SampleCount, SampleMatrix, SampleMatrixCode,
    Seventies, Station, StationNo, StationTypeCode, StationTypeName,
    TwoThousands, _getWaterQualityStation, _getWaterQualityStationData, async,
    attributes, dataUrl, deepEqual, fail, getRenderer, include,
    infoWindowHandlerContent, infoWindowHandlerTitle, isObject, isTrue, length,
    log, match, name, notInclude, reject, resolve, setup, strictEqual, symbol,
    then, url, innerHTML, childNodes, equal
*/
define([
    'intern!object',
    'intern/chai!assert',
    'dojo/query',
    'esri/renderers/SimpleRenderer',
    'app/content/LakeQualityContent'
], function (registerSuite, assert, query, SimpleRenderer, LakeQualityContent) {
    'use strict';
    var lakeContentModule;
    registerSuite({
        name: 'Lake Quality Content module tests',
        setup: function () {
            lakeContentModule = new LakeQualityContent({
                dataUrl: 'http://aemeris.alberta.ca/data/'
            });
        },

        'Test Get Lake station data': function () {
            var stationNo = 'AB07CE0120', def = this.async(5000), expectedLakeStation = {
                StationNo: "GREGOIRE LAKE COMPOSITE",
                SampleMatrixCode: "0",
                SampleMatrix: "WATER",
                SampleClassIndicator: "A",
                AgencyCode: "211",
                SampleCount: null,
                EarliestSample: "/Date(613245600000)/",
                MostRecentSample: "/Date(1222701300000)/",
                PriorSeventies: 0,
                Seventies: 0,
                Eighties: 4,
                Nineties: 48,
                TwoThousands: 39,
                NoMetals: 88,
                Metals: 0,
                Pesticides: 0,
                NoPesticides: 0,
                Station: null
            };

            lakeContentModule._getWaterQualityStationData(stationNo).then(function (data) {
                if (data.length === 0) {
                    assert.fail("Station data not available");
                    def.reject();
                } else {
                    assert.deepEqual(data, expectedLakeStation, 'Unexpected station');
                    def.resolve(data);
                }
            },
             function (error) {
                 console.log(error);
                 def.reject();
             });

            stationNo = 'AB06AA0230';
            expectedLakeStation = {
                StationNo: "BEAVER LAKE COMPOSITE",
                SampleMatrixCode: "0",
                SampleMatrix: "WATER",
                SampleClassIndicator: "A",
                AgencyCode: "211",
                SampleCount: null,
                EarliestSample: "/Date(517687200000)/",
                MostRecentSample: "/Date(1285343100000)/",
                PriorSeventies: 0,
                Seventies: 0,
                Eighties: 6,
                Nineties: 1,
                TwoThousands: 25,
                NoMetals: 32,
                Metals: 10,
                Pesticides: 0,
                NoPesticides: 0,
                Station: null
            };

            lakeContentModule._getWaterQualityStationData(stationNo).then(function (data) {
                if (data.length === 0) {
                    assert.fail("Station data not available");
                    def.reject();
                } else {
                    assert.deepEqual(data, expectedLakeStation, 'Unexpected station');
                    def.resolve(data);
                }
            },
             function (error) {
                 console.log(error);
                 def.reject();
             });
        },

        'Test Get renderer': function () {
            var renderer = lakeContentModule.getRenderer(), expectedStationIcon = '/Scripts/app/content/images/water/LakeQuality.png';

            assert.isTrue(renderer instanceof SimpleRenderer, "Get Renderer doesn't return expected object");
            assert.isObject(renderer, "expects an object");
            assert.include(renderer.symbol.url, expectedStationIcon, 'station doesn\'t have expected icon');
        },
        
        'Test InfoWindow Title handler': function () {
            var title, graphicObject = { attributes: { StationNo: 'AB06AA0230', StationTypeCode: 1, StationTypeName: 'Lake', Location: 'COMPOSITE' } },
                expectedTitleContent = 'Lake Water Quality';

            title = lakeContentModule.infoWindowHandlerTitle(graphicObject);
            assert.strictEqual(title, expectedTitleContent, 'InfoWindowHandlerTitle error');
        },

        'Test InfoWindow Content handler': function () {
            var graphicObject = { attributes: { StationNo: 'AB06AA0230', StationTypeCode: 1, StationTypeName: 'Lake', Location: 'COMPOSITE' } },
                stationNameKeyword = "Station Name:",
                contentNode = lakeContentModule.infoWindowHandlerContent(graphicObject),
                sectionList = query('.infoWindowSection', contentNode),
                stationNameSection = query('.infoWindowStationName', contentNode),
                sectionContent = null;

            assert.equal(contentNode.childNodes.length, 5, 'child nodes number is wrong');
            assert.equal(sectionList.length, 5, 'section number is wrong');
            assert.equal(stationNameSection.length, 1, 'section number is wrong');

            sectionContent = query(':first-child', sectionList[0])[0].innerHTML;
            assert.notInclude(sectionContent, stationNameKeyword, 'infoWindowHandlerContent should not contain Station Name.');

            sectionContent = query(':first-child', sectionList[1])[0].innerHTML;
            assert.include(sectionContent, '(1986 - 2010)', 'infoWindowHandlerContent does not have year information.');

            sectionContent = query(':first-child', sectionList[2])[0].innerHTML;
            assert.include(sectionContent, 'Inorganics:', 'infoWindowHandlerContent does not have Inorganics information');

            sectionContent = query(':first-child', sectionList[3])[0].innerHTML;
            assert.include(sectionContent, 'Metals:', 'infoWindowHandlerContent does not have Metals information');

            sectionContent = query(':first-child', sectionList[4])[0].innerHTML;
            assert.include(sectionContent, 'Pesticides:', 'infoWindowHandlerContent does not have Pesticides information');

            graphicObject = { attributes: { StationNo: 'AB06AC0290', StationTypeCode: 1, StationTypeName: 'Lake', Location: 'WHOLE LAKE COMPOSITE' } };
            contentNode = lakeContentModule.infoWindowHandlerContent(graphicObject);
            sectionList = query('.infoWindowSection', contentNode);
            stationNameSection = query('.infoWindowStationName', contentNode);

            assert.equal(contentNode.childNodes.length, 5, 'child nodes number is wrong');
            assert.equal(sectionList.length, 5, 'section number is wrong');
            assert.equal(stationNameSection.length, 1, 'section number is wrong');

            sectionContent = query(':first-child', sectionList[0])[0].innerHTML;
            assert.notInclude(sectionContent, stationNameKeyword, 'infoWindowHandlerContent should not contain Station Name.');

            sectionContent = query(':first-child', sectionList[1])[0].innerHTML;
            assert.include(sectionContent, '(1988 - 2012)', 'infoWindowHandlerContent does not have year information.');

            sectionContent = query(':first-child', sectionList[2])[0].innerHTML;
            assert.include(sectionContent, 'Inorganics:', 'infoWindowHandlerContent does not have Inorganics information');

            sectionContent = query(':first-child', sectionList[3])[0].innerHTML;
            assert.include(sectionContent, 'Metals:', 'infoWindowHandlerContent does not have Metals information');

            sectionContent = query(':first-child', sectionList[4])[0].innerHTML;
            assert.include(sectionContent, 'Pesticides:', 'infoWindowHandlerContent does not have Pesticides information');

        },
        'Test Get WaterQualityStationData': function () {
            var stationId = "AB06AA0230",
                def = this.async(1000);

            lakeContentModule._getWaterQualityStationData(stationId).then(function (data) {
                assert.isTrue(data.StationNo.length > 0, "Get WaterQualityStationData doesn't return any data.");
                def.resolve();
            }, function (error) {
                assert.fail("Get WaterQualityStationData: " + error);
                def.reject();
            });
        },
        'Test Get WaterQualityStation': function () {
            var graphic = {
                    attributes: {
                        StationNo: "AB07CE0120"
                    }
                },
                def = this.async(1000),
                result = lakeContentModule._getWaterQualityStation(graphic);

            setTimeout(function () {
                // check graphic objects in the layer
                assert.isTrue(result.StationNo.length > 0, "Get WaterQualityStation doesn't return any data.");
                def.resolve();
            }, 500); 
        }
    });
});
