﻿/*property
    Active_Status, Id, MODE_SNAPSHOT, OPERATOR_NAME, OSP_NO, STYLE_SOLID,
    Status, _approvedProjectSymbol, _dataUrl, _defaultSymbol,
    _getProjectStatusByProjectId, _isSnapshot, _json, _layer,
    _loadProjectBoundariesSuccess, _operatingProjectSymbol, _projectStatuses,
    a, addGraphics, alias, async, attributes, createFeatureLayer, dataUrl,
    deepEqual, defaultLabel, defaultSymbol, fail, featureSet, features, fields,
    geometryType, getInfoTemplate, getRenderer, graphics, id, include,
    infoWindowHandlerContent, infos, isNull, isTrue, label, layerDefinition,
    length, mode, name, outFields, reject, resolve, setSymbol, setup, some,
    spatialReference, strictEqual, stringify, symbol, then, type, value,
    visible, wkid, xmax, xmin, ymax, ymin, _mapServerUrl, _options, _iniExtent
*/
define([
    'intern!object',
    'intern/chai!assert',
    'dojo/_base/Color',
    'esri/symbols/SimpleLineSymbol',
    'esri/symbols/SimpleFillSymbol',
    'esri/layers/FeatureLayer',
    'esri/renderers/UniqueValueRenderer',
    'esri/geometry/Extent',
    'app/content/ProjectBoundariesContent'
], function (registerSuite, assert, Color, SimpleLineSymbol, SimpleFillSymbol, FeatureLayer,
    UniqueValueRenderer, Extent, ProjectBoundariesContent) {
    'use strict';
    var options = { dataUrl: 'http://aemerisuat.alberta.ca/data/' }, projectBoundariesContent;
    registerSuite({
        name: 'ProjectBoundariesContent module tests',
        setup: function () {
            projectBoundariesContent = new ProjectBoundariesContent(options);
        },
        'Test Constructor': function () {
            var operatingFillColor = new Color("#48C1EA"),
                operatingBorderColor = new Color("#0099FF"),
                approvedFillColor = new Color("#8ECF63"),
                approvedBorderColor = new Color("#669933"),
                otherFillColor = new Color("#cccccc"),
                otherBorderColor = new Color("#888888");

            operatingFillColor.a = 0.6;
            operatingBorderColor.a = 0.8;
            approvedFillColor.a = 0.6;
            approvedBorderColor.a = 0.8;
            otherFillColor.a = 0.6;
            otherBorderColor.a = 0.8;

            var operatingSymbol = new SimpleFillSymbol(SimpleFillSymbol.STYLE_SOLID,
                    new SimpleLineSymbol(
                        SimpleLineSymbol.STYLE_SOLID,
                        operatingBorderColor,
                        1),
                    operatingFillColor),
                approvedSymbol = new SimpleFillSymbol(SimpleFillSymbol.STYLE_SOLID,
                    new SimpleLineSymbol(
                        SimpleLineSymbol.STYLE_SOLID,
                        approvedBorderColor,
                        1),
                    approvedFillColor),
                otherSymbol = new SimpleFillSymbol(SimpleFillSymbol.STYLE_SOLID,
                    new SimpleLineSymbol(
                        SimpleLineSymbol.STYLE_SOLID,
                        otherBorderColor,
                        1),
                    otherFillColor);

            assert.strictEqual(projectBoundariesContent._dataUrl, options.dataUrl, "Constructor doesn't return expected dataUrl");
            assert.strictEqual(JSON.stringify(projectBoundariesContent._operatingProjectSymbol), JSON.stringify(operatingSymbol), "Constructor doesn't return expected operating project symbol.");
            assert.strictEqual(JSON.stringify(projectBoundariesContent._approvedProjectSymbol), JSON.stringify(approvedSymbol), "Constructor doesn't return expected approved project symbol.");
            assert.strictEqual(JSON.stringify(projectBoundariesContent._defaultSymbol), JSON.stringify(otherSymbol), "Constructor doesn't return expected default project symbol.");

            var hasValidData = false, def = this.async(5000);
            setTimeout(function () {
                assert.isTrue(projectBoundariesContent._projectStatuses.length > 0, "Constructor doesn't return project status data.");
                hasValidData = projectBoundariesContent._projectStatuses.some(function (project) {
                    if (project.Id > 0) {
                        return true;
                    }
                });
                assert.isTrue(hasValidData, "Constructor doesn't contain valid project status.");

                def.resolve();
            }, 4500); // need to wait for webservice data  

        },
        'Test Create FeatureLayer': function () {
            var layerDefinition = {
                geometryType: "esriGeometryPolygon",
                fields: [
                    {
                        name: "OSP_NO",
                        type: "esriFieldTypeSmallInteger",
                        alias: "Project Number"
                    }
                ]},
                layerId = "projectBoundaries1",
                result = projectBoundariesContent.createFeatureLayer(layerDefinition, layerId);

            assert.isTrue(result instanceof FeatureLayer, "Create FeatureLayer doesn't return expected object");
            assert.strictEqual(result.id, layerId, "Create FeatureLayer doesn't return expected layerId.");
            assert.strictEqual(result.graphics.length, 0, "Create FeatureLayer doesn't return expected result.");
            assert.isTrue(result._isSnapshot, "Create FeatureLayer doesn't return expected map mode.");
            assert.include(result._json, JSON.stringify(layerDefinition), "Create FeatureLayer doesn't return expected result.");

            layerDefinition = {
                geometryType: "esriGeometryPoint",
                fields: [
                    {
                        name: "ObjectID",
                        type: "esriFieldTypeOID",
                        alias: "ObjectID"
                    },
                    {
                        name: "testField",
                        type: "esriFieldTypeString",
                        alias: "testField"
                    }
                ]
            };
            layerId = "projectBoundaries2";
            result = projectBoundariesContent.createFeatureLayer(layerDefinition, layerId);

            assert.isTrue(result instanceof FeatureLayer, "Create FeatureLayer doesn't return expected object");
            assert.strictEqual(result.id, layerId, "Create FeatureLayer doesn't return expected layerId.");
            assert.strictEqual(result.graphics.length, 0, "Create FeatureLayer doesn't return expected result.");
            assert.isTrue(result._isSnapshot, "Create FeatureLayer doesn't return expected map mode.");
            assert.include(result._json, JSON.stringify(layerDefinition), "Create FeatureLayer doesn't return expected result.");
        },
        'Test Get Renderer': function () {
            var result = projectBoundariesContent.getRenderer(),
                expectedDefaultLabel = "Other Project Boundaries",
                operatingInfo = { value: "Operating", symbol: projectBoundariesContent._operatingProjectSymbol, label: "Operating Project Boundaries" },
                plannedInfo = { value: "Planned", symbol: projectBoundariesContent._operatingProjectSymbol, label: "Operating Project Boundaries" },
                approvedInfo = { value: "Approved", symbol: projectBoundariesContent._approvedProjectSymbol, label: "Approved Project Boundaries" };

            assert.isTrue(result instanceof UniqueValueRenderer, "Get Renderer doesn't return expected object");
            assert.strictEqual(result.defaultLabel, expectedDefaultLabel, "Get Renderer doesn't return expected default label.");
            assert.deepEqual(result.defaultSymbol, projectBoundariesContent._defaultSymbol, "Get Renderer doesn't return expected default symbol.");
            assert.strictEqual(result.infos.length, 3, "Get Renderer doesn't return expected symbols.");
            assert.deepEqual(result.infos[0], operatingInfo, "Get Renderer doesn't return expected operating project render.");
            assert.deepEqual(result.infos[1], plannedInfo, "Get Renderer doesn't return expected planned project render.");
            assert.deepEqual(result.infos[2], approvedInfo, "Get Renderer doesn't return expected approved project render.");
        },
        'Test Add Graphics': function () {
            var layerDefinition = {
                    geometryType: "esriGeometryPolygon",
                    fields: [
                        {
                            name: "OSP_NO",
                            type: "esriFieldTypeSmallInteger",
                            alias: "Project Number"
                        }
                    ]
                },
                featureCollection = {
                    layerDefinition: layerDefinition,
                    featureSet: null
                },
                layer = new FeatureLayer(featureCollection, { id: "testID", visible: false, mode: FeatureLayer.MODE_SNAPSHOT }),
                iniExtent = new Extent({
                    xmin: -14265055.060527408,
                    ymin: 6259094.656300137,
                    xmax: -11283399.461180044,
                    ymax: 8409115.387905004,
                    spatialReference: {
                        wkid: 102100
                    }
                }),
                mapServerUrl = "https://maps.alberta.ca/genesis_tokenauth/rest/services/OSIP-Layers/20161021/MapServer/137";

            options.outFields = ['*'];
            projectBoundariesContent.addGraphics(layer, mapServerUrl, options, iniExtent);
            assert.deepEqual(projectBoundariesContent._layer, layer, "Add Graphics doesn't return expected result.");
            assert.deepEqual(projectBoundariesContent._mapServerUrl, mapServerUrl, "Add Graphics doesn't return expected result.");
            assert.deepEqual(projectBoundariesContent._options, options, "Add Graphics doesn't return expected result.");
            assert.deepEqual(projectBoundariesContent._iniExtent, iniExtent, "Add Graphics doesn't return expected result.");
        },
        'Test Load Project Boundaries Success': function () {
            var layerDefinition = {
                    geometryType: "esriGeometryPolygon",
                    fields: [
                        {
                            name: "OSP_NO",
                            type: "esriFieldTypeSmallInteger",
                            alias: "Project Number"
                        }
                    ]
                },
                featureCollection = {
                    layerDefinition: layerDefinition,
                    featureSet: null
                },
                layer = new FeatureLayer(featureCollection, { id: "testID", visible: false, mode: FeatureLayer.MODE_SNAPSHOT }),
                data = {
                    features: [
                        { attributes: { OSP_NO: 1 }, symbol: null, setSymbol: function (icon) { this.symbol = icon; } },
                        { attributes: { OSP_NO: 2 }, symbol: null, setSymbol: function (icon) { this.symbol = icon; } },
                        { attributes: { OSP_NO: 3 }, symbol: null, setSymbol: function (icon) { this.symbol = icon; } },
                        { attributes: { OSP_NO: 4 }, symbol: null, setSymbol: function (icon) { this.symbol = icon; } }
                    ]
                },
                operatingStatus = "Operating", approvedStatus = "Approved", plannedStatus = "Planned", otherStatus = "Other";

            projectBoundariesContent._layer = layer;
            // setup fake project status for testing
            projectBoundariesContent._projectStatuses = [
                { Id: 1, Status: "Active"},
                { Id: 2, Status: "Approved"},
                { Id: 3, Status: "Exploration"},
                { Id: 4, Status: "Announced"}
            ];

            projectBoundariesContent._loadProjectBoundariesSuccess(data);

            var graphics = projectBoundariesContent._layer.graphics;

            assert.strictEqual(graphics.length, 4, "Load Project Boundaries When Success doesn't return expected result.");

            assert.strictEqual(graphics[0].attributes.Active_Status, operatingStatus, "Load Project Boundaries When Success doesn't return expected project status.");
            assert.deepEqual(graphics[0].symbol, projectBoundariesContent._operatingProjectSymbol, "Load Project Boundaries When Success doesn't return expected project symbol.");

            assert.strictEqual(graphics[1].attributes.Active_Status, approvedStatus, "Load Project Boundaries When Success doesn't return expected project status.");
            assert.deepEqual(graphics[1].symbol, projectBoundariesContent._approvedProjectSymbol, "Load Project Boundaries When Success doesn't return expected project symbol.");

            assert.strictEqual(graphics[2].attributes.Active_Status, plannedStatus, "Load Project Boundaries When Success doesn't return expected project status.");
            assert.deepEqual(graphics[2].symbol, projectBoundariesContent._operatingProjectSymbol, "Load Project Boundaries When Success doesn't return expected project symbol.");

            assert.strictEqual(graphics[3].attributes.Active_Status, otherStatus, "Load Project Boundaries When Success doesn't return expected project status.");
            assert.deepEqual(graphics[3].symbol, projectBoundariesContent._defaultSymbol, "Load Project Boundaries When Success doesn't return expected project symbol.");
        },
        'Test Get ProjectStatus By ProjectId': function () {
            // setup fake project status for testing
            projectBoundariesContent._projectStatuses = [
                { Id: 1, Status: "Active" },
                { Id: 2, Status: "Approved" },
                { Id: 3, Status: "Exploration" },
                { Id: 4, Status: "Announced" }
            ];
            var result = projectBoundariesContent._getProjectStatusByProjectId(1);

            assert.deepEqual(result, projectBoundariesContent._projectStatuses[0], "Get ProjectStatus By ProjectId doesn't return expected result.");

            result = projectBoundariesContent._getProjectStatusByProjectId(2);
            assert.deepEqual(result, projectBoundariesContent._projectStatuses[1], "Get ProjectStatus By ProjectId doesn't return expected result.");

            result = projectBoundariesContent._getProjectStatusByProjectId(-1);
            assert.isNull(result, "Get ProjectStatus By ProjectId doesn't return expected result.");
        },
        'Test Get InfoTemplate': function () {
            assert.isNull(projectBoundariesContent.getInfoTemplate, "Get InfoTemplate is not null");
        },
        'Test InfoWindowHandler Content': function () {
            assert.isNull(projectBoundariesContent.infoWindowHandlerContent, "InfoWindowHandler Content is not null");
        }
    });

});