﻿/*property
    BRD_Name, CurrentReadingURL, HistoricReadingURL, Id, IsAthabascaException,
    Name, Number, ShortName, WaterType, WaterTypeDisplay,
    _getRiverOrLakeStationData, async, attributes, dataUrl, deepEqual, fail,
    getRenderer, include, infoWindowHandlerContent, infoWindowHandlerTitle,
    isObject, isTrue, length, log, match, name, notInclude, reject, resolve,
    setup, strictEqual, then, equal, innerHTML, childNodes
*/
define([
    'intern!object',
    'intern/chai!assert',
    'dojo/query',
    'esri/renderers/SimpleRenderer',
    'app/content/RiverFlowAndLakeLevelContent'
], function (registerSuite, assert, query, SimpleRenderer, RiverFlowAndLakeLevelContent) {
    'use strict';
    var riverContentModule;
    registerSuite({
        name: 'River Flow Content module tests',
        setup: function () {
            riverContentModule = new RiverFlowAndLakeLevelContent({
                dataUrl: 'http://aemeris.alberta.ca/data/'
            });
        },

        'Test Get River/Lake station data': function () {
            var stationId = 10106, type = 1, def = this.async(5000), expectedRiverStation = {
                Id: "10106",
                Name: "PEACE RIVER AT CARCAJOU",
                ShortName: "Peace R at Carcajou",
                Number: "07HD001",
                CurrentReadingURL: "http://www.environment.alberta.ca/apps/basins/DisplayData.aspx?Type=Table&BasinID=1&DataType=1&StationID=RPEACAR",
                HistoricReadingURL: "http://wateroffice.ec.gc.ca/report/report_e.html?type=h2oArc&stn=07HD001",
                WaterType: 1,
                WaterTypeDisplay: "River",
                IsAthabascaException: false
            },
            expectedLakeStation = {
                Id: "30012",
                Name: "Cold Lake at Cold Lake",
                ShortName: "Cold Lake @ Cold Lak",
                Number: "06AF002",
                CurrentReadingURL: "http://www.environment.alberta.ca/apps/basins/DisplayData.aspx?Type=Table&BasinID=3&DataType=3&StationID=RCOLDLK",
                HistoricReadingURL: "http://wateroffice.ec.gc.ca/report/report_e.html?type=h2oArc&stn=06AF002",
                WaterType: 0,
                WaterTypeDisplay: "Lake",
                IsAthabascaException: false
             };

            riverContentModule._getRiverOrLakeStationData(stationId, type).then(function (data) {
                if (data.length === 0) {
                    assert.fail("Station data not available");
                    def.reject();
                } else {
                    assert.deepEqual(data, expectedRiverStation, 'Unexpected station');
                    def.resolve(data);
                }
            },
             function (error) {
                 console.log(error);
                 def.reject();
            });

            stationId = 30012;
            type = 0;

            riverContentModule._getRiverOrLakeStationData(stationId, type).then(function (data) {
                if (data.length === 0) {
                    assert.fail("Station data not available");
                    def.reject();
                } else {
                    assert.deepEqual(data, expectedLakeStation, 'Unexpected station');
                    def.resolve(data);
                    }
                },
             function (error) {
                 console.log(error);
                 def.reject();
                });

        },

        'Test Get renderer': function () {
            var renderer = riverContentModule.getRenderer();

            assert.isTrue(renderer instanceof SimpleRenderer, "Get Renderer doesn't return expected object");
            assert.isObject(renderer, "expects an object");
        },

        'Test InfoWindow Title handler': function () {
            var title,
                expectedTitle = "River Level/Flow",
                graphicObject = { attributes: { Id: 10037, BRD_Name: 'Peace River above Smoky River (Station RPEASMOK)', ShortName: 'Peace River ab Smoky' } };

            title = riverContentModule.infoWindowHandlerTitle(graphicObject);
            assert.strictEqual(title, expectedTitle, 'InfoWindowHandlerTitle error');

            graphicObject = { attributes: { Id: 10077, BRD_Name: 'Embarras River to Mamawi Lake (Station REMBMAMA)', ShortName: 'Embarras R B/T Mam L' }};
            title = riverContentModule.infoWindowHandlerTitle(graphicObject);
            assert.strictEqual(title, expectedTitle, 'InfoWindowHandlerTitle error');
        },

        'Test InfoWindow Content handler': function () {
            var graphicObject = { attributes: { Id: 10037, BRD_Name: 'Peace River above Smoky River (Station RPEASMOK)', ShortName: 'Peace River ab Smoky' } },
                contentNode = riverContentModule.infoWindowHandlerContent(graphicObject),
                stationNode = query('.infoWindowStationName', contentNode),
                sectionList = query('.infoWindowSection', contentNode);

            assert.equal(contentNode.childNodes.length, 5, 'child nodes number is wrong');
            assert.equal(stationNode.length, 1, 'station node does not exist');
            assert.equal(sectionList.length, 5, 'section number is wrong');
            assert.include(sectionList[1].innerHTML, "Station Short-Name", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[2].innerHTML, "07FD901", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[3].innerHTML, "Current Water Flow and Level", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[4].innerHTML, "Historical Water Flow and Level", 'infoWindowHandlerContent does not match');

            graphicObject = { attributes: { Id: 10077, BRD_Name: 'Embarras River to Mamawi Lake (Station REMBMAMA)', ShortName: 'Embarras R B/T Mam L' }};
            contentNode = riverContentModule.infoWindowHandlerContent(graphicObject);
            stationNode = query('.infoWindowStationName', contentNode);
            sectionList = query('.infoWindowSection', contentNode);

            assert.equal(contentNode.childNodes.length, 5, 'child nodes number is wrong');
            assert.equal(stationNode.length, 1, 'station node does not exist');
            assert.equal(sectionList.length, 5, 'section number is wrong');
            assert.include(sectionList[1].innerHTML, "Station Short-Name", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[2].innerHTML, "07KF015", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[3].innerHTML, "Current Water Flow and Level", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[4].innerHTML, "Historical Water Flow and Level", 'infoWindowHandlerContent does not match');

            graphicObject = { attributes: { Id: 20367, BRD_Name: 'Christina Lake near Winefred Lake (Station RCHRISLK)', ShortName: 'Christ Lk nr Win Lk'}};
            contentNode = riverContentModule.infoWindowHandlerContent(graphicObject);
            stationNode = query('.infoWindowStationName', contentNode);
            sectionList = query('.infoWindowSection', contentNode);

            assert.equal(contentNode.childNodes.length, 5, 'child nodes number is wrong');
            assert.equal(stationNode.length, 1, 'station node does not exist');
            assert.equal(sectionList.length, 5, 'section number is wrong');
            assert.include(sectionList[1].innerHTML, "Station Short-Name", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[2].innerHTML, "07CE906", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[3].innerHTML, "Current Water Level", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[4].innerHTML, "Historical Water Level", 'infoWindowHandlerContent does not match');
        }
    });
});
