﻿/*property
    BacterialIndex, BacterialRating, BacterialRatingCode, BasinName, Id,
    LakeSamples, Latitude, Location, Longitude, MetalsIndex, MetalsRating,
    MetalsRatingCode, Name, Number, NutrientsIndex, NutrientsRating,
    NutrientsRatingCode, OBJECTID, Period, PeriodAbbreviation, PeriodEndYear,
    PeriodStartYear, PesticidesIndex, PesticidesRating, PesticidesRatingCode,
    RiverSamples, RiverSubBasinCode, SITE_ID, SampleInventories, Site, Station,
    StationName, StationNo, StationType, StationTypeCode, WaterQualityIndex,
    WaterQualityIndexRating, WaterQualityIndexRatingCode, WaterQualityIndexes,
    Waterbody, Watershed, _createJOSMStationsGraphic,
    _createWaterQualityStationsGraphic, _getRiverQualityVerbose,
    _getWaterQualityStationData, _loadJOSMStations, async, attributes, dataUrl,
    data_url, deepEqual, defaultSymbol, environmentCanadaSite, fail, filter,
    getRenderer, height, include, infoWindowHandlerContent,
    infoWindowHandlerTitle, infos, isObject, isTrue, josmStations, label,
    lat_decimal, latitude, length, libraryUrl, log, long_decimal, longitude,
    match, name, notInclude, number, period, reject, resolve,
    riverQualityStations, setup, site, some, strictEqual, symbol, then, url,
    value, waterBody, watershed, width, x_3400, y_3400, innerHTML, childNodes, equal,
    WaterQualityRatingMetals, WaterQualityRatingNutrients, WaterQualityRatingPesticides,
    WaterQualityRatingBacterial, WaterQualityRating
*/
define([
    'intern!object',
    'intern/chai!assert',
    'dojo/_base/array',
    'dojo/query',
    'esri/renderers/UniqueValueRenderer',
    'app/content/RiverQualityContent'
], function (registerSuite, assert, array, query, UniqueValueRenderer, RiverQualityContent) {
    'use strict';
    var riverQualityContentModule;
    registerSuite({
        name: 'River Quality Content module tests',
        setup: function () {
            riverQualityContentModule = new RiverQualityContent({ dataUrl: 'http://aemeris.alberta.ca/data/', libraryUrl: 'http://aemeris.alberta.ca/library/' });
        },

        'Test Water Quality Station data': function () {
            var station,
                def = this.async(5000),
                expectedLakeStation = {
                    StationNo: "AB07BE0010",
                    StationName: "ATHABASCA RIVER AT ATHABASCA",
                    PeriodStartYear: 2013,
                    PeriodEndYear: 2014,
                    Period: "2013-2014",
                    PeriodAbbreviation: "1314",
                    MetalsIndex: 88.5,
                    NutrientsIndex: 79.2,
                    BacterialIndex: 91.4,
                    PesticidesIndex: 100,
                    WaterQualityIndex: 90,
                    MetalsRatingCode: "G",
                    NutrientsRatingCode: "F",
                    BacterialRatingCode: "G",
                    PesticidesRatingCode: "E",
                    WaterQualityIndexRatingCode: "G",
                    Id: 18,
                    Station: {
                        StationName: "ATHABASCA RIVER",
                        StationTypeCode: 0,
                        Location: "AT TOWN OF ATHABASCA",
                        Latitude: 54.72222,
                        Longitude: -113.28611,
                        RiverSubBasinCode: "07BE",
                        BasinName: "07BE TAWATINAW RIVER",
                        StationNo: "AB07BE0010",
                        StationType: null
                    },
                    WaterQualityRatingMetals: null,
                    WaterQualityRatingNutrients: null,
                    WaterQualityRatingPesticides: null,
                    WaterQualityRatingBacterial: null,
                    WaterQualityRating: null
                };

            riverQualityContentModule._getWaterQualityStationData().then(function (data) {
                if (data.length === 0) {
                    assert.fail("Station data not available");
                    def.reject();
                } else {
                    array.some(data, function (item) {
                        if (item.Station.StationNo === expectedLakeStation.Station.StationNo) {
                            station = item;
                            return true;
                        }
                    });
                    assert.deepEqual(station, expectedLakeStation, 'Unexpected station');
                    def.resolve(data);
                }
            },
             function (error) {
                 console.log(error);
                 def.reject();
             });
        },

        'Test Load JOSM station data': function () {
            var station, expectedStation = {
                name: "SLAVE RIVER AT FITZGERALD, ALBERTA",
                number: "AL07NB0001",
                site: "M11",
                latitude: "59.52.09.012",
                longitude: "111.35.08.988",
                lat_decimal: 59.86917,
                long_decimal: -111.58583,
                x_3400: 691053.2742210376,
                y_3400: 6639110.650466515,
                waterBody: "Slave River",
                watershed: "Slave",
                period: "1960-Present",
                data_url: "http://www.ec.gc.ca/data_donnees/SSB-QualEau_OSM-WaterQual/Surface_Water_Quality/Expanded_Geographic_Extent_Water_Quality/Slave_River_at_Fitzgerald_1960_2010_time_period_corrected.xls",
                environmentCanadaSite: true
            };

            riverQualityContentModule._loadJOSMStations();
            if (riverQualityContentModule.josmStations.length === 0) {
                assert.fail("JOSM Station data not available");
            }

            array.some(riverQualityContentModule.josmStations, function (item) {
                if (item.number === expectedStation.number && item.name === expectedStation.name) {
                    station = item;
                    return true;
                }
            });

            assert.deepEqual(station, expectedStation, 'Station not available');
        },

        'Test Get renderer': function () {
            var renderer = riverQualityContentModule.getRenderer(), expectedDefaultIcon = 'River.png',
                expectedSymbol = {
                    value: "E",
                    symbol: {
                        height: 21,
                        url: "/Scripts/app/content/images/water/River_Excellent.png",
                        width: 20
                    },
                    label: "Excellent"
                };

            assert.isTrue(renderer instanceof UniqueValueRenderer, "Get Renderer doesn't return expected object");
            assert.isObject(renderer, "expects an object");
            assert.include(renderer.defaultSymbol.url, expectedDefaultIcon, 'Get Renderer doesn\'t have expected default icon');
            assert.strictEqual(renderer.infos.filter(function (obj) { return obj.value === expectedSymbol.value; })[0].label, expectedSymbol.label, 'Get Renderer doesn\'t have expected symbol label');
            assert.include(renderer.infos.filter(function (obj) { return obj.value === expectedSymbol.value; })[0].symbol.url, expectedSymbol.symbol.url, 'Get Renderer doesn\'t have expected symbol');

            expectedSymbol = {
                value: "G",
                symbol: {
                    height: 21,
                    url: "/Scripts/app/content/images/water/River_Good.png",
                    width: 20
                },
                label: "Good"
            };
            assert.strictEqual(renderer.infos.filter(function (obj) { return obj.value === expectedSymbol.value; })[0].label, expectedSymbol.label, 'Get Renderer doesn\'t have expected symbol label');
            assert.include(renderer.infos.filter(function (obj) { return obj.value === expectedSymbol.value; })[0].symbol.url, expectedSymbol.symbol.url, 'Get Renderer doesn\'t have expected symbol');

            expectedSymbol = {
                value: "F",
                symbol: {
                    height: 21,
                    url: "/Scripts/app/content/images/water/River_Fair.png",
                    width: 20
                },
                label: "Fair"
            };
            assert.strictEqual(renderer.infos.filter(function (obj) { return obj.value === expectedSymbol.value; })[0].label, expectedSymbol.label, 'Get Renderer doesn\'t have expected symbol label');
            assert.include(renderer.infos.filter(function (obj) { return obj.value === expectedSymbol.value; })[0].symbol.url, expectedSymbol.symbol.url, 'Get Renderer doesn\'t have expected symbol');

            expectedSymbol = {
                value: "M",
                symbol: {
                    height: 21,
                    url: "/Scripts/app/content/images/water/River_Marginal.png",
                    width: 20
                },
                label: "Marginal"
            };
            assert.strictEqual(renderer.infos.filter(function (obj) { return obj.value === expectedSymbol.value; })[0].label, expectedSymbol.label, 'Get Renderer doesn\'t have expected symbol label');
            assert.include(renderer.infos.filter(function (obj) { return obj.value === expectedSymbol.value; })[0].symbol.url, expectedSymbol.symbol.url, 'Get Renderer doesn\'t have expected symbol');

            expectedSymbol = {
                value: "P",
                symbol: {
                    height: 21,
                    url: "/Scripts/app/content/images/water/River_Poor.png",
                    width: 20
                },
                label: "Poor"
            };
            assert.strictEqual(renderer.infos.filter(function (obj) { return obj.value === expectedSymbol.value; })[0].label, expectedSymbol.label, 'Get Renderer doesn\'t have expected symbol label');
            assert.include(renderer.infos.filter(function (obj) { return obj.value === expectedSymbol.value; })[0].symbol.url, expectedSymbol.symbol.url, 'Get Renderer doesn\'t have expected symbol');

        },

        'Test InfoWindow Title handler': function () {
            var title, graphicObject = { attributes: { OBJECTID: 60, SITE_ID: 'DUR-1' } },
                expectedTitleContent = 'River Water Quality';
            title = riverQualityContentModule.infoWindowHandlerTitle(graphicObject);
            assert.strictEqual(title, expectedTitleContent, 'InfoWindowHandlerTitle error');

            graphicObject = { attributes: { OBJECTID: 63, SITE_ID: 'ATR-DD-CC' } };
            title = riverQualityContentModule.infoWindowHandlerTitle(graphicObject);
            assert.strictEqual(title, expectedTitleContent, 'InfoWindowHandlerTitle error');

            graphicObject = {
                attributes: {
                    Number: 'AL07DD0001',
                    Name: 'ATHABASCA RIVER AT 27 BASELINE',
                    Watershed: 'Lower Athabasca',
                    Waterbody: 'Athabasca River',
                    Period: '1969-Present',
                    Site: 'M9'
                }
            };
            expectedTitleContent = 'River Water Quality - JOSM Site';
            title = riverQualityContentModule.infoWindowHandlerTitle(graphicObject);
            assert.strictEqual(title, expectedTitleContent, 'InfoWindowHandlerTitle error');

            graphicObject = {
                attributes: {
                    Id: 17,
                    StationName: "ATHABASCA RIVER AT ATHABASCA",
                    PeriodStartYear: 2012,
                    PeriodEndYear: 2013,
                    Period: "2012-2013",
                    PeriodAbbreviation: "1213",
                    MetalsIndex: 97.3,
                    NutrientsIndex: 89.8,
                    BacterialIndex: 100,
                    PesticidesIndex: 100,
                    WaterQualityIndex: 97,
                    MetalsRatingCode: "E",
                    NutrientsRatingCode: "G",
                    BacterialRatingCode: "E",
                    PesticidesRatingCode: "E",
                    WaterQualityIndexRatingCode: "E",
                    StationNo: "AB07BE0010",
                    WaterQualityIndexRating: null,
                    BacterialRating: null,
                    MetalsRating: null,
                    NutrientsRating: null,
                    PesticidesRating: null,
                    Station: {
                        StationNo: "AB07BE0010",
                        StationName: "ATHABASCA RIVER",
                        StationTypeCode: 0,
                        Location: "AT TOWN OF ATHABASCA",
                        Latitude: 54.72222,
                        Longitude: -113.28611,
                        RiverSubBasinCode: "07BE",
                        BasinName: "07BE TAWATINAW RIVER",
                        SampleInventories: [],
                        WaterQualityIndexes: [],
                        RiverSamples: [],
                        LakeSamples: [],
                        StationType: null
                    }
                }
            };
            expectedTitleContent = 'River Water Quality';
            title = riverQualityContentModule.infoWindowHandlerTitle(graphicObject);
            assert.strictEqual(title, expectedTitleContent, 'InfoWindowHandlerTitle error');
        },

        'Test InfoWindow Content handler': function () {
            var graphicObject = { attributes: { OBJECTID: 60, SITE_ID: 'DUR-1' } },
                contentNode = riverQualityContentModule.infoWindowHandlerContent(graphicObject),
                stationNode = query('.infoWindowStationName', contentNode),
                sectionList = query('.infoWindowSection', contentNode);

            assert.equal(contentNode.childNodes.length, 2, 'child nodes number is wrong');
            assert.equal(stationNode.length, 1, 'station node does not exist');
            assert.equal(sectionList.length, 2, 'section number is wrong');
            assert.include(sectionList[0].innerHTML, graphicObject.attributes.SITE_ID, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[1].innerHTML, "Station Reading", 'infoWindowHandlerContent does not match');

            graphicObject = {
                attributes: {
                    Number: 'AL07DD0001',
                    Name: 'ATHABASCA RIVER AT 27 BASELINE',
                    Watershed: 'Lower Athabasca',
                    Waterbody: 'Athabasca River',
                    Period: '1969-Present',
                    Site: 'M9'
                }
            };
            contentNode = riverQualityContentModule.infoWindowHandlerContent(graphicObject);
            stationNode = query('.infoWindowStationName', contentNode);
            sectionList = query('.infoWindowSection', contentNode);

            assert.equal(contentNode.childNodes.length, 5, 'child nodes number is wrong');
            assert.equal(stationNode.length, 1, 'station node does not exist');
            assert.equal(sectionList.length, 5, 'section number is wrong');
            assert.include(sectionList[0].innerHTML, graphicObject.attributes.Name, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[1].innerHTML, graphicObject.attributes.Number, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[2].innerHTML, 'Water Body', 'infoWindowHandlerContent does not match');
            assert.include(sectionList[3].innerHTML, graphicObject.attributes.Watershed, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[4].innerHTML, 'Data', 'infoWindowHandlerContent does not match');

            graphicObject = {
                attributes: {
                    Id: 17,
                    StationName: "ATHABASCA RIVER AT ATHABASCA",
                    PeriodStartYear: 2012,
                    PeriodEndYear: 2013,
                    Period: "2012-2013",
                    PeriodAbbreviation: "1213",
                    MetalsIndex: 97.3,
                    NutrientsIndex: 89.8,
                    BacterialIndex: 100,
                    PesticidesIndex: 100,
                    WaterQualityIndex: 97,
                    MetalsRatingCode: "E",
                    NutrientsRatingCode: "G",
                    BacterialRatingCode: "E",
                    PesticidesRatingCode: "E",
                    WaterQualityIndexRatingCode: "E",
                    StationNo: "AB07BE0010",
                    WaterQualityIndexRating: null,
                    BacterialRating: null,
                    MetalsRating: null,
                    NutrientsRating: null,
                    PesticidesRating: null,
                    Station: {
                        StationNo: "AB07BE0010",
                        StationName: "ATHABASCA RIVER",
                        StationTypeCode: 0,
                        Location: "AT TOWN OF ATHABASCA",
                        Latitude: 54.72222,
                        Longitude: -113.28611,
                        RiverSubBasinCode: "07BE",
                        BasinName: "07BE TAWATINAW RIVER",
                        SampleInventories: [],
                        WaterQualityIndexes: [],
                        RiverSamples: [],
                        LakeSamples: [],
                        StationType: null
                    }
                }
            };

            contentNode = riverQualityContentModule.infoWindowHandlerContent(graphicObject);
            stationNode = query('.infoWindowStationName', contentNode);
            sectionList = query('.infoWindowSection', contentNode);

            assert.equal(contentNode.childNodes.length, 5, 'child nodes number is wrong');
            assert.equal(stationNode.length, 1, 'station node does not exist');
            assert.equal(sectionList.length, 5, 'section number is wrong');
            assert.include(sectionList[0].innerHTML, graphicObject.attributes.StationName, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[1].innerHTML, graphicObject.attributes.Period, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[2].innerHTML, 'infoWindowNumberTable', 'infoWindowHandlerContent does not match');
            assert.include(sectionList[3].innerHTML, 'More Water Quality Index Detail', 'infoWindowHandlerContent does not match');
            assert.include(sectionList[4].innerHTML, 'More Water Quality Data', 'infoWindowHandlerContent does not match');

            graphicObject = {
                attributes: {
                    Id: 201,
                    StationName: "PEACE RIVER U/S SMOKY RIVER NEAR SHAFTESBURY CROSSING",
                    PeriodStartYear: 2012,
                    PeriodEndYear: 2013,
                    Period: "2012-2013",
                    PeriodAbbreviation: "1213",
                    MetalsIndex: 97.1,
                    NutrientsIndex: 80.5,
                    BacterialIndex: 100,
                    PesticidesIndex: 100,
                    WaterQualityIndex: 94,
                    MetalsRatingCode: "E",
                    NutrientsRatingCode: "G",
                    BacterialRatingCode: "E",
                    PesticidesRatingCode: "E",
                    WaterQualityIndexRatingCode: "G",
                    StationNo: "AB07FD0135",
                    WaterQualityIndexRating: null,
                    BacterialRating: null,
                    MetalsRating: null,
                    NutrientsRating: null,
                    PesticidesRating: null,
                    Station: {
                        StationNo: "AB07FD0135",
                        StationName: "PEACE RIVER",
                        StationTypeCode: 0,
                        Location: "U/S SMOKY RIVER NEAR SHAFTESBURY FERRY TRANSECT",
                        Latitude: 56.09319,
                        Longitude: -117.56608,
                        RiverSubBasinCode: "07FD",
                        BasinName: "07FD PEACE RIVER ABOVE PEACE RIVER",
                        SampleInventories: [],
                        WaterQualityIndexes: [],
                        RiverSamples: [],
                        LakeSamples: [],
                        StationType: null
                    }
                }
            };

            contentNode = riverQualityContentModule.infoWindowHandlerContent(graphicObject);
            stationNode = query('.infoWindowStationName', contentNode);
            sectionList = query('.infoWindowSection', contentNode);

            assert.equal(contentNode.childNodes.length, 3, 'child nodes number is wrong');
            assert.equal(stationNode.length, 1, 'station node does not exist');
            assert.equal(sectionList.length, 3, 'section number is wrong');
            assert.include(sectionList[0].innerHTML, graphicObject.attributes.StationName, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[1].innerHTML, graphicObject.attributes.Period, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[2].innerHTML, 'infoWindowNumberTable', 'infoWindowHandlerContent does not match');
        },

        'Test Create Water Quality Stations Graphic': function () {
            var feature,
                expectedIcon = 'River_Excellent.png',
                waterStationData = riverQualityContentModule.riverQualityStations[1];
            feature = riverQualityContentModule._createWaterQualityStationsGraphic(waterStationData);
            assert.include(feature.symbol.url, expectedIcon, 'Unexpected symbol');
            assert.strictEqual(feature.attributes.Period, waterStationData.Period, 'Unexpected content');

            waterStationData = riverQualityContentModule.riverQualityStations[2];
            feature = riverQualityContentModule._createWaterQualityStationsGraphic(waterStationData);
            assert.include(feature.symbol.url, expectedIcon, 'Unexpected symbol');
            assert.strictEqual(feature.attributes.BacterialIndex, waterStationData.BacterialIndex, 'Unexpected content');

            waterStationData = riverQualityContentModule.riverQualityStations[30];
            feature = riverQualityContentModule._createWaterQualityStationsGraphic(waterStationData);
            assert.include(feature.symbol.url, expectedIcon, 'Unexpected symbol');
            assert.strictEqual(feature.attributes.StationName, waterStationData.StationName, 'Unexpected content');
        },

        'Test JOSM Stations Graphic': function () {
            var feature, expectedIcon = 'River.png', waterStationData = riverQualityContentModule.josmStations[1];
            feature = riverQualityContentModule._createJOSMStationsGraphic(waterStationData);
            assert.include(feature.symbol.url, expectedIcon, 'Unexpected symbol');
            assert.strictEqual(feature.attributes.Name, waterStationData.name, 'Unexpected content');
        },

        'Test Get River Quality Verbose': function () {
            var result, code = 'E', expectedVerbose = 'Excellent';
            result = riverQualityContentModule._getRiverQualityVerbose(code);
            assert.strictEqual(result, expectedVerbose, 'Unexpected Verbose');

            code = 'G';
            expectedVerbose = 'Good';
            result = riverQualityContentModule._getRiverQualityVerbose(code);
            assert.strictEqual(result, expectedVerbose, 'Unexpected Verbose');

            code = 'F';
            expectedVerbose = 'Fair';
            result = riverQualityContentModule._getRiverQualityVerbose(code);
            assert.strictEqual(result, expectedVerbose, 'Unexpected Verbose');

            code = 'M';
            expectedVerbose = 'Marginal';
            result = riverQualityContentModule._getRiverQualityVerbose(code);
            assert.strictEqual(result, expectedVerbose, 'Unexpected Verbose');

            code = 'P';
            expectedVerbose = 'Poor';
            result = riverQualityContentModule._getRiverQualityVerbose(code);
            assert.strictEqual(result, expectedVerbose, 'Unexpected Verbose');

            code = 'Z';
            expectedVerbose = 'N/A';
            result = riverQualityContentModule._getRiverQualityVerbose(code);
            assert.strictEqual(result, expectedVerbose, 'Unexpected Verbose');
        }
    });
});
