﻿/*global
    DOMParser
*/
/*property
    HECTARES, LAND_AREA, MODE_SNAPSHOT, OPERATOR_NAME, POND_NAME, PROJECT_NAME,
    STYLE_SOLID, TAILINGS_STRUCTURE, TotalDedicatedDryingSurfaceArea,
    TotalDedicatedDryingSurfaceAreaHectares, TotalDrySurfaceArea,
    TotalDrySurfaceAreaHectares, TotalSurfaceArea, TotalSurfaceAreaHectares,
    TotalWetSurfaceArea, TotalWetSurfaceAreaHectares, YEAR,
    _addMergedFeatureToLayer, _dataUrl, _isSnapshot, _isWetPond, _json, _layer,
    _loadTailingsPondLocationsSuccess, _tailingsPonds, a, addGraphics, alias,
    async, attributes, content, createFeatureLayer, dataUrl,
    dedicatedDryingFillSymbol, defaultLabel, defaultSymbol, dryFillSymbol,
    fail, featureSet, features, fields, forEach, geometry, geometryType,
    getElementById, getElementsByTagName, getRenderer, graphics, id, include,
    infoTemplate, infoWindowHandlerContent, infoWindowHandlerTitle, infos,
    isFalse, isNotNull, isTrue, label, layerDefinition, length, lengthOf,
    match, mode, name, notEqual, notInclude, outFields, parseFromString, push,
    reject, replace, resolve, rings, setGeometry, setInfoTemplate, setSymbol,
    setup, some, spatialReference, strictEqual, stringify, symbol, then, title,
    type, value, visible, wetFillSymbol, wkid, xmax, xmin, ymax, ymin, innerHTML, childNodes, equal
*/
define([
    'intern!object',
    'intern/chai!assert',
    'dojo/_base/Color',
    'dojo/_base/array',
    'dojo/query',
    'esri/symbols/SimpleLineSymbol',
    'esri/symbols/SimpleFillSymbol',
    'esri/renderers/UniqueValueRenderer',
    'esri/layers/FeatureLayer',
    'esri/geometry/Polygon',
    'esri/geometry/Extent',
    'app/content/TailingsPondContent'
], function (registerSuite, assert, Color, array, query, SimpleLineSymbol, SimpleFillSymbol, UniqueValueRenderer,
    FeatureLayer, Polygon, Extent, TailingsPondContent) {
    'use strict';
    var options = { dataUrl: 'http://aemerisuat.alberta.ca/data/' },
        dryPondSymbol, 
        wetPondSymbol,
        dedicatedDryPondSymbol,
        tailingsPondContent;
    registerSuite({
        name: 'TailingsPondContent module tests',
        setup: function () {
            tailingsPondContent = new TailingsPondContent(options);

            var dryPondColor = new Color("#FFAA00"),
                wetPondColor = new Color("#ffc859"),
                dedicatedDryColor = new Color("#E26229");

            dryPondColor.a = 1;
            wetPondColor.a = 1;
            dedicatedDryColor.a = 1;

            dryPondSymbol = new SimpleFillSymbol(SimpleFillSymbol.STYLE_SOLID,
                new SimpleLineSymbol(
                    SimpleLineSymbol.STYLE_SOLID,
                    dryPondColor,
                    1),
                dryPondColor);

            wetPondSymbol = new SimpleFillSymbol(SimpleFillSymbol.STYLE_SOLID,
                new SimpleLineSymbol(
                    SimpleLineSymbol.STYLE_SOLID,
                    wetPondColor,
                    1),
                wetPondColor);

            dedicatedDryPondSymbol = new SimpleFillSymbol(SimpleFillSymbol.STYLE_SOLID,
                new SimpleLineSymbol(
                    SimpleLineSymbol.STYLE_SOLID,
                    dedicatedDryColor,
                    1),
                dedicatedDryColor);
        },
        'Test Constructor': function () {
            assert.isTrue(tailingsPondContent._tailingsPonds instanceof Object, "Constructor doesn't return expected _tailingsPonds.");
            // tried deepEqual but not working here
            assert.strictEqual(JSON.stringify(tailingsPondContent.dryFillSymbol), JSON.stringify(dryPondSymbol),
                "Constructor doesn't return expected dryFillSymbol.");
            assert.strictEqual(JSON.stringify(tailingsPondContent.wetFillSymbol), JSON.stringify(wetPondSymbol),
                "Constructor doesn't return expected wetFillSymbol.");
            assert.strictEqual(JSON.stringify(tailingsPondContent.dedicatedDryingFillSymbol), JSON.stringify(dedicatedDryPondSymbol),
                "Constructor doesn't return expected dedicatedDryingFillSymbol.");
            assert.strictEqual(tailingsPondContent._dataUrl, options.dataUrl, "Constructor doesn't return expected dataUrl");
        },
        'Test InfoWindowHandlerTitle': function () {
            var graphicObject = { attributes: { PROJECT_NAME: "PROJECT_NAME" } },
                expectedResult = "PROJECT_NAME",
                result = tailingsPondContent.infoWindowHandlerTitle(graphicObject);

            assert.strictEqual(result, expectedResult, "infoWindowHandlerTitle doesn't return expected result.");
            assert.include(result, graphicObject.attributes.PROJECT_NAME, "Project name was not included in the output.");
        },
        'Test infoWindowHandlerContent': function () {
            var pondName = "Pond 1",
                wetGraphicData1 = {
                    attributes: {
                        OPERATOR_NAME: "wet 1 Resources Limited",
                        PROJECT_NAME: "wet 1 Horizon Mine",
                        YEAR: 2012,
                        POND_NAME: pondName,
                        TAILINGS_STRUCTURE: "04"
                    }
                },
                wetGraphicData2 = {
                    attributes: {
                        OPERATOR_NAME: "wet 2 Resources Limited",
                        PROJECT_NAME: "wet 2 Horizon Mine",
                        YEAR: 2012,
                        POND_NAME: pondName,
                        TAILINGS_STRUCTURE: "07"
                    }
                },
                dryGraphicData = {
                    attributes: {
                        OPERATOR_NAME: "Dry Resources Limited",
                        PROJECT_NAME: "Dry Horizon Mine",
                        YEAR: 2012,
                        POND_NAME: pondName,
                        TAILINGS_STRUCTURE: "01"
                    }
                },
                dedicatedDryGraphicData = {
                    attributes: {
                        OPERATOR_NAME: "Dedicated Dry Resources Limited",
                        PROJECT_NAME: "Dedicated Dry Horizon Mine",
                        YEAR: 2012,
                        POND_NAME: pondName,
                        TAILINGS_STRUCTURE: "08"
                    }
                },
                wetTailingsKeyword = "Wet Tailings",
                dryTailingsKeyword = "Dry Tailings",
                dedicatedDryTailingsKeyword = "Dedicated Dry Tailings",
                totalAreaKeyword = "Total Surface Area",
                downloadKeyword = "Download Shape Files",
                contentNode = null, sectionList = null;

            tailingsPondContent._tailingsPonds[pondName] = {
                TotalSurfaceArea: 23223842.45916834,
                TotalWetSurfaceArea: 10298846.85334276,
                TotalDrySurfaceArea: 11663898.086367752,
                TotalDedicatedDryingSurfaceArea: 1261097.5194578299
            };

            // first wet
            contentNode = tailingsPondContent.infoWindowHandlerContent(wetGraphicData1);
            sectionList = query('.infoWindowSection', contentNode);

            assert.equal(contentNode.childNodes.length, 5, 'child nodes number is wrong');
            assert.equal(sectionList.length, 5, 'section number is wrong');
            assert.include(sectionList[0].innerHTML, wetGraphicData1.attributes.OPERATOR_NAME, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[1].innerHTML, pondName + ", " + wetTailingsKeyword, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[2].innerHTML, totalAreaKeyword, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[3].innerHTML, "Wet Tailings Surface Area", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[4].innerHTML, downloadKeyword, 'infoWindowHandlerContent does not match');
          
            // second wet
            contentNode = tailingsPondContent.infoWindowHandlerContent(wetGraphicData2);
            sectionList = query('.infoWindowSection', contentNode);

            assert.equal(contentNode.childNodes.length, 5, 'child nodes number is wrong');
            assert.equal(sectionList.length, 5, 'section number is wrong');
            assert.include(sectionList[0].innerHTML, wetGraphicData2.attributes.OPERATOR_NAME, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[1].innerHTML, pondName + ", " + wetTailingsKeyword, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[2].innerHTML, totalAreaKeyword, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[3].innerHTML, "Wet Tailings Surface Area", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[4].innerHTML, downloadKeyword, 'infoWindowHandlerContent does not match');

            // dry 
            contentNode = tailingsPondContent.infoWindowHandlerContent(dryGraphicData);
            sectionList = query('.infoWindowSection', contentNode);

            assert.equal(contentNode.childNodes.length, 5, 'child nodes number is wrong');
            assert.equal(sectionList.length, 5, 'section number is wrong');
            assert.include(sectionList[0].innerHTML, dryGraphicData.attributes.OPERATOR_NAME, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[1].innerHTML, pondName + ", " + dryTailingsKeyword, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[2].innerHTML, totalAreaKeyword, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[3].innerHTML, "Dry Tailings Surface Area", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[4].innerHTML, downloadKeyword, 'infoWindowHandlerContent does not match');

            // dedicated dry
            contentNode = tailingsPondContent.infoWindowHandlerContent(dedicatedDryGraphicData);
            sectionList = query('.infoWindowSection', contentNode);

            assert.equal(contentNode.childNodes.length, 5, 'child nodes number is wrong');
            assert.equal(sectionList.length, 5, 'section number is wrong');
            assert.include(sectionList[0].innerHTML, dedicatedDryGraphicData.attributes.OPERATOR_NAME, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[1].innerHTML, pondName + ", " + dedicatedDryTailingsKeyword, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[2].innerHTML, totalAreaKeyword, 'infoWindowHandlerContent does not match');
            assert.include(sectionList[3].innerHTML, "Dedicated Drying Surface Area", 'infoWindowHandlerContent does not match');
            assert.include(sectionList[4].innerHTML, downloadKeyword, 'infoWindowHandlerContent does not match');
        },
        'Test Create FeatureLayer': function () {
            var layerDefinition = {
                    geometryType: "esriGeometryPolygon",
                    fields: [
                        {
                            name: "BUFF_DIST",
                            type: "esriFieldTypeInteger",
                            alias: "Buffer Distance"
                        }
                    ]
                },
                layerId = "tailingsPond1",
                result = tailingsPondContent.createFeatureLayer(layerDefinition, layerId);

            assert.isTrue(result instanceof FeatureLayer, "Create FeatureLayer doesn't return expected object");
            assert.strictEqual(result.id, layerId, "Create FeatureLayer doesn't return expected layerId.");
            assert.strictEqual(result.graphics.length, 0, "Create FeatureLayer doesn't return expected result.");
            assert.isTrue(result._isSnapshot, "Create FeatureLayer doesn't return expected map mode.");
            assert.include(result._json, JSON.stringify(layerDefinition), "Create FeatureLayer doesn't return expected result.");

            layerDefinition = {
                geometryType: "esriGeometryPoint",
                fields: [
                    {
                        name: "ObjectID",
                        type: "esriFieldTypeOID",
                        alias: "ObjectID"
                    },
                    {
                        name: "testField",
                        type: "esriFieldTypeString",
                        alias: "testField"
                    }
                ]
            };
            layerId = "tailingsPond2";
            result = tailingsPondContent.createFeatureLayer(layerDefinition, layerId);

            assert.isTrue(result instanceof FeatureLayer, "Create FeatureLayer doesn't return expected object");
            assert.strictEqual(result.id, layerId, "Create FeatureLayer doesn't return expected layerId.");
            assert.strictEqual(result.graphics.length, 0, "Create FeatureLayer doesn't return expected result.");
            assert.isTrue(result._isSnapshot, "Create FeatureLayer doesn't return expected map mode.");
            assert.include(result._json, JSON.stringify(layerDefinition), "Create FeatureLayer doesn't return expected result.");
        },
        'Test Get Renderer': function () {
            var result = tailingsPondContent.getRenderer(),
                expectedDefaultLabel = "Dry Tailings",
                wetPondInfo1 = { value: "04", symbol: wetPondSymbol, label: "Wet Tailings" },
                wetPondInfo2 = { value: "07", symbol: wetPondSymbol, label: "Wet Tailings" },
                dedicatedDryPondInfo = { value: "08", symbol: dedicatedDryPondSymbol, label: "Dedicated Dry Tailings" };

            assert.isTrue(result instanceof UniqueValueRenderer, "Get Renderer doesn't return expected object");
            assert.strictEqual(result.defaultLabel, expectedDefaultLabel, "Get Renderer doesn't return expected default label.");
            assert.strictEqual(JSON.stringify(result.defaultSymbol), JSON.stringify(dryPondSymbol), "Get Renderer doesn't return expected default symbol.");
            assert.strictEqual(result.infos.length, 3, "Get Renderer doesn't return expected symbols.");
            assert.strictEqual(JSON.stringify(result.infos[0]), JSON.stringify(wetPondInfo1), "Get Renderer doesn't return expected wet render.");
            assert.strictEqual(JSON.stringify(result.infos[1]), JSON.stringify(wetPondInfo2), "Get Renderer doesn't return expected wet render.");
            assert.strictEqual(JSON.stringify(result.infos[2]), JSON.stringify(dedicatedDryPondInfo), "Get Renderer doesn't return expected dedicated dry render.");
        },
        'Test Add Graphics': function () {
            var layerDefinition = {
                    geometryType: "esriGeometryPolygon",
                    fields: [
                        {
                            name: "TAILINGS_STRUCTURE",
                            type: "esriFieldTypeString",
                            alias: "Tailings Structure"
                        }, {
                            name: "POND_NAME",
                            type: "esriFieldTypeString",
                            alias: "Pond Name"
                        }, {
                            name: "YEAR",
                            type: "esriFieldTypeSmallInteger",
                            alias: "YEAR"
                        }, {
                            name: "LAND_AREA",
                            type: "esriFieldTypeDouble",
                            alias: "Area"
                        }, {
                            name: "HECTARES",
                            type: "esriFieldTypeDouble",
                            alias: "HECTARES"
                        }, {
                            name: "PROJECT_NAME",
                            type: "esriFieldTypeString",
                            alias: "Project Name"
                        }, {
                            name: "OPERATOR_NAME",
                            type: "esriFieldTypeString",
                            alias: "Operator Name"
                        }
                    ]
                },
                featureCollection = {
                    layerDefinition: layerDefinition,
                    featureSet: null
                },
                layer = new FeatureLayer(featureCollection, { id: "tailingsPond", visible: false, mode: FeatureLayer.MODE_SNAPSHOT }),
                iniExtent = new Extent({
                    xmin: -14265055.060527408,
                    ymin: 6259094.656300137,
                    xmax: -11283399.461180044,
                    ymax: 8409115.387905004,
                    spatialReference: {
                        wkid: 102100
                    }
                }),
                mapServerUrl = "https://maps.alberta.ca/genesis_tokenauth/rest/services/OSIP-Layers/20161021/MapServer/158",
                hasValidPond = false,
                def = this.async(10000);
            options.outFields = ['*'];
            tailingsPondContent.addGraphics(layer, mapServerUrl, options, iniExtent).then(function () {
                setTimeout(function () {
                    assert.isTrue(tailingsPondContent._layer.graphics.length > 0, "Add Graphics doesn't save any graphic objects.");
                    hasValidPond = array.some(tailingsPondContent._layer.graphics, function (graphic) {
                        if (graphic.attributes.OPERATOR_NAME.length > 0 && graphic.geometry instanceof Polygon) {
                            return true;
                        }
                    });
                    assert.isTrue(hasValidPond, "Add Graphics doesn't contain valid ponds.");
                    def.resolve();
                }, 3000); // need to wait longer since it merge features in the async way             
            }, function (error) {
                assert.fail("Add Graphics failed: " + error);
                def.reject();
            });            
        },
        'Test Load TailingsPondLocationsSuccess': function () {
            var layerDefinition = {
                geometryType: "esriGeometryPolygon",
                fields: [
                    {
                        name: "TAILINGS_STRUCTURE",
                        type: "esriFieldTypeString",
                        alias: "Tailings Structure"
                    }, {
                        name: "POND_NAME",
                        type: "esriFieldTypeString",
                        alias: "Pond Name"
                    }, {
                        name: "YEAR",
                        type: "esriFieldTypeSmallInteger",
                        alias: "YEAR"
                    }, {
                        name: "LAND_AREA",
                        type: "esriFieldTypeDouble",
                        alias: "Area"
                    }, {
                        name: "HECTARES",
                        type: "esriFieldTypeDouble",
                        alias: "HECTARES"
                    }, {
                        name: "PROJECT_NAME",
                        type: "esriFieldTypeString",
                        alias: "Project Name"
                    }, {
                        name: "OPERATOR_NAME",
                        type: "esriFieldTypeString",
                        alias: "Operator Name"
                    }
                ]},
                featureCollection = {
                    layerDefinition: layerDefinition,
                    featureSet: null
                },
                layer = new FeatureLayer(featureCollection, { id: "tailingsPond", visible: false, mode: FeatureLayer.MODE_SNAPSHOT });

            tailingsPondContent._layer = layer;

            // to test the sum of wet/dry pond areas, we need at least four features
            // dry ponds
            var dryPondName = "Dry Pond 1",
                polygonJson1 = {
                    rings: [
                        [[-12453909.114073994, 7837531.30460549], [-12453476.821960814, 7837381.89638761], [-12453529.211003032, 7837315.316024232], [-12453708.48359676, 7837091.813973272], [-12453533.886552928, 7837042.790879821], [-12453503.453779617, 7837063.688863605], [-12453504.896048967, 7837176.459793722], [-12453439.017883154, 7837298.942444073], [-12453404.93419509, 7837362.310930569], [-12452921.413817232, 7837163.421924531], [-12452895.831770608, 7837109.694994883], [-12452858.328823652, 7837030.930591884], [-12452513.461834066, 7835986.143460981], [-12453055.774781661, 7835882.005584454], [-12453174.878252637, 7836286.823319815], [-12453343.11338326, 7836585.560512601], [-12453874.711955976, 7837029.441900025], [-12453984.353307525, 7836988.49629312], [-12454224.652643263, 7837115.344847323], [-12454335.59572276, 7837075.130163825], [-12455122.236229392, 7837469.939551821], [-12454935.290766345, 7837803.256269633], [-12454782.729433531, 7837877.024781748], [-12454659.935141945, 7837878.621327496], [-12454134.718790125, 7837609.266838435], [-12453909.114073994, 7837531.30460549]]
                    ],
                    spatialReference: { wkid: 102100 }                    
                },
                polygon1 = new Polygon(polygonJson1),
                dryPondData1 = {
                    geometry: polygon1,
                    attributes: { id: null, POND_NAME: dryPondName, LAND_AREA: 100.50, HECTARES: 10.5, TAILINGS_STRUCTURE: "01" },
                    symbol: null,
                    infoTemplate: null,
                    setInfoTemplate: function(template) { this.infoTemplate = template; },
                    setSymbol: function (icon) { this.symbol = icon; },
                    setGeometry: function (geometry) { this.geometry = geometry; }
                },
                polygonJson2 = {
                    rings: [
                        [[-12452626.11517339, 7830201.994742203], [-12452598.975416098, 7830449.529109035], [-12452692.446281878, 7830429.772527036], [-12452670.851126645, 7830725.547759901], [-12452697.235900661, 7830837.264392866], [-12452652.200485127, 7830747.373989621], [-12452648.438997868, 7830735.180505703], [-12452619.966096472, 7830753.7667067], [-12452571.06856887, 7830752.401346829], [-12452523.11667832, 7830765.780817994], [-12452612.1501226, 7830990.861411893], [-12452638.85128974, 7830972.16195227], [-12452719.845923508, 7830931.380574417], [-12452731.32527345, 7830984.785034877], [-12452627.180199178, 7831135.54616383], [-12452611.420616101, 7831288.198933104], [-12452211.582141064, 7831297.307720374], [-12452129.920916935, 7831289.261551864], [-12452087.645399129, 7831271.448548877], [-12451986.952292008, 7831268.370474991], [-12452078.296643153, 7830167.615294019], [-12452118.509921858, 7830163.071686554], [-12452156.582657646, 7830148.467605501], [-12452351.853195425, 7830170.733601611], [-12452451.142178487, 7830202.700815397], [-12452626.11517339, 7830201.994742203]]
                    ],
                    spatialReference: { wkid: 102100 }
                },
                polygon2 = new Polygon(polygonJson2),
                dryPondData2 = {
                    geometry: polygon2,
                    attributes: { id: null, POND_NAME: dryPondName, LAND_AREA: 200.50, HECTARES: 20.5, TAILINGS_STRUCTURE: "03" },
                    symbol: null,
                    infoTemplate: null,
                    setInfoTemplate: function(template) { this.infoTemplate = template; },
                    setSymbol: function (icon) { this.symbol = icon; },
                    setGeometry: function (geometry) { this.geometry = geometry; }
                },
                // dedicated Dry pond
                dedicatedDryPondName = "Dedicated Dry Pond 1",
                polygonJson3 = {
                    rings: [
                        [[-12452482.79734564, 7829348.281897855], [-12452470.385935307, 7829472.768791159], [-12452456.005454253, 7829472.874152755], [-12452462.48594769, 7829496.846515889], [-12452447.808778258, 7829524.536460458], [-12452420.779737685, 7829520.978240933], [-12452426.006104754, 7829656.470567447], [-12452453.09407287, 7829658.695681028], [-12452442.23405741, 7829771.620014404], [-12452418.891626624, 7830026.428951753], [-12452569.40005665, 7830059.222234255], [-12452587.968734432, 7829870.875117755], [-12452620.30549154, 7829520.666633584], [-12452630.068526432, 7829499.030763342], [-12452686.625098636, 7829372.372010544], [-12452801.791348828, 7829379.481603546], [-12452851.473739833, 7829374.397967003], [-12452938.002876269, 7829376.219839395], [-12452912.56028302, 7829432.640077992], [-12452776.582490215, 7829819.5467493795], [-12452696.621016044, 7829802.665320682], [-12452633.938529922, 7830130.342813489], [-12452631.880025811, 7830149.372176287], [-12452470.75511291, 7830112.403664819], [-12452121.303685935, 7830073.211176248], [-12452088.914698966, 7830059.989040663], [-12452141.612675285, 7829565.077315176], [-12452160.905318387, 7829313.293929345], [-12452482.79734564, 7829348.281897855]]
                    ],
                    spatialReference: { wkid: 102100 }
                },
                polygon3 = new Polygon(polygonJson3),
                dedicatedDryPondData1 = {
                    geometry: polygon3,
                    attributes: { id: null, POND_NAME: dedicatedDryPondName, LAND_AREA: 100.50, HECTARES: 10.5, TAILINGS_STRUCTURE: "08" },
                    symbol: null,
                    infoTemplate: null,
                    setInfoTemplate: function (template) { this.infoTemplate = template; },
                    setSymbol: function (icon) { this.symbol = icon; },
                    setGeometry: function (geometry) { this.geometry = geometry; }
                },
                polygonJson4 = {
                    rings: [
                        [[-12453935.02870412, 7824559.410434582], [-12454050.424295949, 7824426.925695658], [-12454436.783595417, 7824578.229628982], [-12454444.632491643, 7824581.303140369], [-12454638.644616218, 7824626.349220007], [-12454648.70326037, 7824630.340191028], [-12454898.068042329, 7824669.471911043], [-12455020.250339238, 7824637.170247091], [-12455008.441224014, 7824514.48304536], [-12455242.982956465, 7824480.713346437], [-12455379.490820538, 7824371.827012273], [-12455428.944993952, 7824303.875500228], [-12455563.113353705, 7824381.366864579], [-12455625.280599246, 7824404.435135041], [-12455810.009736927, 7824445.422011263], [-12455912.91276639, 7824456.35060948], [-12456166.951926589, 7824540.647411497], [-12455833.969406009, 7824960.80787328], [-12455736.26745011, 7825231.817127613], [-12455495.436930897, 7825080.66078898], [-12455738.37640676, 7824826.457877253], [-12455592.140489757, 7824748.701874899], [-12455407.670062276, 7825022.2939277515], [-12454365.886384426, 7824646.11374869], [-12454170.733785607, 7824588.264157557], [-12453935.02870412, 7824559.410434582]]
                    ],
                    spatialReference: { wkid: 102100 }
                },
                polygon4 = new Polygon(polygonJson4),
                dedicatedDryPondData2 = {
                    geometry: polygon4,
                    attributes: { id: null, POND_NAME: dedicatedDryPondName, LAND_AREA: 200.50, HECTARES: 20.5, TAILINGS_STRUCTURE: "08" },
                    symbol: null,
                    infoTemplate: null,
                    setInfoTemplate: function (template) { this.infoTemplate = template; },
                    setSymbol: function (icon) { this.symbol = icon; },
                    setGeometry: function (geometry) { this.geometry = geometry; }
                },
                // wet ponds
                wetPondName = "Wet Pond 1",
                polygonJson5 = {
                    rings: [
                        [[-12452471.644489411, 7828073.440338894], [-12452486.191224828, 7827945.535383427], [-12452538.980428444, 7827924.190115363], [-12452555.748251816, 7827851.616154734], [-12452497.287141152, 7827774.091700645], [-12452417.6455694, 7827755.007082725], [-12452400.876738364, 7827795.04047736], [-12452388.147717467, 7827884.756022015], [-12452433.495152391, 7827974.263092159], [-12452433.021600556, 7828027.11178614], [-12452404.98608032, 7828046.2318106145], [-12452313.085412947, 7828009.756114038], [-12452423.772937711, 7827554.995178278], [-12452515.88649358, 7827227.478399301], [-12452580.556742225, 7826952.302192809], [-12452753.318471184, 7826423.793705201], [-12453209.034617843, 7826495.064498398], [-12452848.965226442, 7827732.69034909], [-12452703.634861644, 7827705.848608491], [-12452657.011023458, 7827697.47884124], [-12452561.09450998, 7828039.687411047], [-12452520.404166639, 7828083.171564003], [-12452471.644489411, 7828073.440338894]]
                    ],
                    spatialReference: { wkid: 102100 }
                },
                polygon5 = new Polygon(polygonJson5),
                wetPondData1 = {
                    geometry: polygon5,
                    attributes: { id: null, POND_NAME: wetPondName, LAND_AREA: 1000.50, HECTARES: 100.5, TAILINGS_STRUCTURE: "04" },
                    symbol: null,
                    infoTemplate: null,
                    setInfoTemplate: function(template) { this.infoTemplate = template; },
                    setSymbol: function (icon) { this.symbol = icon; },
                    setGeometry: function (geometry) { this.geometry = geometry; }
                },
                polygonJson6 = {
                    rings: [
                        [[-12452234.662497157, 7828670.661394599], [-12452210.445469216, 7828645.472189953], [-12452216.382283896, 7828456.916290348], [-12452226.508242445, 7828394.546721723], [-12452292.052201146, 7828090.076489045], [-12452317.05772533, 7828078.462378025], [-12452729.025588725, 7828214.879142658], [-12452791.6834436, 7828231.461752374], [-12452691.73936676, 7828350.19164032], [-12452624.326524187, 7828408.607731516], [-12452597.231580805, 7828456.10619979], [-12452583.905875241, 7828582.713987113], [-12452562.137866708, 7828656.464306622], [-12452466.852646241, 7828692.299251413], [-12452234.662497157, 7828670.661394599]]
                    ],
                    spatialReference: { wkid: 102100 }
                },
                polygon6 = new Polygon(polygonJson6),
                wetPondData2 = {
                    geometry: polygon6,
                    attributes: { id: null, POND_NAME: wetPondName, LAND_AREA: 2000.50, HECTARES: 200.5, TAILINGS_STRUCTURE: "07" },
                    symbol: null,
                    infoTemplate: null,
                    setInfoTemplate: function(template) { this.infoTemplate = template; },
                    setSymbol: function (icon) { this.symbol = icon; },
                    setGeometry: function (geometry) { this.geometry = geometry; }
                },
                data = { features: [dryPondData1, dryPondData2, wetPondData1, wetPondData2, dedicatedDryPondData1, dedicatedDryPondData2] },
                // expected objects for tailing pond
                expectedDryPondArea = {
                    TotalSurfaceArea: dryPondData1.attributes.LAND_AREA + dryPondData2.attributes.LAND_AREA,
                    TotalSurfaceAreaHectares: dryPondData1.attributes.HECTARES + dryPondData2.attributes.HECTARES,
                    TotalWetSurfaceArea: 0,
                    TotalWetSurfaceAreaHectares: 0,
                    TotalDrySurfaceArea: dryPondData1.attributes.LAND_AREA + dryPondData2.attributes.LAND_AREA,
                    TotalDrySurfaceAreaHectares: dryPondData1.attributes.HECTARES + dryPondData2.attributes.HECTARES,
                    TotalDedicatedDryingSurfaceArea: 0,
                    TotalDedicatedDryingSurfaceAreaHectares: 0
                },
                expectedWetPondArea = {
                    TotalSurfaceArea: wetPondData1.attributes.LAND_AREA + wetPondData2.attributes.LAND_AREA,
                    TotalSurfaceAreaHectares: wetPondData1.attributes.HECTARES + wetPondData2.attributes.HECTARES,
                    TotalWetSurfaceArea: wetPondData1.attributes.LAND_AREA + wetPondData2.attributes.LAND_AREA,
                    TotalWetSurfaceAreaHectares: wetPondData1.attributes.HECTARES + wetPondData2.attributes.HECTARES,
                    TotalDrySurfaceArea: 0,
                    TotalDrySurfaceAreaHectares: 0,
                    TotalDedicatedDryingSurfaceArea: 0,
                    TotalDedicatedDryingSurfaceAreaHectares: 0
                },
                expectedDedicatedDryPondArea = {
                    TotalSurfaceArea: dedicatedDryPondData1.attributes.LAND_AREA + dedicatedDryPondData2.attributes.LAND_AREA,
                    TotalSurfaceAreaHectares: dedicatedDryPondData1.attributes.HECTARES + dedicatedDryPondData2.attributes.HECTARES,
                    TotalWetSurfaceArea: 0,
                    TotalWetSurfaceAreaHectares: 0,
                    TotalDrySurfaceArea: 0,
                    TotalDrySurfaceAreaHectares: 0,
                    TotalDedicatedDryingSurfaceArea: dedicatedDryPondData1.attributes.LAND_AREA + dedicatedDryPondData2.attributes.LAND_AREA,
                    TotalDedicatedDryingSurfaceAreaHectares: dedicatedDryPondData1.attributes.HECTARES + dedicatedDryPondData2.attributes.HECTARES
                };
            // call the function
            tailingsPondContent._loadTailingsPondLocationsSuccess(data);

            // check tailing pond area calculation
            assert.strictEqual(JSON.stringify(tailingsPondContent._tailingsPonds[dryPondName]), JSON.stringify(expectedDryPondArea),
            "TailingsPondLocationsSuccess doesn't save the dry pond data.");
            assert.strictEqual(JSON.stringify(tailingsPondContent._tailingsPonds[wetPondName]), JSON.stringify(expectedWetPondArea),
            "TailingsPondLocationsSuccess doesn't save the wet pond data.");
            assert.strictEqual(JSON.stringify(tailingsPondContent._tailingsPonds[dedicatedDryPondName]), JSON.stringify(expectedDedicatedDryPondArea),
            "TailingsPondLocationsSuccess doesn't save the dedicated dry pond data.");

            // need to wait for graphic objects created
            var def = this.async(4000);
            setTimeout(function () {
                // check graphic objects in the layer
                assert.strictEqual(tailingsPondContent._layer.graphics.length, 3, "TailingsPondLocationsSuccess doesn't save graphic objects.");

                var wetPondExist = false,
                    dryPondExist = false,
                    dedicatedDryPondExist = false;

                tailingsPondContent._layer.graphics.forEach(function (graphic) {
                    assert.isTrue(graphic.infoTemplate.title instanceof Object, "TailingsPondLocationsSuccess doesn't save expected infoTemplate title.");
                    assert.isTrue(graphic.infoTemplate.content instanceof Object, "TailingsPondLocationsSuccess doesn't save expected infoTemplate content.");
                    assert.isTrue(graphic.geometry instanceof Polygon, "TailingsPondLocationsSuccess doesn't save expected graphic geometry.");

                    if (graphic.attributes.POND_NAME === wetPondName) {
                        wetPondExist = true;
                        assert.strictEqual(JSON.stringify(graphic.symbol), JSON.stringify(wetPondSymbol),
                            "TailingsPondLocationsSuccess doesn't save expected wet pond symbol.");
                        assert.strictEqual(graphic.attributes.HECTARES, wetPondData1.attributes.HECTARES, "TailingsPondLocationsSuccess doesn't save expected HECTARES.");
                        assert.strictEqual(graphic.attributes.LAND_AREA, wetPondData1.attributes.LAND_AREA, "TailingsPondLocationsSuccess doesn't save expected LAND_AREA.");
                    } else if (graphic.attributes.POND_NAME === dryPondName) {
                        dryPondExist = true;
                        assert.strictEqual(JSON.stringify(graphic.symbol), JSON.stringify(dryPondSymbol),
                            "TailingsPondLocationsSuccess doesn't save expected dry pond symbol.");
                        assert.strictEqual(graphic.attributes.HECTARES, dryPondData1.attributes.HECTARES, "TailingsPondLocationsSuccess doesn't save expected HECTARES.");
                        assert.strictEqual(graphic.attributes.LAND_AREA, dryPondData1.attributes.LAND_AREA, "TailingsPondLocationsSuccess doesn't save expected LAND_AREA.");
                    } else if (graphic.attributes.POND_NAME === dedicatedDryPondName) {
                        dedicatedDryPondExist = true;
                        assert.strictEqual(JSON.stringify(graphic.symbol), JSON.stringify(dedicatedDryPondSymbol),
                            "TailingsPondLocationsSuccess doesn't save expected dedicated dry pond symbol.");
                        assert.strictEqual(graphic.attributes.HECTARES, dedicatedDryPondData1.attributes.HECTARES, "TailingsPondLocationsSuccess doesn't save expected HECTARES.");
                        assert.strictEqual(graphic.attributes.LAND_AREA, dedicatedDryPondData1.attributes.LAND_AREA, "TailingsPondLocationsSuccess doesn't save expected LAND_AREA.");
                    }
                });

                assert.isTrue(wetPondExist, "TailingsPondLocationsSuccess doesn't save expected wet pond.");
                assert.isTrue(dryPondExist, "TailingsPondLocationsSuccess doesn't save expected dry pond.");
                assert.isTrue(dedicatedDryPondExist, "TailingsPondLocationsSuccess doesn't save expected dedicated dry pond.");
                
                def.resolve();
            }, 2000); // need to wait longer since it merge features in the async way    
        },
        'Test Add Merged Feature To Layer': function () {
            var layerDefinition = {
                    geometryType: "esriGeometryPolygon",
                    fields: [
                        {
                            name: "TAILINGS_STRUCTURE",
                            type: "esriFieldTypeString",
                            alias: "Tailings Structure"
                        }, {
                            name: "POND_NAME",
                            type: "esriFieldTypeString",
                            alias: "Pond Name"
                        }, {
                            name: "YEAR",
                            type: "esriFieldTypeSmallInteger",
                            alias: "YEAR"
                        }, {
                            name: "LAND_AREA",
                            type: "esriFieldTypeDouble",
                            alias: "Area"
                        }, {
                            name: "HECTARES",
                            type: "esriFieldTypeDouble",
                            alias: "HECTARES"
                        }, {
                            name: "PROJECT_NAME",
                            type: "esriFieldTypeString",
                            alias: "Project Name"
                        }, {
                            name: "OPERATOR_NAME",
                            type: "esriFieldTypeString",
                            alias: "Operator Name"
                        }
                    ]
                },
                featureCollection = {
                    layerDefinition: layerDefinition,
                    featureSet: null
                },
                layer = new FeatureLayer(featureCollection, { id: "tailingsPond", visible: false, mode: FeatureLayer.MODE_SNAPSHOT }),
                geometries = [],
                // feature
                pondName = "Pond 1",
                polygonJson1 = {
                    rings: [
                        [[-12453909.114073994, 7837531.30460549], [-12453476.821960814, 7837381.89638761], [-12453529.211003032, 7837315.316024232], [-12453708.48359676, 7837091.813973272], [-12453533.886552928, 7837042.790879821], [-12453503.453779617, 7837063.688863605], [-12453504.896048967, 7837176.459793722], [-12453439.017883154, 7837298.942444073], [-12453404.93419509, 7837362.310930569], [-12452921.413817232, 7837163.421924531], [-12452895.831770608, 7837109.694994883], [-12452858.328823652, 7837030.930591884], [-12452513.461834066, 7835986.143460981], [-12453055.774781661, 7835882.005584454], [-12453174.878252637, 7836286.823319815], [-12453343.11338326, 7836585.560512601], [-12453874.711955976, 7837029.441900025], [-12453984.353307525, 7836988.49629312], [-12454224.652643263, 7837115.344847323], [-12454335.59572276, 7837075.130163825], [-12455122.236229392, 7837469.939551821], [-12454935.290766345, 7837803.256269633], [-12454782.729433531, 7837877.024781748], [-12454659.935141945, 7837878.621327496], [-12454134.718790125, 7837609.266838435], [-12453909.114073994, 7837531.30460549]]
                    ],
                    spatialReference: { wkid: 102100 }
                },
                polygon1 = new Polygon(polygonJson1),
                feature = {
                    geometry: polygon1,
                    attributes: { id: null, POND_NAME: pondName, LAND_AREA: 100.50, HECTARES: 10.5, TAILINGS_STRUCTURE: "01" },
                    symbol: null,
                    infoTemplate: null,
                    setInfoTemplate: function(template) { this.infoTemplate = template; },
                    setSymbol: function(icon) { this.symbol = icon; },
                    setGeometry: function(geometry) { this.geometry = geometry; }
                },
                polygonJson2 = {
                    rings: [
                        [[-12452626.11517339, 7830201.994742203], [-12452598.975416098, 7830449.529109035], [-12452692.446281878, 7830429.772527036], [-12452670.851126645, 7830725.547759901], [-12452697.235900661, 7830837.264392866], [-12452652.200485127, 7830747.373989621], [-12452648.438997868, 7830735.180505703], [-12452619.966096472, 7830753.7667067], [-12452571.06856887, 7830752.401346829], [-12452523.11667832, 7830765.780817994], [-12452612.1501226, 7830990.861411893], [-12452638.85128974, 7830972.16195227], [-12452719.845923508, 7830931.380574417], [-12452731.32527345, 7830984.785034877], [-12452627.180199178, 7831135.54616383], [-12452611.420616101, 7831288.198933104], [-12452211.582141064, 7831297.307720374], [-12452129.920916935, 7831289.261551864], [-12452087.645399129, 7831271.448548877], [-12451986.952292008, 7831268.370474991], [-12452078.296643153, 7830167.615294019], [-12452118.509921858, 7830163.071686554], [-12452156.582657646, 7830148.467605501], [-12452351.853195425, 7830170.733601611], [-12452451.142178487, 7830202.700815397], [-12452626.11517339, 7830201.994742203]]
                    ],
                    spatialReference: { wkid: 102100 }
                },
                polygon2 = new Polygon(polygonJson2);

            // empty geometry
            tailingsPondContent._layer = layer;
            tailingsPondContent._addMergedFeatureToLayer(geometries, feature, dryPondSymbol);
            assert.strictEqual(tailingsPondContent._layer.graphics.length, 0,
                "Add Merged Feature To Layer should not save the graphic with empty geometry.");

            // one geometry
            geometries.push(feature.geometry);
            tailingsPondContent._addMergedFeatureToLayer(geometries, feature, dryPondSymbol);
            assert.strictEqual(tailingsPondContent._layer.graphics.length, 1,
                "Add Merged Feature To Layer doesn't save expected graphic.");
            assert.strictEqual(JSON.stringify(tailingsPondContent._layer.graphics[0].geometry), JSON.stringify(polygon1),
                "Add Merged Feature To Layer doesn't save expected graphic geometry.");
            assert.strictEqual(JSON.stringify(tailingsPondContent._layer.graphics[0].symbol), JSON.stringify(dryPondSymbol),
                "Add Merged Feature To Layer doesn't save expected graphic symbol.");

            tailingsPondContent._layer.graphics.length = 0; // reset

            // two geometries
            geometries.push(polygon2);
            tailingsPondContent._addMergedFeatureToLayer(geometries, feature, dryPondSymbol);

            // need to wait for graphic objects created
            var def = this.async(4000);
            setTimeout(function () {
                assert.strictEqual(tailingsPondContent._layer.graphics.length, 1,
                "Add Merged Feature To Layer doesn't save expected graphic.");
                assert.isTrue(tailingsPondContent._layer.graphics[0].geometry instanceof Polygon, "Add Merged Feature To Layer doesn't save expected graphic geometry.");
                assert.notEqual(JSON.stringify(tailingsPondContent._layer.graphics[0].geometry), JSON.stringify(polygon1),
                    "Add Merged Feature To Layer doesn't save expected graphic geometry.");
                assert.strictEqual(JSON.stringify(tailingsPondContent._layer.graphics[0].symbol), JSON.stringify(dryPondSymbol),
                    "Add Merged Feature To Layer doesn't save expected graphic symbol.");

                def.resolve();
            }, 2000);
        },
        'Test Is Wet Pond': function () {
            var tailingsStructureValue = "01",
                result = tailingsPondContent._isWetPond(tailingsStructureValue);

            assert.isFalse(result, "Is Wet Pond doesn't return expected result");

            tailingsStructureValue = "04";
            result = tailingsPondContent._isWetPond(tailingsStructureValue);
            assert.isTrue(result, "Is Wet Pond doesn't return expected result");

            tailingsStructureValue = "07";
            result = tailingsPondContent._isWetPond(tailingsStructureValue);
            assert.isTrue(result, "Is Wet Pond doesn't return expected result");
        }
    });
});