﻿/*property
    GetProjectStatuses, Status, _loadProjectStatuses, _projectStatuses,
    deepEqual, fail, isNotNull, isNull, isTrue, length, log, name, setup, some,
    then, async, subscribe, hitch, remove, Id, getAirQualityStationNames,
    _airQualityStationNames, _getProjectsInfo, _projectsInfo, _projectsEmission,
    getProjectsEmission, getEnforcementTypes, _enforcementTypes, getProjectsInfo,
    getProjectStatuses, resolve
*/
define([
    'intern!object',
    'intern/chai!assert',
    'dojo/topic',
    'dojo/_base/lang',
    'app/content/WebServiceData'
], function (registerSuite, assert, topic, lang, WebServiceData) {
    'use strict';
    registerSuite({
        name: 'WebServiceData module tests',
        setup: function () {
            assert.isNull(WebServiceData._projectStatuses, "WebServiceData._projectStatuses should be null before first call to WebServiceData.GetProjectStatuses()");
        },
        'Test Singleton': function () {
            var def = this.async(6000),
                projectsData = null,
                projectStatuesHandler = null;

            projectStatuesHandler = topic.subscribe("getProjectStatuses/DataIsReady", lang.hitch(this, function (data) {
                    projectStatuesHandler.remove();
                    projectsData = data;
                }));

            WebServiceData.getProjectStatuses();

            setTimeout(function () {
                assert.isNotNull(WebServiceData._projectStatuses, "WebServiceData._projectStatuses should not be null after any call to WebServiceData.GetProjectStatuses()");
                assert.deepEqual(WebServiceData._projectStatuses, projectsData, "WebServiceData doesn't return single instance");
                require(['app/content/WebServiceData'], function (WebServiceData2) {
                    assert.isNotNull(WebServiceData2._projectStatuses, "WebServiceData2._projectStatuses should not be null since WebServiceData and WebServiceData2 should be a singleton.");
                });

                def.resolve();
            }, 5000); // need to wait for webservice data                        
        },
        'Test Get Project Statuses': function () {
            var hasValidData = false;

            hasValidData = WebServiceData._projectStatuses.some(function (project) {
                if (project.Id > 0) {
                    return true;
                }
            });
            assert.isTrue(hasValidData, "Get Project Statuses doesn't contain valid data.");
        },
        'Test Get AirQualityStationNames': function () {
            var def = this.async(5000),
                webServiceData = null,
                handler = null;

            handler = topic.subscribe("getAirQualityStationNames/DataIsReady", lang.hitch(this, function (data) {
                    handler.remove();
                    webServiceData = data;
                }));

            WebServiceData.getAirQualityStationNames();

            setTimeout(function () {
                assert.isNotNull(WebServiceData._airQualityStationNames, "WebServiceData._airQualityStationNames should not be null.");
                assert.deepEqual(WebServiceData._airQualityStationNames, webServiceData, "Get AirQualityStationNames doesn't return expected result.");
                def.resolve();
            }, 4500); // need to wait for webservice data      
        },
        'Test Get ProjectsInfo': function () {
            var def = this.async(15000),
                webServiceData = null,
                handler = null;

            handler = topic.subscribe("getProjectsInfo/DataIsReady", lang.hitch(this, function (data) {
                    handler.remove();
                    webServiceData = data;
                }));

            WebServiceData.getProjectsInfo();

            setTimeout(function () {
                assert.isNotNull(WebServiceData._projectsInfo, "WebServiceData._projectsInfo should not be null.");
                assert.deepEqual(WebServiceData._projectsInfo, webServiceData, "Get ProjectsInfo doesn't return expected result.");
                def.resolve();
            }, 14500); // need to wait for webservice data      
        },
        'Test Get EnforcementTypes': function () {
            var def = this.async(9000),
                webServiceData = null,
                handler = null;

            handler = topic.subscribe("getEnforcementTypes/DataIsReady", lang.hitch(this, function (data) {
                    handler.remove();
                    webServiceData = data;
                }));

            WebServiceData.getEnforcementTypes();

            setTimeout(function () {
                assert.isNotNull(WebServiceData._enforcementTypes, "WebServiceData._projectsInfo should not be null.");
                assert.deepEqual(WebServiceData._enforcementTypes, webServiceData, "Get EnforcementTypes doesn't return expected result.");
                def.resolve();
            }, 8500); // need to wait for webservice data      
        },
        'Test Get ProjectsEmission': function () {
            var def = this.async(9000),
                webServiceData = null,
                handler = null;

            handler = topic.subscribe("getProjectsEmission/DataIsReady", lang.hitch(this, function (data) {
                    handler.remove();
                    webServiceData = data;
                }));

            WebServiceData.getProjectsEmission();

            setTimeout(function () {
                assert.isNotNull(WebServiceData._projectsEmission, "WebServiceData._projectsEmission should not be null.");
                assert.deepEqual(WebServiceData._projectsEmission, webServiceData, "Get ProjectsEmission doesn't return expected result.");
                def.resolve();
            }, 8500); // need to wait for webservice data      
        }
    });
});