﻿/*property
    OwnerName, WIN, _initInfoWindowModal, addGraphics, attr1, attr2, attr3,
    content, createInfoWindowPopups, getDefinitionExpression, getInfoTemplate,
    getRenderer, infoWindowHandlerContent, infoWindowHandlerTitle,
    infoWindowMessagePopupId, infoWindowPopupId, 
    initInfoWindowModal, isNull, isTrue, mapControl, name, setup,
    showGraphicTooltip, strictEqual, test1, test2, test3, title, wkid
*/
define([
    'intern!object',
    'intern/chai!assert',
    'esri/InfoTemplate',
    'esri/graphic',
    'esri/geometry/Point',
    'esri/SpatialReference',
    'app/content/_BaseContent'
], function (registerSuite, assert, InfoTemplate, Graphic, Point, SpatialReference, BaseContent) {
    'use strict';
    var baseContent;
    registerSuite({
        name: '_BaseContent module tests',
        setup: function () {
            baseContent = new BaseContent();
        },
        'Test Constructor': function () {
            assert.strictEqual(baseContent.mapControl, null, "Constructor doesn't return expected result.");
            assert.strictEqual(baseContent.infoWindowMessagePopupId, "infoWindowModalWithMessage", "Constructor doesn't return expected result.");
            assert.strictEqual(baseContent.infoWindowPopupId, "infoWindowModal", "Constructor doesn't return expected result.");
            assert.isTrue(window.createInfoWindowPopups, "Constructor doesn't return expected result.");
        },
        'Test Get InfoTemplate with strings': function () {
            var templateTitle = "templateTitle", templateContent = "templateContent",
                result = baseContent.getInfoTemplate(templateTitle, templateContent);

            assert.isTrue(result instanceof InfoTemplate, "Get InfoTemplate doesn't return expected object");
            assert.strictEqual(result.title, templateTitle, "Get InfoTemplate doesn't return expected template title.");
            assert.strictEqual(result.content, templateContent, "Get InfoTemplate doesn't return expected template content.");
        },
        'Test Get InfoTemplate with functions': function () {
            var templateTitleFunc = function() {
                    var templateTitle = "templateTitle";
                    return templateTitle;
                },
                templateContentFunc = function() {
                    var templateContent = "templateContent";
                    return templateContent;
                },
                result = baseContent.getInfoTemplate(templateTitleFunc, templateContentFunc);

            assert.isTrue(result instanceof InfoTemplate, "Get InfoTemplate doesn't return expected object");
            assert.strictEqual(result.title, templateTitleFunc, "Get InfoTemplate doesn't return expected template title.");
            assert.strictEqual(result.content, templateContentFunc, "Get InfoTemplate doesn't return expected template content.");
        },
        'Test InfoWindowHandler Content': function () {
            var point = new Point(-12797057.3396, 7237102.4651, new SpatialReference({ wkid: 102100 })),
                attr = { WIN: "123456", OwnerName: "ownerName" },
                graphic = new Graphic(point,
                           null,
                           attr,
                           null),
                result = baseContent.infoWindowHandlerContent(graphic),
                expectedResult = 'WIN : 123456<br />OwnerName : ownerName<br />';

            assert.strictEqual(result, expectedResult, "InfoWindowHandler Content doesn't return expected content.");

            point = new Point(-12791234.3396, 7231234.4651, new SpatialReference({ wkid: 10299 }));
            attr = { attr1: "12311", attr2: "attr2", attr3: "test" };
            graphic = new Graphic(point,
                           null,
                           attr,
                           null);
            expectedResult = 'attr1 : 12311<br />attr2 : attr2<br />attr3 : test<br />';
            result = baseContent.infoWindowHandlerContent(graphic);
            assert.strictEqual(result, expectedResult, "InfoWindowHandler Content doesn't return expected content.");

            point = new Point(-122233.3396, 72313334.4651, new SpatialReference({ wkid: 10777 }));
            attr = { test1: "test1", test2: "test2", test3: 123456 };
            graphic = new Graphic(point,
                           null,
                           attr,
                           null);
            expectedResult = 'test1 : test1<br />test2 : test2<br />test3 : 123456<br />';
            result = baseContent.infoWindowHandlerContent(graphic);
            assert.strictEqual(result, expectedResult, "InfoWindowHandler Content doesn't return expected content.");
        },
        'Test Get Renderer': function () {
            assert.isNull(baseContent.getRenderer, "Get Renderer function is not null");
        },
        'Test Get DefinitionExpression': function () {
            assert.isNull(baseContent.getDefinitionExpression, "Get DefinitionExpression function is not null");
        },
        'Test Add Graphics': function () {
            assert.isNull(baseContent.addGraphics, "Add Graphics function is not null");
        },
        'Test InfoWindowHandler Title': function () {
            assert.isNull(baseContent.infoWindowHandlerTitle, "InfoWindowHandler Title function is not null");
        },
        'Test Show GraphicTooltip': function () {
            assert.isNull(baseContent.showGraphicTooltip, "Show GraphicTooltip function is not null");
        }
    });
});