﻿define([
	'intern!object',
	'intern/chai!assert',
    "dojo/query",
    'dojo/dom-construct',
    'dojo/_base/window',
    'dijit/registry',
    'app/layout/IFrameModal'
], function (registerSuite, assert, query, domConstruct, win, registry, IFrameModal) {
    'use strict';
    var divName = "iframeModal",
        modalRequiredMarkup = '<div id="myModal" class="modal fade iframe-modal" style="display: none;" aria-hidden="true"><div id="' + divName + '"></div></div>';
    
    registerSuite({
        name: 'IFrameModal test suite',
        setup: function () {
            domConstruct.place('<link title="bootstrapCss" rel="stylesheet" href="../../Scripts/lib/bootstrap/css/bootstrap.min.css" />', win.doc.getElementsByTagName("head")[0], 'last');
            
        },
        teardown: function () {
            //disable and then remove the added stylesheets
            var stylesheet = query('link[title=bootstrapCss]')[0];
            stylesheet.disabled = true;
            stylesheet.remove();
        },
        beforeEach: function() {
            domConstruct.place(modalRequiredMarkup, win.body());
        },
        afterEach: function() {
            //remove the elements from the DOM
            query('.iframe-modal').remove();
            //remove from the dijit registry
            registry.remove(divName);
        },
        'test Constructor without src': function () {
            //constructor is run during the setup
            var domElements,
                modalId = "modalFrame",
                iframeModal = new IFrameModal({ iframeId: modalId}, divName);
            iframeModal.startup();
            domElements = query('.modal-dialog');
            assert.isDefined(domElements[0], "IFrameModal template elements should be included in the DOM.");
        },
        'test Constructor with src': function () {
            //constructor is run during the setup
            var domElements, def = this.async(8000),
                modalRoot = query('.iframe-modal'), url = "../../tests/app/layout/IFrameModalTest.html",
                modalId = "modalFrame",
                iframeModal = new IFrameModal({ iframeId: modalId, iframeSrc: url }, divName);
            iframeModal.startup();
            domElements = query('.modal-dialog');
            assert.isDefined(domElements[0], "IFrameModal template elements should be included in the DOM.");

            assert.isDefined(query('[id="' + modalId + '"]'), "IFrameModal with the given iframeId is not defined");
            assert.strictEqual(query('[id="'+ modalId +'"]').attr('src')[0], url, "iframe src attribute should be equal to the IFrameModal iframeSrc option.");

            query('[id="' + modalId + '"]').attr('height', "300px").attr('width', "100%");
            
            assert.isDefined(modalRoot.modal, "the bootstrap modal extension is not defined.");

            modalRoot.on('show.bs.modal', function () {
                setTimeout(function() {
                    console.log("waiting for modal dialog to open"); 
                    def.resolve();
                }, 250);
                
            });
            modalRoot.modal('show');

        }


    });
});