﻿define([
    'intern!object',
    'intern/chai!assert',
    'app/utils/SimpleEncoder'
], function (registerSuite, assert, SimpleEncoder) {
    'use strict';
    registerSuite({
        name: 'SimpleEncoder module tests',
        'Test StringToByteArray Simple Case': function () {
            var toEncodeSimple = "Apple",
                expectedResult = [65, 112, 112, 108, 101],
                result = SimpleEncoder.stringToByteArray(toEncodeSimple);
            assert.notStrictEqual(result, toEncodeSimple, 'Result should not equal input');
            assert.deepEqual(result, expectedResult, 'Unexpected result.');
        },
        'Test StringToByteArray with unicode': function () {
            var toEncodeUnicode = "✓ à la mode",
                expectedResult = [37, 69, 50, 37, 57, 67, 37, 57, 51, 37, 50, 48, 37, 67, 51, 37, 65, 48, 37, 50, 48, 108, 97, 37, 50, 48, 109, 111, 100, 101],
                result = SimpleEncoder.stringToByteArray(toEncodeUnicode);
            assert.notStrictEqual(result, toEncodeUnicode, 'Result should not equal input');
            assert.deepEqual(result, expectedResult, 'Unexpected result.');
        },
        'Test base 64 encoding a simple string': function() {
            var toEncodeSimple = "Apple",
                expectedResult = "QXBwbGU=",
                result = SimpleEncoder.encodeString(toEncodeSimple);
            assert.notStrictEqual(result, toEncodeSimple, 'Result should not equal input');
            assert.strictEqual(result, expectedResult, 'Unexpected result.');
        },
        'Test base 64 encoding a unicode string': function () {
            var toEncodeUnicode = "✓ à la mode",
                expectedResult = "JUUyJTlDJTkzJTIwJUMzJUEwJTIwbGElMjBtb2Rl",
                result = SimpleEncoder.encodeString(toEncodeUnicode);
            assert.notStrictEqual(result, toEncodeUnicode, 'Result should not equal input');
            assert.strictEqual(result, expectedResult, 'Unexpected result.');
        },
        'Test base 64 decoding a simple string': function () {
            var toDecode = "QXBwbGU=" ,
                expectedResult = "Apple",
                result = SimpleEncoder.decodeString(toDecode);
            assert.notStrictEqual(result, toDecode, 'Result should not equal input');
            assert.strictEqual(result, expectedResult, 'Unexpected result.');
        },
        'Test base 64 decoding a unicode string': function () {
            var toDecode = "JUUyJTlDJTkzJTIwJUMzJUEwJTIwbGElMjBtb2Rl",
                expectedResult = "✓ à la mode",
                result = SimpleEncoder.decodeString(toDecode);
            assert.notStrictEqual(result, toDecode, 'Result should not equal input');
            assert.strictEqual(result, expectedResult, 'Unexpected result.');
        }
    });
});