﻿
var siteConfig = {
    dataUrl: 'http://aemerisuat.alberta.ca/data/',
    libraryUrl: 'http://aemerisuat.alberta.ca/library/',
    imagePath: '/Images/',
    rootUrl: '/',
    logoUrl: 'http://environmentalmonitoring.alberta.ca/',
    oilSandsApiUrl: 'http://osipuat.alberta.ca/services/oilsandsapi/odata',
    scriptsPath: 'Scripts/'
};

// Learn more about configuring this file at <https://github.com/theintern/intern/wiki/Configuring-Intern>.
// These default settings work OK for most people. The options that *must* be changed below are the
// packages, suites, excludeInstrumentation, and (if you want functional tests) functionalSuites.
define([ 'intern/node_modules/dojo/has', '../Scripts/app/dojoConfig' ], function(has) {
    'use strict';
    var suites = [
        //'tests/sample',
        'tests/app/utils/SimpleEncoder',
        'tests/app/utils/Common',
        'tests/app/mapping/Utils',
        'tests/app/content/OilSandsContent',
        'tests/app/content/_BaseContent',
        'tests/app/content/CaribouContent',
        'tests/app/content/TailingsPondContent',
        'tests/app/content/AirEmissionsContent',
        'tests/app/content/AQHIContent',
        'tests/app/content/RiverFlowAndLakeLevelContent',
        'tests/app/content/RiverQualityContent',
        'tests/app/content/LakeQualityContent',
        'tests/app/content/WebServiceData',
        'tests/app/search/SearchableConfig',
        'tests/app/search/modules/ContentGroupLink',
        'tests/app/search/modules/ContentGroupOperationalLayerMultiLayerLink',
        'tests/app/search/modules/ContentGroupOperationalLayerMultiLayerTitle',
        'tests/app/search/modules/ContentGroupOperationalLayerRelatedLink',
        'tests/app/search/modules/ContentGroupOperationalLayerTitle',
        'tests/app/search/modules/MapLayerOSIPProject'
    ];

    if (has('host-browser')) {
        //The Bookmarker module makes use of History.js which requires a browser environment
        suites.push('tests/app/utils/Bookmarker');
        suites.push('tests/app/layout/IFrameModal');
    }
    
    return {
        // The port on which the instrumenting proxy will listen
        proxyPort: 9000,

        // A fully qualified URL to the Intern proxy
        proxyUrl: 'http://localhost:9000/',

        // Default desired capabilities for all environments. Individual capabilities can be overridden by any of the
        // specified browser environments in the `environments` array below as well. See
        // https://code.google.com/p/selenium/wiki/DesiredCapabilities for standard Selenium capabilities and
        // https://saucelabs.com/docs/additional-config#desired-capabilities for Sauce Labs capabilities.
        // Note that the `build` capability will be filled in with the current commit ID from the Travis CI environment
        // automatically
        capabilities: {
            'selenium-version': '2.38.0'
        },

        // Browsers to run integration testing against. Note that version numbers must be strings if used with Sauce
        // OnDemand. Options that will be permutated are browserName, version, platform, and platformVersion; any other
        // capabilities options specified for an environment will be copied as-is
        environments: [
            {
                browserName: 'internet explorer',
                version: '10',
                platform: 'Windows 8'
            }, {
                browserName: 'internet explorer',
                version: '9',
                platform: 'Windows 7'
            }, {
                browserName: 'firefox',
                version: '23',
                platform: ['Linux', 'Windows 7']
            }, {
                browserName: 'firefox',
                version: '21',
                platform: 'Mac 10.6'
            }, {
                browserName: 'chrome',
                platform: ['Linux', 'Mac 10.8', 'Windows 7']
            }, {
                browserName: 'safari',
                version: '6',
                platform: 'Mac 10.8'
            }
        ],

        // Maximum number of simultaneous integration tests that should be executed on the remote WebDriver service
        maxConcurrency: 3,

        // Name of the tunnel class to use for WebDriver tests
        tunnel: 'SauceLabsTunnel',

        // Connection information for the remote WebDriver service. If using Sauce Labs, keep your username and password
        // in the SAUCE_USERNAME and SAUCE_ACCESS_KEY environment variables unless you are sure you will NEVER be
        // publishing this configuration file somewhere
        webdriver: {
            host: 'localhost',
            port: 4444
        },

        // The desired AMD loader to use when running unit tests (client.html/client.js). Omit to use the default Dojo
        // loader
        useLoader: {
            'host-node': 'dojo/dojo',
            'host-browser': 'node_modules/dojo/dojo.js'
        },

        // Configuration options for the module loader; any AMD configuration options supported by the Dojo loader can be
        // used here
        loader: {
            packages: dojoConfig.packages.concat([
                { name: 'tests', location: 'tests' },
                { name: 'esri', location: 'Scripts/lib/esri' },
                { name: 'put-selector', location: 'Scripts/lib/put-selector' },
                { name: 'xstyle', location: 'Scripts/lib/xstyle' },
                { name: 'dojo', location: 'Scripts/lib/dojo' },
                { name: 'dojox', location: 'Scripts/lib/dojox' },
                { name: 'dijit', location: 'Scripts/lib/dijit' }
            ])
        },

        // Non-functional test suite(s) to run in each browser
        suites: suites,

        // Functional test suite(s) to run in each browser once non-functional tests are completed
        functionalSuites: [
            /* 'myPackage/tests/functional' */
            //'tests/functional/index'
        ],

        // A regular expression matching URLs to files that should not be included in code coverage analysis
        excludeInstrumentation: /^(?:tests|node_modules|Scripts\\lib)\\/
    };
});
